package org.jeecg.common.exception;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Iterator;

@Component
@Slf4j
public class LoggingInterceptor implements HandlerInterceptor {

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        // 记录普通请求信息
        log.info("Request intercepted: URL={}, Method={}, Parameters={}",
                request.getRequestURI(), request.getMethod(), request.getParameterMap());

        // 如果是多部分请求（文件上传），记录文件元数据
        if (request instanceof MultipartHttpServletRequest) {
            MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
            Iterator<String> fileNames = multipartRequest.getFileNames();

            while (fileNames.hasNext()) {
                String fileName = fileNames.next();
                MultipartFile file = multipartRequest.getFile(fileName);
                log.info("Intercepted file upload: URL={}, File name={}, Size={} bytes, Content type={}",
                        request.getRequestURI(), file.getOriginalFilename(), file.getSize(), file.getContentType());
            }
        }

        return true; // 继续处理链
    }

    // 可选：实现postHandle和afterCompletion方法...
    @Override
    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler, ModelAndView modelAndView) throws Exception {
        // 可以在这里添加处理后的行为
    }

    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) throws Exception {
        // 可以在这里添加请求完成后的行为
    }
}
