package org.jeecg.common.util;

import com.jcraft.jsch.*;
import org.jeecg.common.constant.SymbolConstant;
import org.jeecg.common.util.filter.StrAttackFilter;
import org.jeecg.common.util.text.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.net.URLEncoder;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;

public class SFTPUtil {
    private static long count = 3;
    private static long count1 = 0;
    private static long sleepTime = 1000;//1秒
    private static final Logger logger = LoggerFactory.getLogger(SFTPUtil.class);
    private static Session sshSession = null;
    private static ChannelSftp sftp = null;

    public static void getSession(SftpConfig sftpConfig){
        try {
            if(sshSession == null ){
                JSch jsch = new JSch();
                sshSession = jsch.getSession(sftpConfig.getUsername(), sftpConfig.getHostname(), sftpConfig.getPort());
                logger.info("Session created ... host=" + sftpConfig.getHostname() + ";port=" + sftpConfig.getPort()+";UserName=" + sftpConfig.getUsername() + ";Password="+sftpConfig.getPassword());
//            jsch.addIdentity("e:/sftp_keys.ppk","");
                sshSession.setPassword(sftpConfig.getPassword());
                Properties sshConfig = new Properties();
                sshConfig.put("StrictHostKeyChecking", "no");
                sshSession.setConfig(sshConfig);
                sshSession.setTimeout(sftpConfig.getTimeout());
                sshSession.connect();
                logger.info("Session connected ...");
                logger.info("Opening Channel ...");
            }
        } catch (Exception e){
            try{
                count1 += 1;
                if(count == count1){
                    throw new RuntimeException(e);
                }
                Thread.sleep(sleepTime);
                logger.info("重新连接....");
                getSession(sftpConfig);
            } catch (InterruptedException e1){
                throw new RuntimeException(e1);
            }
        }
    }

    public static void getChannelSftp(SftpConfig sftpConfig){
        try {
            if(sshSession == null){
                getSession(sftpConfig);
                Channel channel = sshSession.openChannel("sftp");
                channel.connect();
                sftp = (ChannelSftp) channel;
                logger.info("登录成功");
            }else{
                Channel channel = sshSession.openChannel("sftp");
                channel.connect();
                sftp = (ChannelSftp) channel;
            }
        } catch (Exception e){
            try{
                count1 += 1;
                if(count == count1){
                    throw new RuntimeException(e);
                }
                 Thread.sleep(sleepTime);
                logger.info("重新连接....");
                getChannelSftp(sftpConfig);
            } catch (InterruptedException e1){
                throw new RuntimeException(e1);
            }
        }
    }

    private static void mkdirs(String directory) throws SftpException {
        String[] dics = directory.split("/");
        for(int i=0;i< dics.length;i++){
            try {
                 if(dics[i].equals("")){
                    continue;
                }
                sftp.cd(dics[i]);
            } catch (SftpException e1) {
                try {
                    sftp.mkdir(dics[i]);
                    sftp.cd(dics[i]);
                } catch (SftpException e2) {
                    throw new RuntimeException("打开文件夹错误，"+e2.getMessage(), e2);
                }
            }
        }
    }

    /**
     * 上传文件
     * @param isConcat  是否拼接，true时拼接/kczx
     * @param directory  上传的目录
     * @param uploadFilePath 要上传的文件路径（文件真实路径+名称）
     * @param uploadFileName 要上传的文件名称（重新定义的文件名称）
     * @param
     */
    public static Map<String,String> upload(SftpConfig sftpConfig,boolean isConcat, String directory, String uploadFilePath, String uploadFileName) {
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        map.put("msg","上传成功");
        try{
            if(sftp == null){
                getChannelSftp(sftpConfig);
            }
            try {
                sftp.cd(sftpConfig.getFullpath());
            } catch (SftpException e1) {
                try {
                    mkdirs(sftpConfig.getFullpath());
                } catch (SftpException e2) {
                    map.put("code", "1");
                    map.put("msg", "sftp创建" + sftpConfig.getUploadpath() + "文件路径失败");
                }
            }
            try {
                if(isConcat){
                    directory = getDirectory(sftpConfig.getUploadpath(),directory);
                }
                sftp.cd(directory);
            } catch (SftpException e1) {
                try {
                    mkdirs(directory);
//                    sftp.mkdir(directory);
//                    sftp.cd(directory);
                } catch (SftpException e2) {
                    map.put("code","1");
                    map.put("msg","ftp创建"+directory+"文件路径失败");
//                throw new RuntimeException("ftp创建文件路径失败" + directory);
                }
            }
            File file = new File(uploadFilePath);
            InputStream inputStream=null;
            try {
                inputStream = new FileInputStream(file);
                sftp.put(inputStream, uploadFileName);
                map.put("data",directory.concat(uploadFileName));
            } catch (Exception e3) {
                map.put("code","1");
                map.put("msg","上传文件异常：" + e3.getMessage());
//            throw new RuntimeException("sftp异常" + e3);
            } finally {
                closeStream(inputStream,null);
            }
        }catch (Exception e) {
            map.put("code","1");
            map.put("msg","sftp异常：" + e.getMessage());
        }
        return map;
    }

    public static Map<String,String> upload(SftpConfig sftpConfig, MultipartFile file, String directory) {
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        map.put("msg","上传成功");
        try{
            if(sftp == null){
                getChannelSftp(sftpConfig);
            }
            try {
                sftp.cd(sftpConfig.getFullpath());
            } catch (SftpException e1) {
                try {
                    mkdirs(sftpConfig.getFullpath());
                } catch (SftpException e2) {
                    map.put("code", "1");
                    map.put("msg", "sftp创建" + sftpConfig.getUploadpath() + "文件路径失败");
                }
            }
            try {
                sftp.cd(directory);
            } catch (SftpException e1) {
                try {
                    mkdirs(directory);
                } catch (SftpException e2) {
                    map.put("code","1");
                    map.put("msg","ftp创建"+directory+"文件路径失败");
//                throw new RuntimeException("ftp创建文件路径失败" + directory);
                }
            }
            String fileName = null;
            // 获取文件名
            String orgName = StrAttackFilter.filter2(file.getOriginalFilename());
            orgName = CommonUtils.getFileName(orgName);
            if(orgName.indexOf(SymbolConstant.SPOT)!=-1){
                fileName = orgName.substring(0, orgName.lastIndexOf(".")) + "_" + System.currentTimeMillis() + orgName.substring(orgName.lastIndexOf("."));
            }else{
                fileName = orgName+ "_" + System.currentTimeMillis();
            }
            InputStream inputStream=null;
            try {
                sftp.put(file.getInputStream(), fileName);
                map.put("data",directory.concat("/").concat(fileName));
            } catch (Exception e3) {
                map.put("code","1");
                map.put("msg","上传文件异常：" + e3.getMessage());
//            throw new RuntimeException("sftp异常" + e3);
            } finally {
                closeStream(inputStream,null);
            }
        }catch (Exception e) {
            map.put("code","1");
            map.put("msg","sftp异常：" + e.getMessage());
        }
        return map;
    }

    /**
     * 下载文件
     *
     * @param directory    下载目录
     * @param downloadFile 下载的文件
     * @param saveFile     存在本地的路径
     */
    public static Map<String,String> download(SftpConfig sftpConfig, String directory, String downloadFile, String saveFile) {
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        map.put("msg","下载成功");
        try{
            if(sftp == null){
                getChannelSftp(sftpConfig);
            }
            OutputStream output = null;
            try {
                File localDirFile = new File(saveFile);
                // 判断本地目录是否存在，不存在需要新建各级目录
                if (!localDirFile.exists()) {
                    localDirFile.mkdirs();
                }
                if (logger.isInfoEnabled()) {
                    logger.info("开始获取远程文件:[{}]---->[{}]", new Object[]{directory, saveFile});
                }
//                sftp.cd(directory);
                if (logger.isInfoEnabled()) {
                    logger.info("打开远程文件:[{}]", new Object[]{directory});
                }
                String newName = CommonUtils.getFileName(downloadFile);
                String newDownloadFile = saveFile.concat(File.separator).concat(newName);
                output = new FileOutputStream(new File(newDownloadFile));
                sftp.get(directory, output);
                if (logger.isInfoEnabled()) {
                    logger.info("文件下载成功");
                }
                map.put("fileName",newDownloadFile);
            } catch (Exception e) {
                if (logger.isInfoEnabled()) {
                    logger.info("文件下载出现异常，[{}]", e);
                }
                throw new RuntimeException("文件下载出现异常，[{}]", e);
            } finally {
                closeStream(null,output);
            }
        }catch (Exception e) {
            map.put("code","1");
            map.put("msg","sftp异常：" + e.getMessage());
        }
        return map;
    }

    /**
     * 下载文件
     * @param directory    下载目录
     * @param saveFile     存在本地的路径
     */
    public static Map<String,String> download(SftpConfig sftpConfig, String directory, String saveFile) {
        Map<String,String> map = new HashMap<>();
        map.put("code","0");
        map.put("msg","下载成功");
        String[] df = getDirectoryAndFileName(directory);

        File localDirFile = new File(saveFile);
        // 判断本地目录是否存在，不存在需要新建各级目录
        if (!localDirFile.exists()) {
            localDirFile.mkdirs();
        }
        saveFile = saveFile.replace("\\","/");
        String newName = CommonUtils.getFileName(df[1]);
        if(!newName.startsWith("/")){
            newName = "/"+newName;
        }
        String newDownloadFile = saveFile.concat(newName);

        File localFile = new File(newDownloadFile);
        // 判断本地目录是否存在，不存在需要新建各级目录
        if (localFile.exists()) {
            map.put("fileName",newDownloadFile);
            return map;
        }

        try{
            if(sftp == null){
                getChannelSftp(sftpConfig);
                if(sftp == null){
                    map.put("code","1");
                    map.put("msg","sftp链接异常：");
                    return map;
                }
            }else{
                sftp.cd(sftpConfig.getFullpath());
            }
            OutputStream output = null;
            try {
                if (logger.isInfoEnabled()) {
                    logger.info("开始获取远程文件:[{}]---->[{}]", new Object[]{directory, newDownloadFile});
                }
//                sftp.cd(directory);
                if (logger.isInfoEnabled()) {
                    logger.info("打开远程文件:[{}]", new Object[]{directory});
                }
                output = new FileOutputStream(localFile);
                sftp.get(directory, output);
                if (logger.isInfoEnabled()) {
                    logger.info("文件下载成功");
                }
                map.put("fileName",newDownloadFile);
            } catch (Exception e) {
                if (logger.isInfoEnabled()) {
                    logger.info("文件下载出现异常，[{}]", e);
                }
                throw new RuntimeException("文件下载出现异常，[{}]", e);
            } finally {
                closeStream(null,output);
            }
        }catch (Exception e) {
            map.put("code","1");
            map.put("msg","sftp异常：" + e.getMessage());
        }
        return map;
    }

    /**
     * 网页下载文件
     * @param response
     * @param downloadFilePath
     * @throws Exception
     */
    public static void writeFileToRes(SftpConfig sftpConfig, String downloadFilePath, HttpServletResponse response) throws Exception {
        String[] df = getDirectoryAndFileName(downloadFilePath);
        String directory = df[0];
        String downloadFile = df[1];
        try{
            if(sftp == null){
                getChannelSftp(sftpConfig);
            }
            InputStream inputStream = null;
            ServletOutputStream outputStream=null;
            try {
//                sftp.cd(directory);
                inputStream = sftp.get(downloadFilePath);
                byte[] buf = new byte[1024 * 10];
                outputStream = response.getOutputStream();
                response.setHeader("content-disposition", "attachment;filename=" + URLEncoder.encode(downloadFile, "UTF-8"));
                int readLength;
                while (((readLength = inputStream.read(buf)) != -1)) {
                    outputStream.write(buf, 0, readLength);
                }
                outputStream.flush();
            } catch (Exception e1) {
//                e1.printStackTrace();
//                throw new Exception(StringUtils.format("sftp exception,sftp exception。 ", e1.getMessage()));
            } finally {
                closeStream(null,outputStream);
            }
        }catch (Exception e) {
            e.printStackTrace();
            throw new Exception(StringUtils.format("sftp exception,sftp exception。 ", e.getMessage()));
        }
    }

    /**
     * 移动文件
     * @param oldpath 原文件路径（文件路径+名称）
     * @param directory 目的文件路径
     * @param newname 目的文件名称
     * @param
     */
    public static Map<String,String> moveFile(SftpConfig sftpConfig, String oldpath, String directory, String newname) {
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        map.put("msg","上传成功");
        try {
            if(sftp == null){
                getChannelSftp(sftpConfig);
            }
            try {
                sftp.cd(sftpConfig.getFullpath());
            } catch (SftpException e1) {
                try {
                    mkdirs(sftpConfig.getFullpath());
                } catch (SftpException e2) {
                    map.put("code", "1");
                    map.put("msg", "sftp创建" + sftpConfig.getUploadpath() + "文件路径失败");
                }
            }
            try {
                directory = getDirectory(sftpConfig.getUploadpath(), directory);
                sftp.cd(directory);
            } catch (SftpException e1) {
                try {
                    mkdirs(directory);
                } catch (SftpException e2) {
                    map.put("code", "1");
                    map.put("msg", "ftp创建" + directory + "文件路径失败");
                }
            }
            Channel channel = null;
            try {
                if(!oldpath.startsWith("/")){
                    oldpath = "/"+oldpath;
                }
                String oldfullpath = sftpConfig.getFullpath().concat(oldpath);
                String newpath = directory.concat(newname);
                String newfullpath = sftpConfig.getFullpath().concat(newpath);
                String moveCommand = "mv " + oldfullpath + " " + newfullpath; // 移动文件的命令
                channel = sshSession.openChannel("exec");
                ((ChannelExec) channel).setCommand(moveCommand);
                channel.setInputStream(null);
                ((ChannelExec) channel).setErrStream(System.err);
                InputStream in = channel.getInputStream();
                channel.connect();
                byte[] tmp = new byte[1024];
                while (true) {
                    while (in.available() > 0) {
                        int i = in.read(tmp, 0, 1024);
                        if (i < 0) break;
                    }
                    if (channel.isClosed()) {
                        System.out.println("exit-status: " + channel.getExitStatus());
                        break;
                    }
                    try {
                        Thread.sleep(sleepTime);
                    } catch (Exception ee) {
                    }
                }
                channel.disconnect();
                channel = null;
                map.put("data",newpath);
            } catch (Exception e1) {
                map.put("code","1");
                map.put("msg",e1.getMessage());
//                throw new RuntimeException("ftp创建文件路径失败" + directory);
            }finally {
                if(channel!=null){
                    channel.disconnect();
                    channel = null;
                }
            }
        } catch (Exception e) {
            map.put("code","1");
            map.put("msg","sftp异常：" + e.getMessage());
        }
        return map;
    }

    public static Map<String,String> moveFiles(SftpConfig sftpConfig, String directory, List<String[]> list) {
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        map.put("msg","上传成功");
        try {
            if(sftp == null){
                getChannelSftp(sftpConfig);
            }
            try {
                sftp.cd(sftpConfig.getFullpath());
            } catch (SftpException e1) {
                try {
                    mkdirs(sftpConfig.getFullpath());
                } catch (SftpException e2) {
                    map.put("code", "1");
                    map.put("msg", "sftp创建" + sftpConfig.getUploadpath() + "文件路径失败");
                }
            }
            try {
                directory = getDirectory(sftpConfig.getUploadpath(), directory);
                sftp.cd(directory);
            } catch (SftpException e1) {
                try {
                    mkdirs(directory);
                } catch (SftpException e2) {
                    map.put("code", "1");
                    map.put("msg", "sftp创建" + directory + "文件路径失败");
                }
            }
            sftp.cd(sftpConfig.getFullpath());
            Channel channel = null;
            try {
                StringBuffer sb = new StringBuffer();
                for(int item=0;item<list.size();item++){
                    String oldpath = list.get(item)[0];
                    if(!oldpath.startsWith("/")){
                        oldpath = "/"+oldpath;
                    }
                    String oldfullpath = sftpConfig.getFullpath().concat(oldpath);
                    String newname = list.get(item)[1];
                    String newpath = directory.concat(newname);
                    String newfullpath = sftpConfig.getFullpath().concat("/").concat(newpath);
                    String moveCommand = "cp " + oldfullpath + " " + newfullpath; // 移动文件的命令
                    channel = sshSession.openChannel("exec");
                    ((ChannelExec) channel).setCommand(moveCommand);
                    channel.setInputStream(null);
                    ((ChannelExec) channel).setErrStream(System.err);
                    InputStream in = channel.getInputStream();
                    channel.connect();
                    byte[] tmp = new byte[1024];
                    while (true) {
                        while (in.available() > 0) {
                            int i = in.read(tmp, 0, 1024);
                            if (i < 0) break;
                        }
                        if (channel.isClosed()) {
                            System.out.println("exit-status: " + channel.getExitStatus());
                            break;
                        }
                        try {
                            Thread.sleep(1000);
                        } catch (Exception ee) {
                        }
                    }
                    channel.disconnect();
                    channel = null;
                    sb.append(newpath);
                    sb.append("|");
                }
                String path = sb.toString();
                path = path.substring(0,path.length()-1);
                map.put("data",path);
                logger.info("移动文件成功....");
            } catch (Exception e1) {
                map.put("code","1");
                map.put("msg",e1.getMessage());
//                throw new RuntimeException("ftp创建文件路径失败" + directory);
            }finally {
                if(channel!=null){
                    channel.disconnect();
                    channel = null;
                }
            }
        } catch (Exception e) {
            map.put("code","1");
            map.put("msg","sftp异常：" + e.getMessage());
        }
        return map;
    }


    /**
     * 删除文件
     * @param directory  要删除文件所在目录
     * @param deleteFile 要删除的文件
     */
    public static Map<String,String> delete(SftpConfig sftpConfig, String directory, String deleteFile) {
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        map.put("msg","删除成功");
        try{
            if(sftp == null){
                getChannelSftp(sftpConfig);
            }
            directory = delDiagonalLines(directory);
            sftp.cd(directory);
            sftp.rm(deleteFile);
        }catch (Exception e) {
            map.put("code","1");
            map.put("msg","sftp异常：" + e.getMessage());
        }
        return map;
    }

    private static String getDirectory(String uploadpath, String directory){
        if(uploadpath.endsWith("/")){
            return uploadpath + directory;
        }else{
            return uploadpath +"/"+ directory;
        }
    }

    private static String delDiagonalLines(String directory){
        if(directory.startsWith("/")){
            directory = directory.substring(directory.indexOf("/")+1);
            delDiagonalLines(directory);
        }
        return directory;
    }

    /**
     * 断掉连接
     */
    public static void disChannel() {
        try {
            if(sftp!=null){
                sftp.disconnect();
                sftp=null;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void disSession() {
        try {
            if(sshSession!=null) {
                sshSession.disconnect();
                sshSession=null;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 关闭流
     * @param outputStream
     */
    private static void closeStream(InputStream inputStream,OutputStream outputStream) {
        if (outputStream != null) {
            try {
                outputStream.close();
            } catch (IOException e) {
                e.printStackTrace();
            }finally {
            }
        }
        if(inputStream != null){
            try {
                inputStream.close();
            } catch (IOException e) {
                e.printStackTrace();
            }finally {
            }
        }
        if(sftp != null){
            try {
                disChannel();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public static String[] getDirectoryAndFileName(String fileName) {
        String[] ss = new String[2];
        String path = fileName.substring(0,fileName.lastIndexOf("/"));
        String name = fileName.substring(fileName.lastIndexOf("/")+1);
        ss[0] = path;
        ss[1] = name;
        return ss;
    }

    /*****************以下为预留方法*******************/
//    /**
//     * 下载远程文件夹下的所有文件
//     * @param remoteFilePath
//     * @param localDirPath
//     * @throws Exception
//     */
//    public void getFileDir(String remoteFilePath, String localDirPath) throws Exception {
//        File localDirFile = new File(localDirPath);
//        // 判断本地目录是否存在，不存在需要新建各级目录
//        if (!localDirFile.exists()) {
//            localDirFile.mkdirs();
//        }
//        if (logger.isInfoEnabled()) {
//            logger.info("sftp文件服务器文件夹[{}],下载到本地目录[{}]", new Object[]{remoteFilePath, localDirFile});
//        }
//        ChannelSftp channelSftp = connect();
//        Vector<LsEntry> lsEntries = channelSftp.ls(remoteFilePath);
//        if (logger.isInfoEnabled()) {
//            logger.info("远程目录下的文件为[{}]", lsEntries);
//        }
//        for (LsEntry entry : lsEntries) {
//            String fileName = entry.getFilename();
//            if (checkFileName(fileName)) {
//                continue;
//            }
//            String remoteFileName = getRemoteFilePath(remoteFilePath, fileName);
//            channelSftp.get(remoteFileName, localDirPath);
//        }
//        disConnect(channelSftp);
//    }
//
//    private boolean checkFileName(String fileName) {
//        if (".".equals(fileName) || "..".equals(fileName)) {
//            return true;
//        }
//        return false;
//    }
//
//    private String getRemoteFilePath(String remoteFilePath, String fileName) {
//        if (remoteFilePath.endsWith("/")) {
//            return remoteFilePath.concat(fileName);
//        } else {
//            return remoteFilePath.concat("/").concat(fileName);
//        }
//    }
//
//    /**
//     * 列出目录下的文件
//     * @param directory  要列出的目录
//     * @return
//     * @throws SftpException
//     */
//    public List<String> listFiles(String directory) throws SftpException {
//        ChannelSftp sftp = connect();
//        List fileNameList = new ArrayList();
//        try {
//            sftp.cd(directory);
//        } catch (SftpException e) {
//            return fileNameList;
//        }
//        Vector vector = sftp.ls(directory);
//        for (int i = 0; i < vector.size(); i++) {
//            if (vector.get(i) instanceof LsEntry) {
//                LsEntry lsEntry = (LsEntry) vector.get(i);
//                String fileName = lsEntry.getFilename();
//                if (".".equals(fileName) || "..".equals(fileName)) {
//                    continue;
//                }
//                fileNameList.add(fileName);
//            }
//        }
//        disConnect(sftp);
//        return fileNameList;
//    }


    /**
     * ftp上传文件
     * @param sftpConfig ftp配置
     * @param localFile 本地存储地址
     * @param sftpFile sftp存储地址
     * @return
     */
    public static Map<String,String> upload(SftpConfig sftpConfig, String localFile, String sftpFile) {
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        map.put("msg","上传成功");
        try{
            String allPath = sftpConfig.getFullpath() +"/"+sftpConfig.getUploadpath();
            if(sftp == null){
                getChannelSftp(sftpConfig);
            }
            try {
                sftp.cd(sftpConfig.getFullpath());
            } catch (SftpException e1) {
                try {
                    sftp.mkdir(sftpConfig.getFullpath());
                } catch (SftpException e2) {
                    map.put("code", "1");
                    map.put("msg", "sftp创建" + sftpConfig.getFullpath() + "文件路径失败");
                }
            }
            try {
                sftp.cd(sftpConfig.getUploadpath());
            } catch (SftpException e1) {
                try {
                    mkdirs(sftpConfig.getUploadpath());
                } catch (SftpException e2) {
                    map.put("code", "1");
                    map.put("msg", "sftp创建" + sftpConfig.getUploadpath() + "文件路径失败");
                }
            }
            InputStream inputStream = null;
            try {
                inputStream = new FileInputStream(localFile);
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
            try {

                String aaa[] = sftpFile.split("/");
                String wwqName = aaa[aaa.length -1];
                for(int i=0;i<aaa.length -1;i++){
                    allPath = allPath+"/"+aaa[i];
                    try {
                        sftp.cd(aaa[i]);
                    } catch (SftpException e1) {
                        try {
                            mkdirs(aaa[i]);
                        } catch (SftpException e2) {
                            map.put("code", "1");
                            map.put("msg", "sftp创建" + sftpConfig.getUploadpath() + "文件路径失败");
                        }
                    }
                }


                sftp.put(inputStream, allPath+"/"+wwqName);
                map.put("data",sftpConfig.getUploadpath().concat("/").concat(sftpFile));
            } catch (Exception e3) {
                map.put("code","1");
                map.put("msg","上传文件异常：" + e3.getMessage());
//            throw new RuntimeException("sftp异常" + e3);
            } finally {
                closeStream(inputStream,null);
            }
        }catch (Exception e) {
            map.put("code","1");
            map.put("msg","sftp异常：" + e.getMessage());
        }
        return map;
    }
}
