package org.jeecg.modules.httpinterface.controller;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.net.url.UrlBuilder;
import cn.hutool.core.util.CharsetUtil;
import cn.hutool.crypto.SecureUtil;
import cn.hutool.http.HttpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.google.common.collect.Maps;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.compress.utils.Lists;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.modules.kc.grab.exports.entity.TBks;
import org.jeecg.modules.kc.grab.exports.service.ITBksService;
import org.jeecg.modules.kc.jiaoshi.entity.KcZhihuijiaoshi;
import org.jeecg.modules.kc.jiaoshi.entity.KcZhihuijiaoshiMonitorLog;
import org.jeecg.modules.kc.jiaoshi.entity.KcZhihuijiaoshiOperateLog;
import org.jeecg.modules.kc.jiaoshi.service.IKcZhihuijiaoshiMonitorLogService;
import org.jeecg.modules.kc.jiaoshi.service.IKcZhihuijiaoshiOperateLogService;
import org.jeecg.modules.kc.jiaoshi.service.IKcZhihuijiaoshiService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * @Description: 对外部访问接口
 * @Author: jeecg-boot
 * @Date:   2023-04-10
 * @Version: V1.0
 */
@Slf4j
@Api(tags="对外部访问接口")
@RestController
@RequestMapping("/httpinterface")
public class httpController extends JeecgController<TBks, ITBksService> {

    @Autowired
    private IKcZhihuijiaoshiService kcZhihuijiaoshiService;

    @Autowired
    private IKcZhihuijiaoshiOperateLogService kcZhihuijiaoshiOperateLogService;

    @Autowired
    private IKcZhihuijiaoshiMonitorLogService kcZhihuijiaoshiMonitorLogService;//操作与状态日志


    @AutoLog(value = "对外部访问接口-通过IDS访问奥威亚接口")
    @ApiOperation(value="T_BKS-抓取-通过id查询", notes="T_BKS-抓取-通过id查询")
    @GetMapping(value = "/runAvyApiByIds")
    public Result<?> runAvyApiByIds(String ids,String type){
        Result<List<Map<String,String>>> res = Result.OK("操作成功");
        List<Map<String,String>> resultList = Lists.newArrayList();
        res.setResult(resultList);
        if(StringUtils.isNotBlank(ids)){
            List<String> idList = Arrays.asList(ids.split(","));
            QueryWrapper<KcZhihuijiaoshi> qw = new QueryWrapper<>();
            qw.in("id",idList);
            List<KcZhihuijiaoshi> list = kcZhihuijiaoshiService.list(qw);

            list.forEach(x -> {
                KcZhihuijiaoshiOperateLog operateLog = new KcZhihuijiaoshiOperateLog();
                operateLog.setJxlId(x.getJxlId());//教学楼ID
                operateLog.setJxlName(x.getJxlName());//教学楼名称
                operateLog.setJsbh(x.getJsbh());//教室编号
                operateLog.setJsmc(x.getJsmc());//教室名称
                operateLog.setOperateType(type);//操作类型（打开还是关闭）
                operateLog.setLogType(2);//日志类型
                operateLog.setOperateResultType("0");//调用成功还是失败

                KcZhihuijiaoshiMonitorLog mnitorLog = new KcZhihuijiaoshiMonitorLog();
                mnitorLog.setJxlId(x.getJxlId());//教学楼ID
                mnitorLog.setJxlName(x.getJxlName());//教学楼名称
                mnitorLog.setJsbh(x.getJsbh());//教室编号
                mnitorLog.setJsmc(x.getJsmc());//教室名称
//                mnitorLog.setHh(x.get)
                //访问。汇总结果
                //http://${ip}/cgi-bin/plat.cgi?action=9&user=${user}&pwsd=${getMd5Str(pwd)}&command=1
                String hex = Convert.toHex("live_setParam_enable=" + type, CharsetUtil.CHARSET_UTF_8);
                String buildUrl = UrlBuilder.create()
                        .setScheme("http")
                        .setHost(x.getIp())
                        .addPath("/cgi-bin")
                        .addPath("/plat.cgi")
                        .addQuery("action", "9")
                        .addQuery("user", x.getUser())
                        .addQuery("pwsd", SecureUtil.md5(x.getMima()))
                        .addQuery("command", "1")
                        .addQuery("data", hex)
                        .build();
                log.info("访问奥威亚接口地址"+buildUrl);
                Map<String,String> rm = Maps.newHashMap();
                resultList.add(rm);
                rm.put("xm",x.getXm());
                rm.put("jsmc",x.getJsmc());
                rm.put("url",buildUrl);
                operateLog.setOperateUrl(buildUrl);//操作URL
                mnitorLog.setLogType(2);//默认调用成功失败
                try{
                    String resText = HttpUtil.get(buildUrl);
                    log.info("奥威亚返回接口内容：" + resText);//live_setParam_ret=ok
                    rm.put("resText",resText);
                    operateLog.setOperateResult(resText);
                    mnitorLog.setLogType(2);//调用成功
//                    res.setResult(rm);
                } catch (Exception e){
                    log.error(e.getMessage(),e);
                    rm.put("resText",e.getMessage());
                    operateLog.setOperateResultType("1");
                    operateLog.setOperateResult(e.getMessage());
                    mnitorLog.setLogType(3);//调用失败
//                    res.setResult(rm);
                }finally {
                    kcZhihuijiaoshiOperateLogService.save(operateLog);
                    //保存操作详细日志
                    kcZhihuijiaoshiMonitorLogService.save(mnitorLog);
                }
                //解析，决定最后返回结果
            });
        }else{
            return Result.ok("操作失败");
        }
        //URL url = new URL("www.hutool.cn")
        return res;
    }

    @AutoLog(value = "对外部访问接口-通过jsbh访问奥威亚接口")
    @ApiOperation(value="对外部访问接口-通过jsbh访问奥威亚接口", notes="对外部访问接口-通过jsbh访问奥威亚接口")
    @GetMapping(value = "/runAvyApiByJsbhs")
    public Result<?> runAvyApiByJsbhs(String jsbhs,String type){
        Result<List<Map<String,String>>> res = Result.OK("操作成功");
        List<Map<String,String>> resultList = Lists.newArrayList();
        res.setResult(resultList);
        if(StringUtils.isNotBlank(jsbhs)){
            List<String> jsbhList = Arrays.asList(jsbhs.split(","));
            QueryWrapper<KcZhihuijiaoshi> qw = new QueryWrapper<>();
            qw.in("jsbh",jsbhList);
            qw.eq("xm","教师近景");
            List<KcZhihuijiaoshi> list = kcZhihuijiaoshiService.list(qw);

            list.forEach(x -> {
                KcZhihuijiaoshiOperateLog operateLog = new KcZhihuijiaoshiOperateLog();
                operateLog.setJxlId(x.getJxlId());//教学楼ID
                operateLog.setJxlName(x.getJxlName());//教学楼名称
                operateLog.setJsbh(x.getJsbh());//教室编号
                operateLog.setJsmc(x.getJsmc());//教室名称
                operateLog.setOperateType(type);//操作类型（打开还是关闭）
                operateLog.setLogType(2);//日志类型
                operateLog.setOperateResultType("0");//调用成功还是失败

                KcZhihuijiaoshiMonitorLog mnitorLog = new KcZhihuijiaoshiMonitorLog();
                mnitorLog.setJxlId(x.getJxlId());//教学楼ID
                mnitorLog.setJxlName(x.getJxlName());//教学楼名称
                mnitorLog.setJsbh(x.getJsbh());//教室编号
                mnitorLog.setJsmc(x.getJsmc());//教室名称

                //访问。汇总结果
                //http://${ip}/cgi-bin/plat.cgi?action=9&user=${user}&pwsd=${getMd5Str(pwd)}&command=1
                String hex = Convert.toHex("live_setParam_enable=" + type, CharsetUtil.CHARSET_UTF_8);
                String buildUrl = UrlBuilder.create()
                        .setScheme("http")
                        .setHost(x.getIp())
                        .addPath("/cgi-bin")
                        .addPath("/plat.cgi")
                        .addQuery("action", "9")
                        .addQuery("user", x.getUser())
                        .addQuery("pwsd", SecureUtil.md5(x.getMima()))
                        .addQuery("command", "1")
                        .addQuery("data", hex)
                        .build();
                log.info("访问奥威亚接口地址"+buildUrl);
                Map<String,String> rm = Maps.newHashMap();
                resultList.add(rm);
                rm.put("xm",x.getXm());
                rm.put("jsmc",x.getJsmc());
                rm.put("url",buildUrl);
                operateLog.setOperateUrl(buildUrl);//操作URL
                mnitorLog.setLogType(2);//默认调用成功失败
                try{
                    String resText = HttpUtil.get(buildUrl);
                    log.info("奥威亚返回接口内容：" + resText);//live_setParam_ret=ok
                    rm.put("resText",resText);
                    operateLog.setOperateResult(resText);
                    mnitorLog.setLogType(2);//调用成功
//                    res.setResult(rm);
                } catch (Exception e){
                    log.error(e.getMessage(),e);
                    rm.put("resText",e.getMessage());
                    operateLog.setOperateResultType("1");
                    operateLog.setOperateResult(e.getMessage());
                    mnitorLog.setLogType(3);//调用失败
//                    res.setResult(rm);
                }finally {
                    kcZhihuijiaoshiOperateLogService.save(operateLog);
                    //保存操作详细日志
                    kcZhihuijiaoshiMonitorLogService.save(mnitorLog);
                }
                //解析，决定最后返回结果
            });
        }else{
            return Result.ok("操作失败");
        }
        //URL url = new URL("www.hutool.cn")
        return res;
    }
    public static void main(String[] args) {
        String hex = Convert.toHex("live_setParam_enable=1", CharsetUtil.CHARSET_UTF_8);//开始
        //String hex = Convert.toHex("live_setParam_enable=0", CharsetUtil.CHARSET_UTF_8);//停止
        String ip = "10.68.100.46";
        String user = "admin";
        String pwd = "admin";
        String buildUrl = UrlBuilder.create()
                .setScheme("http")
                .setHost(ip)
                .addPath("/cgi-bin")
                .addPath("/plat.cgi")
                .addQuery("action", "9")
                .addQuery("user", user)
                .addQuery("pwsd", SecureUtil.md5(pwd))
                .addQuery("command", "1")
                .addQuery("data", hex)
                .build();
//        String res = HttpUtil.get("http://live555.com/liveMedia/#config-windows");
        log.info(buildUrl);
        String res = HttpUtil.get("http://localhost:8090/jeecg-boot/sys/getLoginQrcode?action=9&command=1&user=admin&pwsd=21232f297a57a5a743894a0e4a801fc3&data=6c6976655f736574506172616d5f656e61626c653d30");
        log.info("奥威亚返回接口内容：" + res);
    }
}
