package org.jeecg.modules.kc.blTeacherMain.controller;

import java.io.UnsupportedEncodingException;
import java.io.IOException;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.jeecg.modules.kc.jiaoshi.export.Export;
import org.jeecg.modules.tools.word.ExportWord;
import org.jeecg.modules.tools.word.WordOperator;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.vo.LoginUser;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.blTeacherMain.entity.BlTeacherTjfx;
import org.jeecg.modules.kc.blTeacherMain.entity.BlTeacherMain;
import org.jeecg.modules.kc.blTeacherMain.vo.BlTeacherMainPage;
import org.jeecg.modules.kc.blTeacherMain.service.IBlTeacherMainService;
import org.jeecg.modules.kc.blTeacherMain.service.IBlTeacherTjfxService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;


 /**
 * @Description: 教师调查问卷
 * @Author: jeecg-boot
 * @Date:   2024-06-07
 * @Version: V1.0
 */
@Api(tags="教师调查问卷")
@RestController
@RequestMapping("/blTeacherMain/blTeacherMain")
@Slf4j
public class BlTeacherMainController {
	@Autowired
	private IBlTeacherMainService blTeacherMainService;
	@Autowired
	private IBlTeacherTjfxService blTeacherTjfxService;
	
	/**
	 * 分页列表查询
	 *
	 * @param blTeacherMain
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "教师调查问卷-分页列表查询")
	@ApiOperation(value="教师调查问卷-分页列表查询", notes="教师调查问卷-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<BlTeacherMain>> queryPageList(BlTeacherMain blTeacherMain,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<BlTeacherMain> queryWrapper = QueryGenerator.initQueryWrapper(blTeacherMain, req.getParameterMap());
		Page<BlTeacherMain> page = new Page<BlTeacherMain>(pageNo, pageSize);
		IPage<BlTeacherMain> pageList = blTeacherMainService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param blTeacherMainPage
	 * @return
	 */
	@AutoLog(value = "教师调查问卷-添加")
	@ApiOperation(value="教师调查问卷-添加", notes="教师调查问卷-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody BlTeacherMainPage blTeacherMainPage) {
		BlTeacherMain blTeacherMain = new BlTeacherMain();
		BeanUtils.copyProperties(blTeacherMainPage, blTeacherMain);
		blTeacherMainService.saveMain(blTeacherMain, blTeacherMainPage.getBlTeacherTjfxList());
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param blTeacherMainPage
	 * @return
	 */
	@AutoLog(value = "教师调查问卷-编辑")
	@ApiOperation(value="教师调查问卷-编辑", notes="教师调查问卷-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody BlTeacherMainPage blTeacherMainPage) {
		BlTeacherMain blTeacherMain = new BlTeacherMain();
		BeanUtils.copyProperties(blTeacherMainPage, blTeacherMain);
		BlTeacherMain blTeacherMainEntity = blTeacherMainService.getById(blTeacherMain.getId());
		if(blTeacherMainEntity==null) {
			return Result.error("未找到对应数据");
		}
		blTeacherMainService.updateMain(blTeacherMain, blTeacherMainPage.getBlTeacherTjfxList());
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "教师调查问卷-通过id删除")
	@ApiOperation(value="教师调查问卷-通过id删除", notes="教师调查问卷-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		blTeacherMainService.delMain(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "教师调查问卷-批量删除")
	@ApiOperation(value="教师调查问卷-批量删除", notes="教师调查问卷-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.blTeacherMainService.delBatchMain(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "教师调查问卷-通过id查询")
	@ApiOperation(value="教师调查问卷-通过id查询", notes="教师调查问卷-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<BlTeacherMain> queryById(@RequestParam(name="id",required=true) String id) {
		BlTeacherMain blTeacherMain = blTeacherMainService.getById(id);
		if(blTeacherMain==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(blTeacherMain);

	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "问卷信息通过主表ID查询")
	@ApiOperation(value="问卷信息主表ID查询", notes="问卷信息-通主表ID查询")
	@GetMapping(value = "/queryBlTeacherTjfxByMainId")
	public Result<List<BlTeacherTjfx>> queryBlTeacherTjfxListByMainId(@RequestParam(name="id",required=true) String id) {
		List<BlTeacherTjfx> blTeacherTjfxList = blTeacherTjfxService.selectByMainId(id);
		return Result.OK(blTeacherTjfxList);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param blTeacherMain
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, BlTeacherMain blTeacherMain) {
      // Step.1 组装查询条件查询数据
      QueryWrapper<BlTeacherMain> queryWrapper = QueryGenerator.initQueryWrapper(blTeacherMain, request.getParameterMap());
      LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

      //配置选中数据查询条件
      String selections = request.getParameter("selections");
      if(oConvertUtils.isNotEmpty(selections)) {
         List<String> selectionList = Arrays.asList(selections.split(","));
         queryWrapper.in("id",selectionList);
      }
      //Step.2 获取导出数据
      List<BlTeacherMain> blTeacherMainList = blTeacherMainService.list(queryWrapper);

      // Step.3 组装pageList
      List<BlTeacherMainPage> pageList = new ArrayList<BlTeacherMainPage>();
      for (BlTeacherMain main : blTeacherMainList) {
          BlTeacherMainPage vo = new BlTeacherMainPage();
          BeanUtils.copyProperties(main, vo);
          List<BlTeacherTjfx> blTeacherTjfxList = blTeacherTjfxService.selectByMainId(main.getId());
          vo.setBlTeacherTjfxList(blTeacherTjfxList);
          pageList.add(vo);
      }

      // Step.4 AutoPoi 导出Excel
      ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
      mv.addObject(NormalExcelConstants.FILE_NAME, "教师调查问卷列表");
      mv.addObject(NormalExcelConstants.CLASS, BlTeacherMainPage.class);
      mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("教师调查问卷数据", "导出人:"+sysUser.getRealname(), "教师调查问卷"));
      mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
      return mv;
    }

    /**
    * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
      MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
      Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
      for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
          // 获取上传文件对象
          MultipartFile file = entity.getValue();
          ImportParams params = new ImportParams();
          params.setTitleRows(2);
          params.setHeadRows(1);
          params.setNeedSave(true);
          try {
              List<BlTeacherMainPage> list = ExcelImportUtil.importExcel(file.getInputStream(), BlTeacherMainPage.class, params);
              for (BlTeacherMainPage page : list) {
                  BlTeacherMain po = new BlTeacherMain();
                  BeanUtils.copyProperties(page, po);
                  blTeacherMainService.saveMain(po, page.getBlTeacherTjfxList());
              }
              return Result.OK("文件导入成功！数据行数:" + list.size());
          } catch (Exception e) {
              log.error(e.getMessage(),e);
              return Result.error("文件导入失败:"+e.getMessage());
          } finally {
              try {
                  file.getInputStream().close();
              } catch (IOException e) {
                  e.printStackTrace();
              }
          }
      }
      return Result.OK("文件导入失败！");
    }



	 @AutoLog(value = "教师调查问卷生成统计分析报表")
	 @ApiOperation(value="教师调查问卷生成统计分析报表", notes="教师调查问卷生成统计分析报表")
	 @GetMapping(value = "/createWordTjfx")
	 public void createWordTjfx(@RequestParam(name="id",required=true) String id,HttpServletRequest request, HttpServletResponse response) throws Exception {
//		 Export export = new Export();
		 WordOperator wo = blTeacherMainService.createWordTjfx(id);
		 ExportWord.download_word(request, response, "file.doc", wo);
//		 BlTeacherMain blTeacherMain = blTeacherMainService.createWordTjfx(id);
//		 return Result.OK(null);
	 }

}
