package org.jeecg.modules.kc.blTeacherMain.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import org.jeecg.common.util.SpringContextHolder;
import org.jeecg.modules.kc.blTeacherMain.entity.BlTeacherMain;
import org.jeecg.modules.kc.blTeacherMain.entity.BlTeacherTjfx;
import org.jeecg.modules.kc.blTeacherMain.mapper.BlTeacherTjfxMapper;
import org.jeecg.modules.kc.blTeacherMain.mapper.BlTeacherMainMapper;
import org.jeecg.modules.kc.blTeacherMain.service.IBlTeacherMainService;
import org.jeecg.modules.tools.DateUtils;
import org.jeecg.modules.tools.Global;
import org.jeecg.modules.tools.word.ExportWord;
import org.jeecg.modules.tools.word.WordOperator;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartUtils;
import org.jfree.chart.JFreeChart;
import org.jfree.data.category.DefaultCategoryDataset;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.Serializable;
import java.util.*;

/**
 * @Description: 教师调查问卷
 * @Author: jeecg-boot
 * @Date:   2024-06-07
 * @Version: V1.0
 */
@Service
public class BlTeacherMainServiceImpl extends ServiceImpl<BlTeacherMainMapper, BlTeacherMain> implements IBlTeacherMainService {

	@Autowired
	private BlTeacherMainMapper blTeacherMainMapper;
	@Autowired
	private BlTeacherTjfxMapper blTeacherTjfxMapper;
	
	@Override
	@Transactional(rollbackFor = Exception.class)
	public void saveMain(BlTeacherMain blTeacherMain, List<BlTeacherTjfx> blTeacherTjfxList) {
		blTeacherMainMapper.insert(blTeacherMain);
		if(blTeacherTjfxList!=null && blTeacherTjfxList.size()>0) {
			for(BlTeacherTjfx entity:blTeacherTjfxList) {
				//外键设置
				entity.setMainId(blTeacherMain.getId());
				blTeacherTjfxMapper.insert(entity);
			}
		}
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void updateMain(BlTeacherMain blTeacherMain,List<BlTeacherTjfx> blTeacherTjfxList) {
		blTeacherMainMapper.updateById(blTeacherMain);
		
		//1.先删除子表数据
		blTeacherTjfxMapper.deleteByMainId(blTeacherMain.getId());
		
		//2.子表数据重新插入
		if(blTeacherTjfxList!=null && blTeacherTjfxList.size()>0) {
			for(BlTeacherTjfx entity:blTeacherTjfxList) {
				//外键设置
				entity.setMainId(blTeacherMain.getId());
				blTeacherTjfxMapper.insert(entity);
			}
		}
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void delMain(String id) {
		blTeacherTjfxMapper.deleteByMainId(id);
		blTeacherMainMapper.deleteById(id);
	}

	@Override
	@Transactional(rollbackFor = Exception.class)
	public void delBatchMain(Collection<? extends Serializable> idList) {
		for(Serializable id:idList) {
			blTeacherTjfxMapper.deleteByMainId(id.toString());
			blTeacherMainMapper.deleteById(id);
		}
	}

	@Override
	public WordOperator createWordTjfx(String id) throws Exception {
		String templateName = "exp1\\teacher-tjfx.docx";

		WordOperator wo = ExportWord.getWordOperator(templateName);

//		QueryWrapper<BlTeacherTjfx> queryWrapper = new QueryWrapper<>();
//		queryWrapper.eq("main_id",id);
//		queryWrapper.last("limit 10");
//		List<BlTeacherTjfx> dataList = blTeacherTjfxMapper.selectList(queryWrapper);

		BlTeacherMain blTeacherMain = baseMapper.selectById(id);
		Random random = new Random();
		Map<String, Object> result = Maps.newHashMap();
		Map<String, Object> result2 = Maps.newHashMap();
		result.put("title", blTeacherMain.getTitle());
		result.put("nan", random.nextInt(900) + 100+"");//男占比
		result.put("nan_zb", random.nextInt(900) + 10+"");//女占比
		result.put("nv", random.nextInt(900) + 100+"");//女
		result.put("nv_zb", random.nextInt(900) + 10+"");//女占比
		result.put("xlccjg1", random.nextInt(900) + 100+"");//研究生
		result.put("xlccjg2", random.nextInt(900) + 100+"");//研究生
		result.put("xlccjg3", random.nextInt(900) + 100+"");//研究生
		result.put("xlccjg1_zb", random.nextInt(900) + 10+"");//研究生
		result.put("xlccjg2_zb", random.nextInt(900) + 10+"");//研究生
		result.put("xlccjg3_zb", random.nextInt(900) + 10+"");//研究生

		result.put("zcjg1", random.nextInt(900) + 100+"");//教学科研型
		result.put("zcjg2", random.nextInt(900) + 100+"");//教学科研型
		result.put("zcjg3", random.nextInt(900) + 100+"");//教学科研型
		result.put("zcjg4", random.nextInt(900) + 100+"");//教学科研型
		result.put("zcjg1_zb", random.nextInt(900) + 10+"");//教学科研型
		result.put("zcjg2_zb", random.nextInt(900) + 10+"");//教学科研型
		result.put("zcjg3_zb", random.nextInt(900) + 10+"");//教学科研型
		result.put("zcjg4_zb", random.nextInt(900) + 10+"");//教学科研型

		result.put("gwlxjg1", random.nextInt(900) + 100+"");//教学科研型
		result.put("gwlxjg2", random.nextInt(900) + 100+"");//教学科研型
		result.put("gwlxjg3", random.nextInt(900) + 100+"");//教学科研型
		result.put("gwlxjg4", random.nextInt(900) + 100+"");//教学科研型
		result.put("gwlxjg1_zb", random.nextInt(900) + 10+"");//教学科研型
		result.put("gwlxjg2_zb", random.nextInt(900) + 10+"");//教学科研型
		result.put("gwlxjg3_zb", random.nextInt(900) + 10+"");//教学科研型
		result.put("gwlxjg4_zb", random.nextInt(900) + 10+"");//教学科研型

		result.put("xyjg1", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg2", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg3", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg4", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg5", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg6", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg7", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg8", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg9", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg10", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg11", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg12", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg13", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg14", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg15", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg16", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg17", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg18", random.nextInt(900) + 100+"");//学院结构
		result.put("xyjg1_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg2_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg3_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg4_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg5_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg6_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg7_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg8_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg9_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg10_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg11_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg12_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg13_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg14_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg15_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg16_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg17_zb", random.nextInt(900) + 10+"");//学院结构
		result.put("xyjg18_zb", random.nextInt(900) + 10+"");//学院结构


		// 创建数据集
		DefaultCategoryDataset dataset = new DefaultCategoryDataset();
		dataset.addValue(random.nextInt(900) + 10, "tjfx", "tjfx1");
		dataset.addValue(random.nextInt(900) + 10, "tjfx", "tjfx2");
		dataset.addValue(random.nextInt(900) + 10, "tjfx", "tjfx3");

		// 创建图表
		JFreeChart chart = ChartFactory.createBarChart(
				"", // 图表标题
				"",       // 类别轴标签
				"",           // 数值轴标签
				dataset            // 数据集
		);

		Global global = SpringContextHolder.getBean(Global.class);
		String imgName = DateUtils.format(new Date(),"yyyyMMddHHmmss")+".png";
		String imgPath1 = global.uploadPath + "/tjfxChart/"+ imgName;
		// 保存图表到本地
		File file = new File(imgPath1);
		ChartUtils.saveChartAsPNG(file, chart, 400, 300); // 设置图片大小为400x300

		result.put("imgPath1", "tjfxChart/"+imgName);//学院结构

		wo.replaceTextPlus(result);

		List<List<String>> oneList = Lists.newArrayList();
		List<List<String>> twoList = Lists.newArrayList();
		//-------拼装list--------------
			List<String> list = Lists.newArrayList();
			list.add("依法依规，履行教师职责");
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			oneList.add(list);
			list = Lists.newArrayList();
			list.add("关心爱护学生");
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			oneList.add(list);
			list = Lists.newArrayList();
			list.add("精神面貌及品德修养良好");
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			list.add(String.format("%.2f", (double) random.nextInt(10)));
			oneList.add(list);

			List<String> list2 = Lists.newArrayList();
			list2.add("依法依规，履行教师职责");
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			twoList.add(list2);
			list2 = Lists.newArrayList();
			list2.add("关心爱护学生");
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			twoList.add(list2);
			list2 = Lists.newArrayList();
			list2.add("精神面貌及品德修养良好");
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			list2.add(String.format("%.2f", (double) random.nextInt(10)));
			twoList.add(list2);
		wo.insert2Table(1, 1, true, oneList);
		wo.insert2Table(2, 1, true, twoList);


		wo = WordOperator.twoReplaceWord(wo);
		wo.replaceTextPlus(result2);
		return wo;
	}

}
