package org.jeecg.modules.kc.blZycc.controller;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson.JSONObject;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.SpringContextUtils;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.blZycc.entity.BlZycc;
import org.jeecg.modules.kc.blZycc.service.IBlZyccService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.tools.AuthService;
import org.jeecg.modules.tools.Global;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: bl_zycc
 * @Author: jeecg-boot
 * @Date:   2024-04-13
 * @Version: V1.0
 */
@Api(tags="bl_zycc")
@RestController
@RequestMapping("/blZycc/blZycc")
@Slf4j
public class BlZyccController extends JeecgController<BlZycc, IBlZyccService> {
	@Autowired
	private IBlZyccService blZyccService;
	@Autowired
	private AuthService authService;

	 private static String uploadpath;

	 @Value("${jeecg.path.upload}")
	 public void setUploadPath(String uploadPath) {
		 this.uploadpath = uploadPath;
	 }
//	 private static AuthService authService = SpringContextUtils.getBean(AuthService.class);
	/**
	 * 分页列表查询
	 *
	 * @param blZycc
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "bl_zycc-分页列表查询")
	@ApiOperation(value="bl_zycc-分页列表查询", notes="bl_zycc-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<BlZycc>> queryPageList(BlZycc blZycc,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<BlZycc> queryWrapper = QueryGenerator.initQueryWrapper(blZycc, req.getParameterMap());
		Page<BlZycc> page = new Page<BlZycc>(pageNo, pageSize);
		IPage<BlZycc> pageList = blZyccService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param blZycc
	 * @return
	 */
	@AutoLog(value = "bl_zycc-添加")
	@ApiOperation(value="bl_zycc-添加", notes="bl_zycc-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody BlZycc blZycc) {
		blZyccService.save(blZycc);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param blZycc
	 * @return
	 */
	@AutoLog(value = "bl_zycc-编辑")
	@ApiOperation(value="bl_zycc-编辑", notes="bl_zycc-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody BlZycc blZycc) {
		blZyccService.updateById(blZycc);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "bl_zycc-通过id删除")
	@ApiOperation(value="bl_zycc-通过id删除", notes="bl_zycc-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		blZyccService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "bl_zycc-批量删除")
	@ApiOperation(value="bl_zycc-批量删除", notes="bl_zycc-批量删除")
	@RequiresPermissions("blZycc:bl_zycc:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.blZyccService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "bl_zycc-通过id查询")
	@ApiOperation(value="bl_zycc-通过id查询", notes="bl_zycc-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<BlZycc> queryById(@RequestParam(name="id",required=true) String id) {
		BlZycc blZycc = blZyccService.getById(id);
		if(blZycc==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(blZycc);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param blZycc
    */
    @RequiresPermissions("blZycc:bl_zycc:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, BlZycc blZycc) {
        return super.exportXls(request, blZycc, BlZycc.class, "bl_zycc");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("blZycc:bl_zycc:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, BlZycc.class);
    }


	 @AutoLog(value = "维普外网上传")
	 @ApiOperation(value="维普外网上传", notes="维普外网上传")
	 @PostMapping(value = "/zyccUpload")
	 public Result<BlZycc> zyccUpload(@RequestBody BlZycc blZycc) {
		 BlZycc blZyccPar =blZyccService.zyccUpload(blZycc);
		 return Result.OK(blZyccPar);
	 }

	 @AutoLog(value = "维普外网开始检测")
	 @ApiOperation(value="维普外网开始检测", notes="维普外网开始检测")
	 @PostMapping(value = "/wwKsjc")
	 public Result<String> wwKsjc(@RequestBody BlZycc blZycc) {
		 blZyccService.wwKsjc(blZycc);
		 return Result.OK("添加成功！");
	 }

	 @AutoLog(value = "维普外网检测结果")
	 @ApiOperation(value="维普外网检测结果", notes="维普外网检测结果")
	 @PostMapping(value = "/wwCxjcjg")
	 public Result<Map<String,String>> wwCxjcjg(@RequestBody BlZycc blZycc) {
		 Map<String,String> map = blZyccService.wwCxjcjg(blZycc);
		 return Result.OK(map);
	 }



	 @AutoLog(value = "小范围比对上传")
	 @ApiOperation(value="小范围比对上传", notes="小范围比对上传")
	 @PostMapping(value = "/xfwbdUpload")
	 public Result<BlZycc> xfwbdUpload(@RequestBody BlZycc blZycc) {
		 blZycc.setPaperid(blZycc.getXnpaperid());
		 blZycc.setFilePath(blZycc.getXnfilePath());
		 BlZycc blZyccPar = blZyccService.xfwbdUpload(blZycc);
		 return Result.OK(blZyccPar);
	 }

	 @AutoLog(value = "小范围比对开始检测")
	 @ApiOperation(value="小范围比对开始检测", notes="小范围比对开始检测")
	 @PostMapping(value = "/xfwbdKsjc")
	 public Result<String> xfwbdKsjc(@RequestBody BlZycc blZycc) {
		 blZyccService.xfwbdKsjc(blZycc);
		 return Result.OK("添加成功！");
	 }

	 @AutoLog(value = "小范围比对查询检测结果")
	 @ApiOperation(value="小范围比对查询检测结果", notes="小范围比对查询检测结果")
	 @PostMapping(value = "/xfwbdCxjcjg")
	 public Result<Map<String,String>> xfwbdCxjcjg(@RequestBody BlZycc blZycc) {
		 blZycc.setPaperid(blZycc.getXnpaperid());
		 Map<String,String> map = blZyccService.xfwbdCxjcjg(blZycc);
		 return Result.OK(map);
	 }






	 @AutoLog(value = "维普aigc上传")
	 @ApiOperation(value="维普aigc上传", notes="维普aigc上传")
	 @PostMapping(value = "/aigcUpload")
	 public Result<BlZycc> aigcUpload(@RequestBody BlZycc blZycc) {
		 blZycc.setPaperid(blZycc.getAigcpaperid());
		 blZycc.setFilePath(blZycc.getAigcfilePath());
		 BlZycc blZyccPar = blZyccService.aigcUpload(blZycc);
		 return Result.OK(blZyccPar);
	 }

	 @AutoLog(value = "AIGC开始检测")
	 @ApiOperation(value="AIGC开始检测", notes="AIGC开始检测")
	 @PostMapping(value = "/aigcKsjc")
	 public Result<String> aigcKsjc(@RequestBody BlZycc blZycc) {
		 blZyccService.aigcKsjc(blZycc);
		 return Result.OK("添加成功！");
	 }

	 @AutoLog(value = "AIGC获取检测结果")
	 @ApiOperation(value="AIGC获取检测结果", notes="AIGC获取检测结果")
	 @PostMapping(value = "/aigcCxjcjg")
	 public Result<Map<String,String>> aigcCxjcjg(@RequestBody BlZycc blZycc) {
		 blZycc.setPaperid(blZycc.getAigcpaperid());
		 Map<String,String> map = blZyccService.aigcCxjcjg(blZycc);
		 return Result.OK(map);
	 }



	 @AutoLog(value = "获取图片比对人数接口")
	 @ApiOperation(value="获取图片比对人数接口", notes="获取图片比对人数接口")
	 @PostMapping(value = "/getPicPerno")
	 public Result<Map<String,String>> getPicPerno(@RequestBody BlZycc blZycc) {
		 Map<String,String> map = new HashMap<>();
//		 String sign = authService.getAuth();
//		 System.out.println("sign:--->"+sign);
		 String filePath = uploadpath+"/"+blZycc.getFacefilePath();
		 String ret = authService.faceDetect(filePath);
		 JSONObject object= JSONObject.parseObject(ret);
		 JSONObject object2= JSONObject.parseObject(object.get("result").toString());
		 map.put("facenum",object2.getString("face_num"));
		 return Result.OK(map);
	 }


	 @AutoLog(value = "获取图片比对人数接口")
	 @ApiOperation(value="获取图片比对人数接口", notes="获取图片比对人数接口")
	 @PostMapping(value = "/getRlltj")
	 public Result<Map<String,String>> getRlltj(@RequestBody BlZycc blZycc) {
		 Map<String,String> map = new HashMap<>();
//		 String sign = authService.getAuth();
//		 System.out.println("sign:--->"+sign);
		 String filePath = uploadpath+"/"+blZycc.getRllfilePath();
		 String ret = authService.body_num(filePath);
		 map.put("ret--->",ret);
		 JSONObject object= JSONObject.parseObject(ret);
//		 JSONObject object2= JSONObject.parseObject(object.get("result").toString());
		 map.put("personnum",object.getString("person_num"));
		 return Result.OK(map);
	 }

}
