package org.jeecg.modules.kc.detection.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.beust.jcommander.internal.Sets;
import com.google.common.collect.Maps;
import org.apache.commons.compress.utils.Lists;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.detection.entity.KcDetectionDetailed;
import org.jeecg.modules.kc.detection.entity.KcDetectionMain;
import org.jeecg.modules.kc.detection.service.IKcDetectionDetailedService;
import org.jeecg.modules.kc.detection.service.IKcDetectionMainService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.kc.grab.imports.entity.Xxhbuser;
import org.jeecg.modules.kc.grab.imports.service.IXxhbuserService;
import org.jeecg.modules.kc.ktgl.entity.KcKetangbiao;
import org.jeecg.modules.system.service.impl.SysBaseApiImpl;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 教室人数检测-主表
 * @Author: jeecg-boot
 * @Date:   2024-05-07
 * @Version: V1.0
 */
@Api(tags="教室人数检测-主表")
@RestController
@RequestMapping("/detection/kcDetectionMain")
@Slf4j
public class KcDetectionMainController extends JeecgController<KcDetectionMain, IKcDetectionMainService> {
	@Autowired
	private IKcDetectionMainService kcDetectionMainService;

	@Autowired
	private IKcDetectionDetailedService kcDetectionDetailedService;

	 @Autowired
	 private SysBaseApiImpl sysBaseApi;
	 @Autowired
	 private IXxhbuserService xxhbuserService;
	 /**
	 * 分页列表查询
	 *
	 * @param kcDetectionMain
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "教室人数检测-主表-分页列表查询")
	@ApiOperation(value="教室人数检测-主表-分页列表查询", notes="教室人数检测-主表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcDetectionMain>> queryPageList(KcDetectionMain kcDetectionMain,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcDetectionMain> queryWrapper = QueryGenerator.initQueryWrapper(kcDetectionMain, req.getParameterMap());
		//补充搜索
		if(StringUtils.isNotBlank(kcDetectionMain.getSearchSkrq())){
			//线上数据库不支持
			//queryWrapper.eq("JSON_VALUE(ketangbiao_info,'$.skrq')", kcDetectionMain.getSearchSkrq());
			queryWrapper.eq("ketangbiao_info ->'$.skrq'", kcDetectionMain.getSearchSkrq());
		}
		if(StringUtils.isNotBlank(kcDetectionMain.getSearchHh())){
			queryWrapper.eq("ketangbiao_info -> '$.hh'", kcDetectionMain.getSearchHh());
		}

//		if(StringUtils.isNotBlank(kcDetectionMain.getSearchHh())){
//			queryWrapper.eq("ketangbiao_info -> '$.hh'", kcDetectionMain.getSearchHh());
//		}

		if(StringUtils.isNotBlank(kcDetectionMain.getSkjs())){
			queryWrapper.like("ketangbiao_info -> '$.skjs'", kcDetectionMain.getSkjs());
		}
		Page<KcDetectionMain> page = new Page<>(pageNo, pageSize);
		IPage<KcDetectionMain> pageList = kcDetectionMainService.page(page, queryWrapper);
		//补充查询子列表
		if(kcDetectionMain.getIsSelectKcDetailed() != null && kcDetectionMain.getIsSelectKcDetailed()){
			Set<String> pidSet = Sets.newHashSet();
			Map<String, KcDetectionMain> detectionMainMap = Maps.newHashMap();
			pageList.getRecords().forEach(x -> {
				pidSet.add(x.getId());
				detectionMainMap.put(x.getId(),x);
				x.setDetectionDetailedList(Lists.newArrayList());
				if(x.getKetangbiaoInfo() == null){
					x.setKetangbiaoInfo(new KcKetangbiao());
				}
		}	);
			if(!pidSet.isEmpty()){
				QueryWrapper<KcDetectionDetailed> qw = new QueryWrapper<>();
				qw.lambda().in(KcDetectionDetailed::getPid,pidSet);
//				qw.orderByAsc("detection_num");
				qw.orderByAsc("create_time");
				List<KcDetectionDetailed> detailedList = kcDetectionDetailedService.list(qw);
				detailedList.forEach(x -> {
					if(detectionMainMap.containsKey(x.getPid())){
						KcDetectionMain pData = detectionMainMap.get(x.getPid());
						pData.getDetectionDetailedList().add(x);
					}
				});
			}
		}

		List<KcDetectionMain> alist = pageList.getRecords();
		for(KcDetectionMain par: alist){
			List<KcDetectionDetailed> blist = par.getDetectionDetailedList();
			int anum = 0;//第一次抓取人数
			int bnum = 0;//第二次抓取人数
			int cnum = 0;//第三次抓取人数
			if(blist.size()>=2){
				for(int i=0;i<blist.size();i++){
					KcDetectionDetailed bpar = blist.get(i);
					if(i==0){
						anum = bpar.getNum();
					}else if (i==1){
						bnum = bpar.getNum();
					}else if (i==2){
						cnum = bpar.getNum();
					}
				}
			}
			if(bnum!=0){
				if(anum!=0){
					if(bnum-anum<0){
						par.setCdrs("0");
					}else{
						par.setCdrs(String.valueOf(bnum-anum));
					}
				}else{
					par.setCdrs("0");
				}
				if(cnum!=0){
					if(bnum-cnum<0){
						par.setZtrs("0");
					}else{
						par.setZtrs(String.valueOf(bnum-cnum));
					}
				}else{
					par.setZtrs("0");
				}
			}else{
				par.setCdrs("0");
				par.setZtrs("0");
			}
		}


		return Result.OK(pageList);
	}





	 @GetMapping(value = "/syslist")
	 public Result<IPage<KcDetectionMain>> syslist(KcDetectionMain kcDetectionMain,
														 @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
														 @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
														 HttpServletRequest req) {
		 QueryWrapper<KcDetectionMain> queryWrapper = QueryGenerator.initQueryWrapper(kcDetectionMain, req.getParameterMap());

		 LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
		 List<String> roleList = sysBaseApi.getRolesByUsername(sysUser.getUsername());
		 String adminRole = "1";//0 admin  1教务秘书
		 for(String role :roleList){
			 if(org.apache.commons.lang.StringUtils.equals("admin",role)){
				 adminRole = "0";
				 break;
			 }
		 }
		 if(org.apache.commons.lang.StringUtils.equals("1",adminRole)){
			 QueryWrapper<Xxhbuser> uqw = new QueryWrapper<>();
			 uqw.eq("gh",sysUser.getUsername());
			 uqw.last("limit 1");
			 Xxhbuser xxhbUser = xxhbuserService.getOne(uqw);
			 if(xxhbUser == null) {
				 return Result.OK(new Page<>());
			 }
			 queryWrapper.eq("ketangbiao_info ->'$.kkdw'",xxhbUser.getDwmc());
		 }


		 //补充搜索
		 if(StringUtils.isNotBlank(kcDetectionMain.getSearchSkrq())){
			 //线上数据库不支持
			 //queryWrapper.eq("JSON_VALUE(ketangbiao_info,'$.skrq')", kcDetectionMain.getSearchSkrq());
			 queryWrapper.eq("ketangbiao_info ->'$.skrq'", kcDetectionMain.getSearchSkrq());
		 }
		 if(StringUtils.isNotBlank(kcDetectionMain.getSearchHh())){
			 queryWrapper.eq("ketangbiao_info -> '$.hh'", kcDetectionMain.getSearchHh());
		 }

//		if(StringUtils.isNotBlank(kcDetectionMain.getSearchHh())){
//			queryWrapper.eq("ketangbiao_info -> '$.hh'", kcDetectionMain.getSearchHh());
//		}

		 if(StringUtils.isNotBlank(kcDetectionMain.getSkjs())){
			 queryWrapper.like("ketangbiao_info -> '$.skjs'", kcDetectionMain.getSkjs());
		 }
		 Page<KcDetectionMain> page = new Page<>(pageNo, pageSize);
		 IPage<KcDetectionMain> pageList = kcDetectionMainService.page(page, queryWrapper);
		 //补充查询子列表
		 if(kcDetectionMain.getIsSelectKcDetailed() != null && kcDetectionMain.getIsSelectKcDetailed()){
			 Set<String> pidSet = Sets.newHashSet();
			 Map<String, KcDetectionMain> detectionMainMap = Maps.newHashMap();
			 pageList.getRecords().forEach(x -> {
				 pidSet.add(x.getId());
				 detectionMainMap.put(x.getId(),x);
				 x.setDetectionDetailedList(Lists.newArrayList());
				 if(x.getKetangbiaoInfo() == null){
					 x.setKetangbiaoInfo(new KcKetangbiao());
				 }
			 }	);
			 if(!pidSet.isEmpty()){
				 QueryWrapper<KcDetectionDetailed> qw = new QueryWrapper<>();
				 qw.lambda().in(KcDetectionDetailed::getPid,pidSet);
//				qw.orderByAsc("detection_num");
				 qw.orderByAsc("create_time");
				 List<KcDetectionDetailed> detailedList = kcDetectionDetailedService.list(qw);
				 detailedList.forEach(x -> {
					 if(detectionMainMap.containsKey(x.getPid())){
						 KcDetectionMain pData = detectionMainMap.get(x.getPid());
						 pData.getDetectionDetailedList().add(x);
					 }
				 });
			 }
		 }

		 List<KcDetectionMain> alist = pageList.getRecords();
		 for(KcDetectionMain par: alist){
			 List<KcDetectionDetailed> blist = par.getDetectionDetailedList();
			 int anum = 0;//第一次抓取人数
			 int bnum = 0;//第二次抓取人数
			 int cnum = 0;//第三次抓取人数
			 if(blist.size()>=2){
				 for(int i=0;i<blist.size();i++){
					 KcDetectionDetailed bpar = blist.get(i);
					 if(i==0){
						 anum = bpar.getNum();
					 }else if (i==1){
						 bnum = bpar.getNum();
					 }else if (i==2){
						 cnum = bpar.getNum();
					 }
				 }
			 }
			 if(bnum!=0){
				 if(anum!=0){
					 if(bnum-anum<0){
						 par.setCdrs("0");
					 }else{
						 par.setCdrs(String.valueOf(bnum-anum));
					 }
				 }else{
					 par.setCdrs("0");
				 }
				 if(cnum!=0){
					 if(bnum-cnum<0){
						 par.setZtrs("0");
					 }else{
						 par.setZtrs(String.valueOf(bnum-cnum));
					 }
				 }else{
					 par.setZtrs("0");
				 }
			 }else{
				 par.setCdrs("0");
				 par.setZtrs("0");
			 }
		 }


		 return Result.OK(pageList);
	 }
	
//	/**
//	 *   添加
//	 *
//	 * @param kcDetectionMain
//	 * @return
//	 */
//	@AutoLog(value = "教室人数检测-主表-添加")
//	@ApiOperation(value="教室人数检测-主表-添加", notes="教室人数检测-主表-添加")
//	@RequiresPermissions("detection:kc_detection_main:add")
//	@PostMapping(value = "/add")
//	public Result<String> add(@RequestBody KcDetectionMain kcDetectionMain) {
//		kcDetectionMainService.save(kcDetectionMain);
//		return Result.OK("添加成功！");
//	}
//
//	/**
//	 *  编辑
//	 *
//	 * @param kcDetectionMain
//	 * @return
//	 */
//	@AutoLog(value = "教室人数检测-主表-编辑")
//	@ApiOperation(value="教室人数检测-主表-编辑", notes="教室人数检测-主表-编辑")
//	@RequiresPermissions("detection:kc_detection_main:edit")
//	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
//	public Result<String> edit(@RequestBody KcDetectionMain kcDetectionMain) {
//		kcDetectionMainService.updateById(kcDetectionMain);
//		return Result.OK("编辑成功!");
//	}
//
//	/**
//	 *   通过id删除
//	 *
//	 * @param id
//	 * @return
//	 */
//	@AutoLog(value = "教室人数检测-主表-通过id删除")
//	@ApiOperation(value="教室人数检测-主表-通过id删除", notes="教室人数检测-主表-通过id删除")
//	@RequiresPermissions("detection:kc_detection_main:delete")
//	@DeleteMapping(value = "/delete")
//	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
//		kcDetectionMainService.removeById(id);
//		return Result.OK("删除成功!");
//	}
//
//	/**
//	 *  批量删除
//	 *
//	 * @param ids
//	 * @return
//	 */
//	@AutoLog(value = "教室人数检测-主表-批量删除")
//	@ApiOperation(value="教室人数检测-主表-批量删除", notes="教室人数检测-主表-批量删除")
//	@RequiresPermissions("detection:kc_detection_main:deleteBatch")
//	@DeleteMapping(value = "/deleteBatch")
//	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
//		this.kcDetectionMainService.removeByIds(Arrays.asList(ids.split(",")));
//		return Result.OK("批量删除成功!");
//	}
//
//	/**
//	 * 通过id查询
//	 *
//	 * @param id
//	 * @return
//	 */
//	//@AutoLog(value = "教室人数检测-主表-通过id查询")
//	@ApiOperation(value="教室人数检测-主表-通过id查询", notes="教室人数检测-主表-通过id查询")
//	@GetMapping(value = "/queryById")
//	public Result<KcDetectionMain> queryById(@RequestParam(name="id",required=true) String id) {
//		KcDetectionMain kcDetectionMain = kcDetectionMainService.getById(id);
//		if(kcDetectionMain==null) {
//			return Result.error("未找到对应数据");
//		}
//		return Result.OK(kcDetectionMain);
//	}
//
    /**
    * 导出excel
    *
    * @param request
    * @param kcDetectionMain
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcDetectionMain kcDetectionMain) {
        return exportXls(request, kcDetectionMain, KcDetectionMain.class, "教室人数检测-主表");
    }

	 protected ModelAndView exportXls(HttpServletRequest request, KcDetectionMain kcDetectionMain, Class<KcDetectionMain> clazz, String title) {
		 // Step.1 组装查询条件
		 QueryWrapper<KcDetectionMain> queryWrapper = QueryGenerator.initQueryWrapper(kcDetectionMain, request.getParameterMap());
		 LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

		 List<String> roleList = sysBaseApi.getRolesByUsername(sysUser.getUsername());
		 String adminRole = "1";//0 admin  1教务秘书
		 for(String role :roleList){
			 if(org.apache.commons.lang.StringUtils.equals("admin",role)){
				 adminRole = "0";
				 break;
			 }
		 }
		 if(org.apache.commons.lang.StringUtils.equals("1",adminRole)){
			 QueryWrapper<Xxhbuser> uqw = new QueryWrapper<>();
			 uqw.eq("gh",sysUser.getUsername());
			 uqw.last("limit 1");
			 Xxhbuser xxhbUser = xxhbuserService.getOne(uqw);
			 queryWrapper.eq("ketangbiao_info ->'$.kkdw'",xxhbUser.getDwmc());
		 }


		 //补充搜索
		 if(StringUtils.isNotBlank(kcDetectionMain.getSearchSkrq())){
			 //线上数据库不支持
			 //queryWrapper.eq("JSON_VALUE(ketangbiao_info,'$.skrq')", kcDetectionMain.getSearchSkrq());
			 queryWrapper.eq("ketangbiao_info ->'$.skrq'", kcDetectionMain.getSearchSkrq());
		 }
		 if(StringUtils.isNotBlank(kcDetectionMain.getSearchHh())){
			 queryWrapper.eq("ketangbiao_info -> '$.hh'", kcDetectionMain.getSearchHh());
		 }

//		if(StringUtils.isNotBlank(kcDetectionMain.getSearchHh())){
//			queryWrapper.eq("ketangbiao_info -> '$.hh'", kcDetectionMain.getSearchHh());
//		}

		 if(StringUtils.isNotBlank(kcDetectionMain.getSkjs())){
			 queryWrapper.like("ketangbiao_info -> '$.skjs'", kcDetectionMain.getSkjs());
		 }
		 List<KcDetectionMain> pageList = kcDetectionMainService.list( queryWrapper);
		 //补充查询子列表
		 if(kcDetectionMain.getIsSelectKcDetailed() != null && kcDetectionMain.getIsSelectKcDetailed()){
			 Set<String> pidSet = Sets.newHashSet();
			 Map<String, KcDetectionMain> detectionMainMap = Maps.newHashMap();
			 pageList.forEach(x -> {
				 pidSet.add(x.getId());
				 detectionMainMap.put(x.getId(),x);
				 x.setDetectionDetailedList(Lists.newArrayList());
				 if(x.getKetangbiaoInfo() == null){
					 x.setKetangbiaoInfo(new KcKetangbiao());
				 }
			 }	);
			 if(!pidSet.isEmpty()){
				 QueryWrapper<KcDetectionDetailed> qw = new QueryWrapper<>();
				 qw.lambda().in(KcDetectionDetailed::getPid,pidSet);
//				qw.orderByAsc("detection_num");
				 qw.orderByAsc("create_time");
				 List<KcDetectionDetailed> detailedList = kcDetectionDetailedService.list(qw);
				 detailedList.forEach(x -> {
					 if(detectionMainMap.containsKey(x.getPid())){
						 KcDetectionMain pData = detectionMainMap.get(x.getPid());
						 pData.getDetectionDetailedList().add(x);
					 }
				 });
			 }
		 }

		 List<KcDetectionMain> alist = pageList;
		 for(KcDetectionMain par: alist){
			 par.setSkjs(par.getKetangbiaoInfo().getSkjs());
			 par.setSkrq(par.getKetangbiaoInfo().getSkrq());
			 par.setKkdw(par.getKetangbiaoInfo().getKkdw());
			 par.setSkjc(par.getKetangbiaoInfo().getHh());;
			 par.setXkrs(par.getKetangbiaoInfo().getXkrs());
			 Double xkrs = 0.0;
			 if(StringUtils.isNotBlank(par.getXkrs())){
				 xkrs = Double.parseDouble(par.getXkrs());
			 }
			 Double pjsNum = Double.parseDouble(par.getAverageNum()+"");
			 String cql = "";
			 if(xkrs!=0 && pjsNum!=0){
				 cql = String.format("%.1f",(pjsNum / xkrs) * 100) + "%";
			 }

			 par.setCql(cql);

		 }


		 // Step.3 AutoPoi 导出Excel
		 ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
		 //此处设置的filename无效 ,前端会重更新设置一下
		 mv.addObject(NormalExcelConstants.FILE_NAME, title);
		 mv.addObject(NormalExcelConstants.CLASS, clazz);
		 //update-begin--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置--------------------
		 ExportParams  exportParams=new ExportParams(title + "报表", "导出人:" + sysUser.getRealname(), title);
		 //update-end--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置----------------------
		 mv.addObject(NormalExcelConstants.PARAMS,exportParams);
		 mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
		 return mv;
	 }
//
//    /**
//      * 通过excel导入数据
//    *
//    * @param request
//    * @param response
//    * @return
//    */
//    @RequiresPermissions("detection:kc_detection_main:importExcel")
//    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
//    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
//        return super.importExcel(request, response, KcDetectionMain.class);
//    }

}
