package org.jeecg.modules.kc.detection.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.io.FileUtil;
import cn.hutool.core.thread.ThreadUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.beust.jcommander.internal.Sets;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.util.SFTPUtil;
import org.jeecg.common.util.SftpConfig;
import org.jeecg.modules.kc.detection.entity.KcDetectionDetailed;
import org.jeecg.modules.kc.detection.entity.KcDetectionMain;
import org.jeecg.modules.kc.detection.mapper.KcDetectionDetailedMapper;
import org.jeecg.modules.kc.detection.service.IKcDetectionDetailedService;
import org.jeecg.modules.kc.detection.service.IKcDetectionMainService;
import org.jeecg.modules.kc.jiaoshi.entity.KcZhihuijiaoshi;
import org.jeecg.modules.kc.jiaoshi.service.IKcZhihuijiaoshiService;
import org.jeecg.modules.kc.kcJieci.entity.KcJieci;
import org.jeecg.modules.kc.kcJieci.service.IKcJieciService;
import org.jeecg.modules.kc.ktgl.entity.KcKetangbiao;
import org.jeecg.modules.kc.ktgl.service.IKcKetangbiaoService;
import org.jeecg.modules.tools.*;
import org.jeecg.modules.tools.ffmpeg.FFmpegTools;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.File;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.Callable;
import java.util.concurrent.CompletionService;
import java.util.concurrent.Executors;

/**
 * @Description: 教室人数检测-详细表
 * @Author: jeecg-boot
 * @Date:   2024-05-07
 * @Version: V1.0
 */
@Slf4j
@Service
public class KcDetectionDetailedServiceImpl extends ServiceImpl<KcDetectionDetailedMapper, KcDetectionDetailed> implements IKcDetectionDetailedService {

	@Resource
	private IKcDetectionMainService kcDetectionMainService;

	@Resource
	private IKcZhihuijiaoshiService zhihuijiaoshiService;

	@Resource
	private AuthService authService;

	@Resource
	private FFmpegTools _FFmpegTools;

	@Resource
	private IKcKetangbiaoService kcKetangbiaoService;

	@Resource
	private IKcJieciService jieciService;

	@Autowired
	private Global global;

	@Autowired
	SftpConfig sftpConfig;

	@Value(value = "${jeecg.path.upload}")
	private String uploadpath;

	@Value(value = "${jeecg.path.webapp}")
	private String downloadpath;

	@Override
	public void videoScreenshotAll() {
		DateTime now = DateTime.now();
		String nowStr = now.toString("yyyy-MM-dd");

		String yearMonthStr = now.toString("yyyy-MM");

		CompletionService<Boolean> threadService = ThreadUtil.newCompletionService(Executors.newFixedThreadPool(2));

		List<Callable<Boolean>> calls = Lists.newArrayList();

		log.info("----------抓取图片开始--------------");

		//新版，查询当前是否有课
		KcZhihuijiaoshi jiaoshi = new KcZhihuijiaoshi();
		jiaoshi.setXm("学生全景");
		jiaoshi.setChangshang("奥威亚");
		QueryWrapper<KcZhihuijiaoshi> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("xm","学生全景");
		queryWrapper.eq("changshang","奥威亚");

		String hh = "";
		KcJieci kcJieci = new KcJieci();
		List<KcJieci> kcJieciList = jieciService.getIndexJcList(kcJieci);
		log.info("----------kcJieciList--------------{}",kcJieciList);
		if(kcJieciList != null && !kcJieciList.isEmpty()){
			KcJieci kcJieciParam = kcJieciList.get(0);
			String[] jcArray = StringUtils.split(kcJieciParam.getJieci(),"、");

			hh = kcJieciParam.getJieci() + "," + String.join(",", jcArray);
		}


		log.info("----------hh--------------{}",hh);
		KcKetangbiao kcKetangbiao = new KcKetangbiao();
		kcKetangbiao.setSfyzhjs("1");
		kcKetangbiao.setHh(hh);
		kcKetangbiao.setSkrq(nowStr);
//		kcKetangbiao.setSkrq("2024-06-14");
		kcKetangbiao.setSkxs(1);
		kcKetangbiao.setSbType("1");
		kcKetangbiao.setSftkb("1");
		kcKetangbiao.setYwskxs("");
		log.info("----------kcKetangbiao--------------{}",kcKetangbiao);
		if(StringUtils.equals(",", hh)){
			log.error("未查到节次，原因未知！");
			return;
		}

		Page<KcKetangbiao> page = new Page<>(1, -1);
		IPage<KcKetangbiao> pageList = kcKetangbiaoService.getKclblist(page, kcKetangbiao);

		log.info("----------pageList--------------{},{}",pageList.getRecords().size(),pageList.getRecords());
		if(pageList != null){
			List<KcKetangbiao> list = pageList.getRecords();
			Set<String> jsbhSet = Sets.newHashSet();
			Map<String, KcKetangbiao> KcKetangbiaoMap = Maps.newHashMap();
			list.forEach(x -> {
				KcKetangbiaoMap.put(x.getJsbh(), x);
				jsbhSet.add(x.getJsbh());
			});
			log.info("----------jsbhSet--------------{}",jsbhSet);
			if(jsbhSet.isEmpty()){
				log.error("未找到对应的可线上听课课堂");
				return;
			}
			//取智慧教室信息
			//id: item.jsbh, ktId: item.id
			QueryWrapper<KcZhihuijiaoshi> zhjsQW = new QueryWrapper<>();
			zhjsQW.lambda().eq(KcZhihuijiaoshi::getXm,"学生全景");
			zhjsQW.lambda().eq(KcZhihuijiaoshi::getChangshang,"奥威亚");
			zhjsQW.lambda().in(KcZhihuijiaoshi::getJsbh, jsbhSet);

			List<KcZhihuijiaoshi> zhihuijiaoshiList = zhihuijiaoshiService.list(zhjsQW);

			log.info("----------zhihuijiaoshiList--------------{}",zhihuijiaoshiList);
			zhihuijiaoshiList.forEach(x -> {
				try {
					Thread.sleep(1000L);
				} catch (InterruptedException e) {
					e.printStackTrace();
				}
				KcKetangbiao ketangbiao = KcKetangbiaoMap.get(x.getJsbh());
				String rwbh = ketangbiao.getRwbh();

				String fileName;
				File uploadpathFile = new File(uploadpath);
				String uploadpathFilePath = uploadpathFile.getPath();

				File file = new File(uploadpathFilePath + File.separator + "temp" + File.separator + "videoScreenshot" + File.separator + ketangbiao.getXnxq() + File.separator + yearMonthStr + File.separator + x.getJsbh() + File.separator);
				File fileBak = new File(downloadpath + File.separator + "temp" + File.separator + "videoScreenshot" + File.separator + ketangbiao.getXnxq() + File.separator + yearMonthStr + File.separator + x.getJsbh() + File.separator);
				String orgName = x.getPullUrl();// 获取文件名
				orgName = CommonUtil.getFileName(orgName);
				if(orgName.lastIndexOf(".")!=-1){
					//qn更改-- 修复特殊字符上传后无法下载的问题，修复多个.名称错乱的问题
					orgName = URLEncoder.DEFAULT.encode(orgName);
					//原名是m3u8，不是图片，改成jpeg
//					fileName = orgName.substring(0, orgName.lastIndexOf(".")) + "_" + DateUtils.getTradeNo() + orgName.substring(orgName.lastIndexOf("."));
					fileName = DateUtils.getTradeNo()  + "_" + orgName.substring(0, orgName.lastIndexOf(".")) + ".jpeg";
				}else{
//					fileName = x.getRw"_" + orgName+ "_" + DateUtils.getTradeNo();
					fileName = DateUtils.getTradeNo()  + "_" + orgName;
				}
				fileName = rwbh + "_" + fileName;
				//qn更改-- 修复特殊字符上传后无法下载的问题，修复多个.名称错乱的问题END
				//截图
				String outImagePath = file.getPath() + File.separator + fileName;
				log.info("----------outImagePath--------------{}",outImagePath);
				FileUtil.touch(outImagePath);
				String miniOutImagePath = StringUtils.replace(outImagePath, uploadpathFilePath + File.separator, "");
				miniOutImagePath = StringUtils.replace(miniOutImagePath,"\\","/");
				log.info("----------x.getPullUrl()--------------{}",x.getPullUrl());
				boolean isSuccess = _FFmpegTools.videoScreenshot(x.getPullUrl(), outImagePath);

				log.info("----------isSuccess--------------{}",isSuccess);
				FileUtil.copy(outImagePath,fileBak.getPath() + File.separator + fileName, true);
				if(isSuccess){

					//转存文件到ftp
					//miniOutImagePath
//					if(StringUtils.equals(CommonConstant.UPLOAD_TYPE_SFTP, global.uploadType)){
//						//miniOutImagePath =
//						int index = miniOutImagePath.lastIndexOf("/");
//						String outImagePathDir = miniOutImagePath.substring(0,index);
//						String outImagePathName = miniOutImagePath.substring(index+1);
//						String finalFileName = fileName;
//						calls.add(() -> {
//							log.info("sftpConfig: {}, outImagePathDir:{}, outImagePath:{}, outImagePathName:{}",sftpConfig, outImagePathDir, outImagePath, outImagePathName);
//							Map<String, String> res = SFTPUtil.upload(sftpConfig, false, outImagePathDir, outImagePath, outImagePathName );
//							log.info("res: {}",res);
//							if(!StringUtils.equals(res.get("code"),"0")){
//								log.error("上传文件出现错误：{}", res.get("msg"));
//							}
//							return true;
//						});
//					}

				}
				//查找主表，
				QueryWrapper<KcDetectionMain> detectionMainQw = new QueryWrapper<>();

				detectionMainQw.apply("create_time >= '" + nowStr + " 00:00:00' and create_time <= '" + nowStr + " 23:59:59'");
				detectionMainQw.lambda().eq(KcDetectionMain::getRwbh, ketangbiao.getRwbh());
				detectionMainQw.last("limit 1");
				KcDetectionMain detectionMain = kcDetectionMainService.getOne(detectionMainQw);
				if(detectionMain == null) {
					detectionMain = new KcDetectionMain();
					detectionMain.setRwbh(ketangbiao.getRwbh());
					detectionMain.setKcbh(ketangbiao.getKcbh());
					detectionMain.setKcmc(ketangbiao.getKcmc());
					detectionMain.setJsbh(x.getJsbh());
					detectionMain.setXnxq(ketangbiao.getXnxq());
					detectionMain.setDetectionUrl(x.getPullUrl());
					detectionMain.setDetectionNum(0);
					detectionMain.setAllNum(0);
					detectionMain.setAverageNum(0);
				}
				Integer detectionNum = detectionMain.getDetectionNum();
				detectionNum++;
				detectionMain.setDetectionNum(detectionNum);
				detectionMain.setKetangbiaoInfo(ketangbiao);

				KcDetectionDetailed detectionDetailed = new KcDetectionDetailed();
				detectionDetailed.setRwbh(ketangbiao.getRwbh());
				detectionDetailed.setKcbh(ketangbiao.getKcbh());
				detectionDetailed.setKcmc(ketangbiao.getKcmc());
				detectionDetailed.setJsbh(x.getJsbh());
				detectionDetailed.setXnxq(ketangbiao.getXnxq());
				detectionDetailed.setDetectionUrl(x.getPullUrl());
				detectionDetailed.setDetectionOutImgUrl(miniOutImagePath);
				detectionDetailed.setDetectionOutImgRes("{\"log_id\": \"没有图片，无法查询\", \"person_num\": 0}");//
				detectionDetailed.setDetectionNum(detectionNum);//截图序列号
				detectionDetailed.setNum(0);

				//取数量
				if(isSuccess){
					String rJson = authService.body_num(outImagePath);
					log.info("----------rJson--------------{}",rJson);
					detectionDetailed.setDetectionOutImgRes(rJson);
					//解析获取数
					JSONObject object= JSON.parseObject(rJson);

					log.info("----------百度-object--------------{}",object);
					if(object != null){
						Integer num = object.getInteger("person_num");
						if(num == null){
							if(detectionDetailed.getNum() == null){
								detectionDetailed.setNum(0);
							}
						} else {
							detectionDetailed.setNum(num);
						}
						Integer allNum = detectionMain.getAllNum();
						allNum += detectionDetailed.getNum();
						detectionMain.setAllNum(allNum);
						detectionMain.setAverageNum(allNum/detectionNum);
						log.info("----------detectionMain--------------{}",detectionMain);
						//保存主表
						if(StringUtils.isBlank(detectionMain.getId())){
							kcDetectionMainService.save(detectionMain);
						} else {
							kcDetectionMainService.updateById(detectionMain);
						}
						detectionDetailed.setPid(detectionMain.getId());
						log.info("----------detectionDetailed--------------{}",detectionDetailed);
						//保存子表
						save(detectionDetailed);
					}
				}

			});

			calls.forEach(threadService::submit);
			calls.forEach(fn -> {
				try {
					threadService.take();
				} catch (InterruptedException e) {
					throw new RuntimeException(e);
				}
			});
			log.info("----------抓取图片结束--------------");
		}
	}

	@Override
	public void videoScreenshotByJsbh(String jsbh) {
		DateTime now = DateTime.now();
		String nowStr = now.toString("yyyy-MM-dd");

		String yearMonthStr = now.toString("yyyy-MM");

		CompletionService<Boolean> threadService = ThreadUtil.newCompletionService(Executors.newFixedThreadPool(2));

		List<Callable<Boolean>> calls = Lists.newArrayList();

		log.info("------videoScreenshotByJsbh----抓取图片开始--------------");

		//新版，查询当前是否有课
		KcZhihuijiaoshi jiaoshi = new KcZhihuijiaoshi();
		jiaoshi.setXm("学生全景");
		jiaoshi.setChangshang("奥威亚");
		QueryWrapper<KcZhihuijiaoshi> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("xm","学生全景");
		queryWrapper.eq("changshang","奥威亚");

		String hh = "";
		KcJieci kcJieci = new KcJieci();
		List<KcJieci> kcJieciList = jieciService.getIndexJcList(kcJieci);
		log.info("------videoScreenshotByJsbh----kcJieciList--------------{}",kcJieciList);
		if(kcJieciList != null && !kcJieciList.isEmpty()){
			KcJieci kcJieciParam = kcJieciList.get(0);
			String[] jcArray = StringUtils.split(kcJieciParam.getJieci(),"、");

			hh = kcJieciParam.getJieci() + "," + String.join(",", jcArray);
		}


		log.info("-----videoScreenshotByJsbh----hh--------------{}",hh);
		KcKetangbiao kcKetangbiao = new KcKetangbiao();
		kcKetangbiao.setSfyzhjs("1");
		kcKetangbiao.setHh(hh);
		kcKetangbiao.setSkrq(nowStr);
//		kcKetangbiao.setSkrq("2024-06-14");
		kcKetangbiao.setSkxs(1);
		kcKetangbiao.setSbType("1");
		kcKetangbiao.setSftkb("1");
		kcKetangbiao.setYwskxs("");
		log.info("-----videoScreenshotByJsbh-----kcKetangbiao--------------{}",kcKetangbiao);
		if(StringUtils.equals(",", hh)){
			log.error("未查到节次，原因未知！");
			return;
		}

		Page<KcKetangbiao> page = new Page<>(1, -1);
		if(StringUtils.isNotBlank(jsbh)){
			kcKetangbiao.setJsbh(jsbh);
		}
		IPage<KcKetangbiao> pageList = kcKetangbiaoService.getKclblist(page, kcKetangbiao);

		log.info("-----videoScreenshotByJsbh-----pageList--------------{},{}",pageList.getRecords().size(),pageList.getRecords());
		if(pageList != null){
			List<KcKetangbiao> list = pageList.getRecords();
			Set<String> jsbhSet = Sets.newHashSet();
			Map<String, KcKetangbiao> KcKetangbiaoMap = Maps.newHashMap();
			list.forEach(x -> {
				KcKetangbiaoMap.put(x.getJsbh(), x);
				jsbhSet.add(x.getJsbh());
			});
			log.info("-----videoScreenshotByJsbh-----jsbhSet--------------{}",jsbhSet);
			if(jsbhSet.isEmpty()){
				log.error("未找到对应的可线上听课课堂");
				return;
			}
			//取智慧教室信息
			//id: item.jsbh, ktId: item.id
			QueryWrapper<KcZhihuijiaoshi> zhjsQW = new QueryWrapper<>();
			zhjsQW.lambda().eq(KcZhihuijiaoshi::getXm,"学生全景");
			zhjsQW.lambda().eq(KcZhihuijiaoshi::getChangshang,"奥威亚");
			zhjsQW.lambda().in(KcZhihuijiaoshi::getJsbh, jsbhSet);

			List<KcZhihuijiaoshi> zhihuijiaoshiList = zhihuijiaoshiService.list(zhjsQW);

			log.info("---videoScreenshotByJsbh-------zhihuijiaoshiList--------------{}",zhihuijiaoshiList);
			zhihuijiaoshiList.forEach(x -> {
				try {
					Thread.sleep(1000L);
				} catch (InterruptedException e) {
					e.printStackTrace();
				}
				KcKetangbiao ketangbiao = KcKetangbiaoMap.get(x.getJsbh());
				String rwbh = ketangbiao.getRwbh();

				String fileName;
				File uploadpathFile = new File(uploadpath);
				String uploadpathFilePath = uploadpathFile.getPath();

				File file = new File(uploadpathFilePath + File.separator + "temp" + File.separator + "videoScreenshot" + File.separator + ketangbiao.getXnxq() + File.separator + yearMonthStr + File.separator + x.getJsbh() + File.separator);
				File fileBak = new File(downloadpath + File.separator + "temp" + File.separator + "videoScreenshot" + File.separator + ketangbiao.getXnxq() + File.separator + yearMonthStr + File.separator + x.getJsbh() + File.separator);
				String orgName = x.getPullUrl();// 获取文件名
				orgName = CommonUtil.getFileName(orgName);
				if(orgName.lastIndexOf(".")!=-1){
					//qn更改-- 修复特殊字符上传后无法下载的问题，修复多个.名称错乱的问题
					orgName = URLEncoder.DEFAULT.encode(orgName);
					//原名是m3u8，不是图片，改成jpeg
//					fileName = orgName.substring(0, orgName.lastIndexOf(".")) + "_" + DateUtils.getTradeNo() + orgName.substring(orgName.lastIndexOf("."));
					fileName = DateUtils.getTradeNo()  + "_" + orgName.substring(0, orgName.lastIndexOf(".")) + ".jpeg";
				}else{
//					fileName = x.getRw"_" + orgName+ "_" + DateUtils.getTradeNo();
					fileName = DateUtils.getTradeNo()  + "_" + orgName;
				}
				fileName = rwbh + "_" + fileName;
				//qn更改-- 修复特殊字符上传后无法下载的问题，修复多个.名称错乱的问题END
				//截图
				String outImagePath = file.getPath() + File.separator + fileName;
				log.info("------videoScreenshotByJsbh----outImagePath--------------{}",outImagePath);
				FileUtil.touch(outImagePath);
				String miniOutImagePath = StringUtils.replace(outImagePath, uploadpathFilePath + File.separator, "");
				miniOutImagePath = StringUtils.replace(miniOutImagePath,"\\","/");
				log.info("------videoScreenshotByJsbh----x.getPullUrl()--------------{}",x.getPullUrl());
				boolean isSuccess = _FFmpegTools.videoScreenshot(x.getPullUrl(), outImagePath);

				log.info("------videoScreenshotByJsbh----isSuccess--------------{}",isSuccess);
				FileUtil.copy(outImagePath,fileBak.getPath() + File.separator + fileName, true);
				//查找主表，
				QueryWrapper<KcDetectionMain> detectionMainQw = new QueryWrapper<>();

				detectionMainQw.apply("create_time >= '" + nowStr + " 00:00:00' and create_time <= '" + nowStr + " 23:59:59'");
				detectionMainQw.lambda().eq(KcDetectionMain::getRwbh, ketangbiao.getRwbh());
				detectionMainQw.last("limit 1");
				KcDetectionMain detectionMain = kcDetectionMainService.getOne(detectionMainQw);
				if(detectionMain == null) {
					detectionMain = new KcDetectionMain();
					detectionMain.setRwbh(ketangbiao.getRwbh());
					detectionMain.setKcbh(ketangbiao.getKcbh());
					detectionMain.setKcmc(ketangbiao.getKcmc());
					detectionMain.setJsbh(x.getJsbh());
					detectionMain.setXnxq(ketangbiao.getXnxq());
					detectionMain.setDetectionUrl(x.getPullUrl());
					detectionMain.setDetectionNum(0);
					detectionMain.setAllNum(0);
					detectionMain.setAverageNum(0);
				}
				Integer detectionNum = detectionMain.getDetectionNum();
				detectionNum++;
				detectionMain.setDetectionNum(detectionNum);
				detectionMain.setKetangbiaoInfo(ketangbiao);

				KcDetectionDetailed detectionDetailed = new KcDetectionDetailed();
				detectionDetailed.setRwbh(ketangbiao.getRwbh());
				detectionDetailed.setKcbh(ketangbiao.getKcbh());
				detectionDetailed.setKcmc(ketangbiao.getKcmc());
				detectionDetailed.setJsbh(x.getJsbh());
				detectionDetailed.setXnxq(ketangbiao.getXnxq());
				detectionDetailed.setDetectionUrl(x.getPullUrl());
				detectionDetailed.setDetectionOutImgUrl(miniOutImagePath);
				detectionDetailed.setDetectionOutImgRes("{\"log_id\": \"没有图片，无法查询\", \"person_num\": 0}");//
				detectionDetailed.setDetectionNum(detectionNum);//截图序列号
				detectionDetailed.setNum(0);

				//取数量
				if(isSuccess){
					String rJson = authService.body_num(outImagePath);
					log.info("-----videoScreenshotByJsbh-----rJson--------------{}",rJson);
					detectionDetailed.setDetectionOutImgRes(rJson);
					//解析获取数
					JSONObject object= JSON.parseObject(rJson);

					log.info("-----videoScreenshotByJsbh-----百度-object--------------{}",object);
					if(object != null){
						Integer num = object.getInteger("person_num");
						if(num == null){
							if(detectionDetailed.getNum() == null){
								detectionDetailed.setNum(0);
							}
						} else {
							detectionDetailed.setNum(num);
						}
						Integer allNum = detectionMain.getAllNum();
						allNum += detectionDetailed.getNum();
						detectionMain.setAllNum(allNum);
						detectionMain.setAverageNum(allNum/detectionNum);
						log.info("---videoScreenshotByJsbh-------detectionMain--------------{}",detectionMain);
						//保存主表
						if(StringUtils.isBlank(detectionMain.getId())){
							kcDetectionMainService.save(detectionMain);
						} else {
							kcDetectionMainService.updateById(detectionMain);
						}
						detectionDetailed.setPid(detectionMain.getId());
						log.info("----videoScreenshotByJsbh------detectionDetailed--------------{}",detectionDetailed);
						//保存子表
						save(detectionDetailed);
					}
				}

			});

			calls.forEach(threadService::submit);
			calls.forEach(fn -> {
				try {
					threadService.take();
				} catch (InterruptedException e) {
					throw new RuntimeException(e);
				}
			});
			log.info("-----videoScreenshotByJsbh-----抓取图片结束--------------");
		}
	}
}
