package org.jeecg.modules.kc.grab.exports.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.grab.exports.entity.TFwdtShryxx;
import org.jeecg.modules.kc.grab.exports.service.ITFwdtShryxxService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 同步数据表(shryxx)
 * @Author: jeecg-boot
 * @Date:   2023-05-24
 * @Version: V1.0
 */
@Api(tags="同步数据表(shryxx)")
@RestController
@RequestMapping("/grab/xxhbshryxx")
@Slf4j
public class TFwdtShryxxController extends JeecgController<TFwdtShryxx, ITFwdtShryxxService> {
	@Autowired
	private ITFwdtShryxxService xxhbshryxxService;
	
	/**
	 * 分页列表查询
	 *
	 * @param xxhbshryxx
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "同步数据表(shryxx)-分页列表查询")
	@ApiOperation(value="同步数据表(shryxx)-分页列表查询", notes="同步数据表(shryxx)-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TFwdtShryxx>> queryPageList(TFwdtShryxx xxhbshryxx,
													@RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
													@RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
													HttpServletRequest req) {
		QueryWrapper<TFwdtShryxx> queryWrapper = QueryGenerator.initQueryWrapper(xxhbshryxx, req.getParameterMap());
		Page<TFwdtShryxx> page = new Page<TFwdtShryxx>(pageNo, pageSize);
		IPage<TFwdtShryxx> pageList = xxhbshryxxService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param xxhbshryxx
	 * @return
	 */
	@AutoLog(value = "同步数据表(shryxx)-添加")
	@ApiOperation(value="同步数据表(shryxx)-添加", notes="同步数据表(shryxx)-添加")
	@RequiresPermissions("grab:xxhbshryxx:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TFwdtShryxx xxhbshryxx) {
		xxhbshryxxService.save(xxhbshryxx);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param xxhbshryxx
	 * @return
	 */
	@AutoLog(value = "同步数据表(shryxx)-编辑")
	@ApiOperation(value="同步数据表(shryxx)-编辑", notes="同步数据表(shryxx)-编辑")
	@RequiresPermissions("grab:xxhbshryxx:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TFwdtShryxx xxhbshryxx) {
		xxhbshryxxService.updateById(xxhbshryxx);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "同步数据表(shryxx)-通过id删除")
	@ApiOperation(value="同步数据表(shryxx)-通过id删除", notes="同步数据表(shryxx)-通过id删除")
	@RequiresPermissions("grab:xxhbshryxx:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		xxhbshryxxService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "同步数据表(shryxx)-批量删除")
	@ApiOperation(value="同步数据表(shryxx)-批量删除", notes="同步数据表(shryxx)-批量删除")
	@RequiresPermissions("grab:xxhbshryxx:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.xxhbshryxxService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "同步数据表(shryxx)-通过id查询")
	@ApiOperation(value="同步数据表(shryxx)-通过id查询", notes="同步数据表(shryxx)-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TFwdtShryxx> queryById(@RequestParam(name="id",required=true) String id) {
		TFwdtShryxx xxhbshryxx = xxhbshryxxService.getById(id);
		if(xxhbshryxx==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(xxhbshryxx);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param xxhbshryxx
    */
    @RequiresPermissions("grab:xxhbshryxx:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TFwdtShryxx xxhbshryxx) {
        return super.exportXls(request, xxhbshryxx, TFwdtShryxx.class, "同步数据表(shryxx)");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("grab:xxhbshryxx:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TFwdtShryxx.class);
    }

}
