package org.jeecg.modules.kc.grab.exports.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.grab.exports.entity.TJwKcxxb;
import org.jeecg.modules.kc.grab.exports.service.ITJwKcxxbService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: T_JW_KCXXB-抓取
 * @Author: jeecg-boot
 * @Date:   2023-04-11
 * @Version: V1.0
 */
@Slf4j
@Api(tags="T_JW_KCXXB-抓取")
@RestController
@RequestMapping("/grab/tJwKcxxb")
public class TJwKcxxbController extends JeecgController<TJwKcxxb, ITJwKcxxbService> {
	@Autowired
	private ITJwKcxxbService tJwKcxxbService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tJwKcxxb
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "T_JW_KCXXB-抓取-分页列表查询")
	@ApiOperation(value="T_JW_KCXXB-抓取-分页列表查询", notes="T_JW_KCXXB-抓取-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(TJwKcxxb tJwKcxxb,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TJwKcxxb> queryWrapper = QueryGenerator.initQueryWrapper(tJwKcxxb, req.getParameterMap());
		Page<TJwKcxxb> page = new Page<TJwKcxxb>(pageNo, pageSize);
		IPage<TJwKcxxb> pageList = tJwKcxxbService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 * 添加
	 *
	 * @param tJwKcxxb
	 * @return
	 */
	@AutoLog(value = "T_JW_KCXXB-抓取-添加")
	@ApiOperation(value="T_JW_KCXXB-抓取-添加", notes="T_JW_KCXXB-抓取-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody TJwKcxxb tJwKcxxb) {
		tJwKcxxbService.save(tJwKcxxb);
		return Result.OK("添加成功！");
	}
	
	/**
	 * 编辑
	 *
	 * @param tJwKcxxb
	 * @return
	 */
	@AutoLog(value = "T_JW_KCXXB-抓取-编辑")
	@ApiOperation(value="T_JW_KCXXB-抓取-编辑", notes="T_JW_KCXXB-抓取-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<?> edit(@RequestBody TJwKcxxb tJwKcxxb) {
		tJwKcxxbService.updateById(tJwKcxxb);
		return Result.OK("编辑成功!");
	}
	
	/**
	 * 通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "T_JW_KCXXB-抓取-通过id删除")
	@ApiOperation(value="T_JW_KCXXB-抓取-通过id删除", notes="T_JW_KCXXB-抓取-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		tJwKcxxbService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 * 批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "T_JW_KCXXB-抓取-批量删除")
	@ApiOperation(value="T_JW_KCXXB-抓取-批量删除", notes="T_JW_KCXXB-抓取-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tJwKcxxbService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "T_JW_KCXXB-抓取-通过id查询")
	@ApiOperation(value="T_JW_KCXXB-抓取-通过id查询", notes="T_JW_KCXXB-抓取-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		TJwKcxxb tJwKcxxb = tJwKcxxbService.getById(id);
		return Result.OK(tJwKcxxb);
	}

  /**
   * 导出excel
   *
   * @param request
   * @param tJwKcxxb
   */
  @RequestMapping(value = "/exportXls")
  public ModelAndView exportXls(HttpServletRequest request, TJwKcxxb tJwKcxxb) {
      return super.exportXls(request, tJwKcxxb, TJwKcxxb.class, "T_JW_KCXXB-抓取");
  }

  /**
   * 通过excel导入数据
   *
   * @param request
   * @param response
   * @return
   */
  @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
  public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
      return super.importExcel(request, response, TJwKcxxb.class);
  }

}
