package org.jeecg.modules.kc.grab.imports.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.grab.imports.entity.Xxhbbks;
import org.jeecg.modules.kc.grab.imports.service.IXxhbbksService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.List;

/**
 * @Description: 同步数据表（bks）
 * @Author: jeecg-boot
 * @Date: 2023-04-10
 * @Version: V1.0
 */
@Api(tags = "同步数据表（bks）")
@RestController
@RequestMapping("/grab/xxhbbks")
@Slf4j
public class XxhbbksController extends JeecgController<Xxhbbks, IXxhbbksService> {
    @Autowired
    private IXxhbbksService xxhbbksService;

    /**
     * 分页列表查询
     *
     * @param xxhbbks
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "同步数据表（bks）-分页列表查询")
    @ApiOperation(value = "同步数据表（bks）-分页列表查询", notes = "同步数据表（bks）-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<Xxhbbks>> queryPageList(Xxhbbks xxhbbks,
                                                @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                HttpServletRequest req) {
        QueryWrapper<Xxhbbks> queryWrapper = QueryGenerator.initQueryWrapper(xxhbbks, req.getParameterMap());
        Page<Xxhbbks> page = new Page<Xxhbbks>(pageNo, pageSize);
        IPage<Xxhbbks> pageList = xxhbbksService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param xxhbbks
     * @return
     */
    @AutoLog(value = "同步数据表（bks）-添加")
    @ApiOperation(value = "同步数据表（bks）-添加", notes = "同步数据表（bks）-添加")
    @RequiresPermissions("grab:xxhbbks:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody Xxhbbks xxhbbks) {
        xxhbbksService.save(xxhbbks);
        return Result.OK("添加成功！");
    }

    /**
     * 编辑
     *
     * @param xxhbbks
     * @return
     */
    @AutoLog(value = "同步数据表（bks）-编辑")
    @ApiOperation(value = "同步数据表（bks）-编辑", notes = "同步数据表（bks）-编辑")
    @RequiresPermissions("grab:xxhbbks:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody Xxhbbks xxhbbks) {
        xxhbbksService.updateById(xxhbbks);
        return Result.OK("编辑成功!");
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "同步数据表（bks）-通过id删除")
    @ApiOperation(value = "同步数据表（bks）-通过id删除", notes = "同步数据表（bks）-通过id删除")
    @RequiresPermissions("grab:xxhbbks:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        xxhbbksService.removeById(id);
        return Result.OK("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "同步数据表（bks）-批量删除")
    @ApiOperation(value = "同步数据表（bks）-批量删除", notes = "同步数据表（bks）-批量删除")
    @RequiresPermissions("grab:xxhbbks:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.xxhbbksService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK("批量删除成功!");
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "同步数据表（bks）-通过id查询")
    @ApiOperation(value = "同步数据表（bks）-通过id查询", notes = "同步数据表（bks）-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<Xxhbbks> queryById(@RequestParam(name = "id", required = true) String id) {
        Xxhbbks xxhbbks = xxhbbksService.getById(id);
        if (xxhbbks == null) {
            return Result.error("未找到对应数据");
        }
        return Result.OK(xxhbbks);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param xxhbbks
     */
    @RequiresPermissions("grab:xxhbbks:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, Xxhbbks xxhbbks) {
        return super.exportXls(request, xxhbbks, Xxhbbks.class, "同步数据表（bks）");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("grab:xxhbbks:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, Xxhbbks.class);
    }


    @AutoLog(value = "获取本科生选课人员信息")
    @ApiOperation(value = "获取本科生选课人员信息", notes = "获取本科生选课人员信息")
    @GetMapping(value = "/getXsxkbList")
    public Result<?> getXsxkbList(Xxhbbks xxhbbks,
                                  @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                  @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                  HttpServletRequest req) {
        QueryWrapper<Xxhbbks> queryWrapper = QueryGenerator.initQueryWrapper(xxhbbks, req.getParameterMap());
        queryWrapper.apply("a.xh = b.xh");
        queryWrapper.eq(StringUtils.isNotBlank(xxhbbks.getRwbh()), "b.KCAPZBBH", xxhbbks.getRwbh());
        Page<Xxhbbks> page = new Page<Xxhbbks>(pageNo, pageSize);
        IPage<Xxhbbks> pageList = xxhbbksService.getXsxkbList(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 获取选课人员
     * @param rwbh 任务编号
	 *
	 *  获取任务编号下的所有选课人员
     * @return
     */
    @PostMapping(value = "/getXKRY")
    public Result<List<Xxhbbks>> getXKRY(@RequestBody String rwbh) {
        return Result.OK(xxhbbksService.getXKRY(rwbh));
    }
}
