package org.jeecg.modules.kc.grab.imports.controller;

import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.kc.grab.imports.entity.Xxhbuser;
import org.jeecg.modules.kc.grab.imports.service.IXxhbuserService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.modules.system.service.impl.SysBaseApiImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: xxhbuser
 * @Author: jeecg-boot
 * @Date:   2023-06-03
 * @Version: V1.0
 */
@Api(tags="xxhbuser")
@RestController
@RequestMapping("/xxhb/xxhbuser")
@Slf4j
public class XxhbuserController extends JeecgController<Xxhbuser, IXxhbuserService> {
	@Autowired
	private IXxhbuserService xxhbuserService;

	 @Autowired
	 private SysBaseApiImpl sysBaseApi;
	/**
	 * 分页列表查询
	 *
	 * @param xxhbuser
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "xxhbuser-分页列表查询")
	@ApiOperation(value="xxhbuser-分页列表查询", notes="xxhbuser-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<Xxhbuser>> queryPageList(Xxhbuser xxhbuser,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<Xxhbuser> queryWrapper = QueryGenerator.initQueryWrapper(xxhbuser, req.getParameterMap());

		LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
		List<String> roleList = sysBaseApi.getRolesByUsername(sysUser.getUsername());
		String adminRole = "1";//0 admin  1教务秘书
		for(String role :roleList){
			if(StringUtils.equals("admin",role)){
				adminRole = "0";
				break;
			}
		}
		if(StringUtils.equals("1",adminRole)){
			QueryWrapper<Xxhbuser> uqw = new QueryWrapper<>();
			uqw.eq("gh",sysUser.getUsername());
			uqw.last("limit 1");
			Xxhbuser xxhbUser = xxhbuserService.getOne(uqw);
			if(xxhbUser == null) {
				return Result.OK(new Page<>());
			}
			queryWrapper.eq("dwmc ",xxhbUser.getDwmc());
		}

		Page<Xxhbuser> page = new Page<Xxhbuser>(pageNo, pageSize);
		IPage<Xxhbuser> pageList = xxhbuserService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param xxhbuser
	 * @return
	 */
	@AutoLog(value = "xxhbuser-添加")
	@ApiOperation(value="xxhbuser-添加", notes="xxhbuser-添加")
	@RequiresPermissions("xxhb:xxhbuser:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody Xxhbuser xxhbuser) {
		xxhbuserService.save(xxhbuser);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param xxhbuser
	 * @return
	 */
	@AutoLog(value = "xxhbuser-编辑")
	@ApiOperation(value="xxhbuser-编辑", notes="xxhbuser-编辑")
	@RequiresPermissions("xxhb:xxhbuser:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody Xxhbuser xxhbuser) {
		xxhbuserService.updateById(xxhbuser);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "xxhbuser-通过id删除")
	@ApiOperation(value="xxhbuser-通过id删除", notes="xxhbuser-通过id删除")
	@RequiresPermissions("xxhb:xxhbuser:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		xxhbuserService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "xxhbuser-批量删除")
	@ApiOperation(value="xxhbuser-批量删除", notes="xxhbuser-批量删除")
	@RequiresPermissions("xxhb:xxhbuser:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.xxhbuserService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "xxhbuser-通过id查询")
	@ApiOperation(value="xxhbuser-通过id查询", notes="xxhbuser-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<Xxhbuser> queryById(@RequestParam(name="id",required=true) String id) {
		Xxhbuser xxhbuser = xxhbuserService.getById(id);
		if(xxhbuser==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(xxhbuser);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param xxhbuser
    */
    @RequiresPermissions("xxhb:xxhbuser:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, Xxhbuser xxhbuser) {
        return super.exportXls(request, xxhbuser, Xxhbuser.class, "xxhbuser");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("xxhb:xxhbuser:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, Xxhbuser.class);
    }

}
