package org.jeecg.modules.kc.grab.imports.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.grab.imports.entity.Xxhbxskc;
import org.jeecg.modules.kc.grab.imports.service.IXxhbxskcService;
import org.jeecg.modules.kc.zyCyFenxiang.entity.ZyCyFenxiang;
import org.jeecg.modules.kc.zyCyFenxiang.service.IZyCyFenxiangService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.List;

/**
* @Description: 同步数据表（bks）
* @Author: jeecg-boot
* @Date:   2023-04-10
* @Version: V1.0
*/
@Api(tags="同步数据表（bks）")
@RestController
@RequestMapping("/grab/xxhbxskc")
@Slf4j
public class XxhbxskcController extends JeecgController<Xxhbxskc, IXxhbxskcService> {
   @Autowired
   private IXxhbxskcService xxhbxskcService;
    @Autowired
    private IZyCyFenxiangService zyCyFenxiangService;
   /**
    * 分页列表查询
    *
    * @param xxhbxskc
    * @param pageNo
    * @param pageSize
    * @param req
    * @return
    */
   //@AutoLog(value = "同步数据表（bks）-分页列表查询")
   @ApiOperation(value="同步数据表（bks）-分页列表查询", notes="同步数据表（bks）-分页列表查询")
   @GetMapping(value = "/list")
   public Result<IPage<Xxhbxskc>> queryPageList(Xxhbxskc xxhbxskc,
                                  @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
                                  @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
                                  HttpServletRequest req) {
       String mainId = xxhbxskc.getMainId();
       QueryWrapper<Xxhbxskc> queryWrapper = QueryGenerator.initQueryWrapper(xxhbxskc, req.getParameterMap());
       if(StringUtils.isNotBlank(mainId)){
           QueryWrapper<ZyCyFenxiang> zyCyFenxiangQueryWrapper = new QueryWrapper<>();
           zyCyFenxiangQueryWrapper.eq("main_id",mainId);
           List<ZyCyFenxiang> list = zyCyFenxiangService.list(zyCyFenxiangQueryWrapper);
           if(list != null && list.size()>0){
               String arr = "";
               for(ZyCyFenxiang par : list){
                   arr = arr +par.getTeacherNo()+",";
               }
               if(StringUtils.isNotBlank(arr)){
                   arr = arr.substring(0,arr.length()-1);
                   queryWrapper.notIn("gh",arr.split(","));
               }
           }
       }
       Page<Xxhbxskc> page = new Page<Xxhbxskc>(pageNo, pageSize);
       IPage<Xxhbxskc> pageList = xxhbxskcService.page(page, queryWrapper);
       return Result.OK(pageList);
   }
   
   /**
    *   添加
    *
    * @param xxhbxskc
    * @return
    */
   @AutoLog(value = "同步数据表（bks）-添加")
   @ApiOperation(value="同步数据表（bks）-添加", notes="同步数据表（bks）-添加")
   @RequiresPermissions("grab:xxhbxskc:add")
   @PostMapping(value = "/add")
   public Result<String> add(@RequestBody Xxhbxskc xxhbxskc) {
       xxhbxskcService.save(xxhbxskc);
       return Result.OK("添加成功！");
   }
   
   /**
    *  编辑
    *
    * @param xxhbxskc
    * @return
    */
   @AutoLog(value = "同步数据表（bks）-编辑")
   @ApiOperation(value="同步数据表（bks）-编辑", notes="同步数据表（bks）-编辑")
   @RequiresPermissions("grab:xxhbxskc:edit")
   @RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
   public Result<String> edit(@RequestBody Xxhbxskc xxhbxskc) {
       xxhbxskcService.updateById(xxhbxskc);
       return Result.OK("编辑成功!");
   }
   
   /**
    *   通过id删除
    *
    * @param id
    * @return
    */
   @AutoLog(value = "同步数据表（bks）-通过id删除")
   @ApiOperation(value="同步数据表（bks）-通过id删除", notes="同步数据表（bks）-通过id删除")
   @RequiresPermissions("grab:xxhbxskc:delete")
   @DeleteMapping(value = "/delete")
   public Result<String> delete(@RequestParam(name="id",required=true) String id) {
       xxhbxskcService.removeById(id);
       return Result.OK("删除成功!");
   }
   
   /**
    *  批量删除
    *
    * @param ids
    * @return
    */
   @AutoLog(value = "同步数据表（bks）-批量删除")
   @ApiOperation(value="同步数据表（bks）-批量删除", notes="同步数据表（bks）-批量删除")
   @RequiresPermissions("grab:xxhbxskc:deleteBatch")
   @DeleteMapping(value = "/deleteBatch")
   public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
       this.xxhbxskcService.removeByIds(Arrays.asList(ids.split(",")));
       return Result.OK("批量删除成功!");
   }
   
   /**
    * 通过id查询
    *
    * @param id
    * @return
    */
   //@AutoLog(value = "同步数据表（bks）-通过id查询")
   @ApiOperation(value="同步数据表（bks）-通过id查询", notes="同步数据表（bks）-通过id查询")
   @GetMapping(value = "/queryById")
   public Result<Xxhbxskc> queryById(@RequestParam(name="id",required=true) String id) {
       Xxhbxskc xxhbxskc = xxhbxskcService.getById(id);
       if(xxhbxskc==null) {
           return Result.error("未找到对应数据");
       }
       return Result.OK(xxhbxskc);
   }

   /**
   * 导出excel
   *
   * @param request
   * @param xxhbxskc
   */
   @RequiresPermissions("grab:xxhbxskc:exportXls")
   @RequestMapping(value = "/exportXls")
   public ModelAndView exportXls(HttpServletRequest request, Xxhbxskc xxhbxskc) {
       return super.exportXls(request, xxhbxskc, Xxhbxskc.class, "同步数据表（bks）");
   }

   /**
     * 通过excel导入数据
   *
   * @param request
   * @param response
   * @return
   */
   @RequiresPermissions("grab:xxhbxskc:importExcel")
   @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
   public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
       return super.importExcel(request, response, Xxhbxskc.class);
   }


}
