package org.jeecg.modules.kc.grab.log.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.grab.log.entity.KcOldEvaluationansBad;
import org.jeecg.modules.kc.grab.log.service.IKcOldEvaluationansBadService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 老系统同步失败记录
 * @Author: jeecg-boot
 * @Date:   2023-08-13
 * @Version: V1.0
 */
@Api(tags="老系统同步失败记录")
@RestController
@RequestMapping("/grab/kcOldEvaluationansBad")
@Slf4j
public class KcOldEvaluationansBadController extends JeecgController<KcOldEvaluationansBad, IKcOldEvaluationansBadService> {
	@Autowired
	private IKcOldEvaluationansBadService kcOldEvaluationansBadService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcOldEvaluationansBad
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "老系统同步失败记录-分页列表查询")
	@ApiOperation(value="老系统同步失败记录-分页列表查询", notes="老系统同步失败记录-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcOldEvaluationansBad>> queryPageList(KcOldEvaluationansBad kcOldEvaluationansBad,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcOldEvaluationansBad> queryWrapper = QueryGenerator.initQueryWrapper(kcOldEvaluationansBad, req.getParameterMap());
		Page<KcOldEvaluationansBad> page = new Page<KcOldEvaluationansBad>(pageNo, pageSize);
		IPage<KcOldEvaluationansBad> pageList = kcOldEvaluationansBadService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcOldEvaluationansBad
	 * @return
	 */
	@AutoLog(value = "老系统同步失败记录-添加")
	@ApiOperation(value="老系统同步失败记录-添加", notes="老系统同步失败记录-添加")
	@RequiresPermissions("grab:kc_old_evaluationans_bad:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcOldEvaluationansBad kcOldEvaluationansBad) {
		kcOldEvaluationansBadService.save(kcOldEvaluationansBad);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcOldEvaluationansBad
	 * @return
	 */
	@AutoLog(value = "老系统同步失败记录-编辑")
	@ApiOperation(value="老系统同步失败记录-编辑", notes="老系统同步失败记录-编辑")
	@RequiresPermissions("grab:kc_old_evaluationans_bad:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcOldEvaluationansBad kcOldEvaluationansBad) {
		kcOldEvaluationansBadService.updateById(kcOldEvaluationansBad);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "老系统同步失败记录-通过id删除")
	@ApiOperation(value="老系统同步失败记录-通过id删除", notes="老系统同步失败记录-通过id删除")
	@RequiresPermissions("grab:kc_old_evaluationans_bad:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcOldEvaluationansBadService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "老系统同步失败记录-批量删除")
	@ApiOperation(value="老系统同步失败记录-批量删除", notes="老系统同步失败记录-批量删除")
	@RequiresPermissions("grab:kc_old_evaluationans_bad:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcOldEvaluationansBadService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "老系统同步失败记录-通过id查询")
	@ApiOperation(value="老系统同步失败记录-通过id查询", notes="老系统同步失败记录-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcOldEvaluationansBad> queryById(@RequestParam(name="id",required=true) String id) {
		KcOldEvaluationansBad kcOldEvaluationansBad = kcOldEvaluationansBadService.getById(id);
		if(kcOldEvaluationansBad==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcOldEvaluationansBad);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcOldEvaluationansBad
    */
    @RequiresPermissions("grab:kc_old_evaluationans_bad:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcOldEvaluationansBad kcOldEvaluationansBad) {
        return super.exportXls(request, kcOldEvaluationansBad, KcOldEvaluationansBad.class, "老系统同步失败记录");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("grab:kc_old_evaluationans_bad:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcOldEvaluationansBad.class);
    }

}
