package org.jeecg.modules.kc.grab.log.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.grab.log.entity.KcOldEvaluationansGood;
import org.jeecg.modules.kc.grab.log.service.IKcOldEvaluationansGoodService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 老系统同步成功记录
 * @Author: jeecg-boot
 * @Date:   2023-08-13
 * @Version: V1.0
 */
@Api(tags="老系统同步成功记录")
@RestController
@RequestMapping("/grab/kcOldEvaluationansGood")
@Slf4j
public class KcOldEvaluationansGoodController extends JeecgController<KcOldEvaluationansGood, IKcOldEvaluationansGoodService> {
	@Autowired
	private IKcOldEvaluationansGoodService kcOldEvaluationansGoodService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcOldEvaluationansGood
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "老系统同步成功记录-分页列表查询")
	@ApiOperation(value="老系统同步成功记录-分页列表查询", notes="老系统同步成功记录-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcOldEvaluationansGood>> queryPageList(KcOldEvaluationansGood kcOldEvaluationansGood,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcOldEvaluationansGood> queryWrapper = QueryGenerator.initQueryWrapper(kcOldEvaluationansGood, req.getParameterMap());
		Page<KcOldEvaluationansGood> page = new Page<KcOldEvaluationansGood>(pageNo, pageSize);
		IPage<KcOldEvaluationansGood> pageList = kcOldEvaluationansGoodService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcOldEvaluationansGood
	 * @return
	 */
	@AutoLog(value = "老系统同步成功记录-添加")
	@ApiOperation(value="老系统同步成功记录-添加", notes="老系统同步成功记录-添加")
	@RequiresPermissions("grab:kc_old_evaluationans_good:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcOldEvaluationansGood kcOldEvaluationansGood) {
		kcOldEvaluationansGoodService.save(kcOldEvaluationansGood);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcOldEvaluationansGood
	 * @return
	 */
	@AutoLog(value = "老系统同步成功记录-编辑")
	@ApiOperation(value="老系统同步成功记录-编辑", notes="老系统同步成功记录-编辑")
	@RequiresPermissions("grab:kc_old_evaluationans_good:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcOldEvaluationansGood kcOldEvaluationansGood) {
		kcOldEvaluationansGoodService.updateById(kcOldEvaluationansGood);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "老系统同步成功记录-通过id删除")
	@ApiOperation(value="老系统同步成功记录-通过id删除", notes="老系统同步成功记录-通过id删除")
	@RequiresPermissions("grab:kc_old_evaluationans_good:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcOldEvaluationansGoodService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "老系统同步成功记录-批量删除")
	@ApiOperation(value="老系统同步成功记录-批量删除", notes="老系统同步成功记录-批量删除")
	@RequiresPermissions("grab:kc_old_evaluationans_good:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcOldEvaluationansGoodService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "老系统同步成功记录-通过id查询")
	@ApiOperation(value="老系统同步成功记录-通过id查询", notes="老系统同步成功记录-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcOldEvaluationansGood> queryById(@RequestParam(name="id",required=true) String id) {
		KcOldEvaluationansGood kcOldEvaluationansGood = kcOldEvaluationansGoodService.getById(id);
		if(kcOldEvaluationansGood==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcOldEvaluationansGood);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcOldEvaluationansGood
    */
    @RequiresPermissions("grab:kc_old_evaluationans_good:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcOldEvaluationansGood kcOldEvaluationansGood) {
        return super.exportXls(request, kcOldEvaluationansGood, KcOldEvaluationansGood.class, "老系统同步成功记录");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("grab:kc_old_evaluationans_good:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcOldEvaluationansGood.class);
    }

}
