package org.jeecg.modules.kc.jiaoshi.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.jiaoshi.entity.KcJiaoxuelouInfo;
import org.jeecg.modules.kc.jiaoshi.service.IKcJiaoxuelouInfoService;
import java.util.Date;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

 /**
 * @Description: 教学楼信息
 * @Author: jeecg-boot
 * @Date:   2023-10-17
 * @Version: V1.0
 */
@Slf4j
@Api(tags="教学楼信息")
@RestController
@RequestMapping("/jiaoshi/kcJiaoxuelouInfo")
public class KcJiaoxuelouInfoController extends JeecgController<KcJiaoxuelouInfo, IKcJiaoxuelouInfoService> {
	@Autowired
	private IKcJiaoxuelouInfoService kcJiaoxuelouInfoService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcJiaoxuelouInfo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "教学楼信息-分页列表查询")
	@ApiOperation(value="教学楼信息-分页列表查询", notes="教学楼信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(KcJiaoxuelouInfo kcJiaoxuelouInfo,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcJiaoxuelouInfo> queryWrapper = QueryGenerator.initQueryWrapper(kcJiaoxuelouInfo, req.getParameterMap());
		Page<KcJiaoxuelouInfo> page = new Page<KcJiaoxuelouInfo>(pageNo, pageSize);
		IPage<KcJiaoxuelouInfo> pageList = kcJiaoxuelouInfoService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 * 添加
	 *
	 * @param kcJiaoxuelouInfo
	 * @return
	 */
	@AutoLog(value = "教学楼信息-添加")
	@ApiOperation(value="教学楼信息-添加", notes="教学楼信息-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody KcJiaoxuelouInfo kcJiaoxuelouInfo) {
		kcJiaoxuelouInfoService.save(kcJiaoxuelouInfo);
		return Result.OK("添加成功！");
	}
	
	/**
	 * 编辑
	 *
	 * @param kcJiaoxuelouInfo
	 * @return
	 */
	@AutoLog(value = "教学楼信息-编辑")
	@ApiOperation(value="教学楼信息-编辑", notes="教学楼信息-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<?> edit(@RequestBody KcJiaoxuelouInfo kcJiaoxuelouInfo) {
		kcJiaoxuelouInfoService.updateById(kcJiaoxuelouInfo);
		return Result.OK("编辑成功!");
	}
	
	/**
	 * 通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "教学楼信息-通过id删除")
	@ApiOperation(value="教学楼信息-通过id删除", notes="教学楼信息-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		kcJiaoxuelouInfoService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 * 批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "教学楼信息-批量删除")
	@ApiOperation(value="教学楼信息-批量删除", notes="教学楼信息-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcJiaoxuelouInfoService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "教学楼信息-通过id查询")
	@ApiOperation(value="教学楼信息-通过id查询", notes="教学楼信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		KcJiaoxuelouInfo kcJiaoxuelouInfo = kcJiaoxuelouInfoService.getById(id);
		return Result.OK(kcJiaoxuelouInfo);
	}

  /**
   * 导出excel
   *
   * @param request
   * @param kcJiaoxuelouInfo
   */
  @RequestMapping(value = "/exportXls")
  public ModelAndView exportXls(HttpServletRequest request, KcJiaoxuelouInfo kcJiaoxuelouInfo) {
      return super.exportXls(request, kcJiaoxuelouInfo, KcJiaoxuelouInfo.class, "教学楼信息");
  }

  /**
   * 通过excel导入数据
   *
   * @param request
   * @param response
   * @return
   */
  @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
  public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
      return super.importExcel(request, response, KcJiaoxuelouInfo.class);
  }

}
