package org.jeecg.modules.kc.jiaoshi.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.kc.jiaoshi.entity.KcZhihuijiaoshiMonitorLog;
import org.jeecg.modules.kc.jiaoshi.export.Export;
import org.jeecg.modules.kc.jiaoshi.service.IKcZhihuijiaoshiMonitorLogService;
import org.jeecg.modules.tools.word.ExportWord;
import org.jeecg.modules.tools.word.WordOperator;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.List;

/**
 * @Description: 状态日志
 * @Author: jeecg-boot
 * @Date:   2023-10-29
 * @Version: V1.0
 */
@Slf4j
@Api(tags="状态日志")
@RestController
@RequestMapping("/jiaoshi/kcZhihuijiaoshiMonitorLog")
public class KcZhihuijiaoshiMonitorLogController extends JeecgController<KcZhihuijiaoshiMonitorLog, IKcZhihuijiaoshiMonitorLogService> {
	@Autowired
	private IKcZhihuijiaoshiMonitorLogService kcZhihuijiaoshiMonitorLogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcZhihuijiaoshiMonitorLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "状态日志-分页列表查询")
	@ApiOperation(value="状态日志-分页列表查询", notes="状态日志-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(KcZhihuijiaoshiMonitorLog kcZhihuijiaoshiMonitorLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcZhihuijiaoshiMonitorLog> queryWrapper = QueryGenerator.initQueryWrapper(kcZhihuijiaoshiMonitorLog, req.getParameterMap());
		queryWrapper.orderByDesc("create_time");
		Page<KcZhihuijiaoshiMonitorLog> page = new Page<KcZhihuijiaoshiMonitorLog>(pageNo, pageSize);
		IPage<KcZhihuijiaoshiMonitorLog> pageList = kcZhihuijiaoshiMonitorLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 * 添加
	 *
	 * @param kcZhihuijiaoshiMonitorLog
	 * @return
	 */
	@AutoLog(value = "状态日志-添加")
	@ApiOperation(value="状态日志-添加", notes="状态日志-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody KcZhihuijiaoshiMonitorLog kcZhihuijiaoshiMonitorLog) {
		kcZhihuijiaoshiMonitorLogService.save(kcZhihuijiaoshiMonitorLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 * 编辑
	 *
	 * @param kcZhihuijiaoshiMonitorLog
	 * @return
	 */
	@AutoLog(value = "状态日志-编辑")
	@ApiOperation(value="状态日志-编辑", notes="状态日志-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<?> edit(@RequestBody KcZhihuijiaoshiMonitorLog kcZhihuijiaoshiMonitorLog) {
		kcZhihuijiaoshiMonitorLogService.updateById(kcZhihuijiaoshiMonitorLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 * 通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "状态日志-通过id删除")
	@ApiOperation(value="状态日志-通过id删除", notes="状态日志-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		kcZhihuijiaoshiMonitorLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 * 批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "状态日志-批量删除")
	@ApiOperation(value="状态日志-批量删除", notes="状态日志-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcZhihuijiaoshiMonitorLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "状态日志-通过id查询")
	@ApiOperation(value="状态日志-通过id查询", notes="状态日志-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		KcZhihuijiaoshiMonitorLog kcZhihuijiaoshiMonitorLog = kcZhihuijiaoshiMonitorLogService.getById(id);
		return Result.OK(kcZhihuijiaoshiMonitorLog);
	}

  /**
   * 导出excel
   *
   * @param request
   * @param kcZhihuijiaoshiMonitorLog
   */
  @RequestMapping(value = "/exportXls")
  public ModelAndView exportXls(HttpServletRequest request, KcZhihuijiaoshiMonitorLog kcZhihuijiaoshiMonitorLog) {
//      return super.exportXls(request, kcZhihuijiaoshiMonitorLog, KcZhihuijiaoshiMonitorLog.class, "状态日志");
	  String title = "统计报表";
	  // Step.1 组装查询条件
	  QueryWrapper<KcZhihuijiaoshiMonitorLog> queryWrapper = QueryGenerator.initQueryWrapper(kcZhihuijiaoshiMonitorLog, request.getParameterMap());
	  queryWrapper.ge(StringUtils.isNotBlank(kcZhihuijiaoshiMonitorLog.getStartTime()),"create_time",kcZhihuijiaoshiMonitorLog.getStartTime());
	  queryWrapper.le(StringUtils.isNotBlank(kcZhihuijiaoshiMonitorLog.getEndTime()),"create_time",kcZhihuijiaoshiMonitorLog.getEndTime());
	  LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
	  // Step.2 获取导出数据
	  List<KcZhihuijiaoshiMonitorLog> exportList = service.staticAllList(queryWrapper);

	  // Step.3 AutoPoi 导出Excel
	  ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
	  //此处设置的filename无效 ,前端会重更新设置一下
	  mv.addObject(NormalExcelConstants.FILE_NAME, title);
	  mv.addObject(NormalExcelConstants.CLASS, KcZhihuijiaoshiMonitorLog.class);
	  //update-begin--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置--------------------
	  ExportParams exportParams=new ExportParams(title + "报表", "导出人:" + sysUser.getRealname(), title);
//	  exportParams.setImageBasePath(upLoadPath);
	  //update-end--Author:liusq  Date:20210126 for：图片导出报错，ImageBasePath未设置----------------------
	  mv.addObject(NormalExcelConstants.PARAMS,exportParams);
	  mv.addObject(NormalExcelConstants.DATA_LIST, exportList);
	  return mv;
  }

  /**
   * 通过excel导入数据
   *
   * @param request
   * @param response
   * @return
   */
  @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
  public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
      return super.importExcel(request, response, KcZhihuijiaoshiMonitorLog.class);
  }

	 @AutoLog(value = "状态日志-分页列表查询")
	 @ApiOperation(value="状态日志-分页列表查询", notes="状态日志-分页列表查询")
	 @GetMapping(value = "/staticList")
	 public Result<?> staticList(KcZhihuijiaoshiMonitorLog kcZhihuijiaoshiMonitorLog,
									@RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
									@RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
									HttpServletRequest req) {
		 QueryWrapper<KcZhihuijiaoshiMonitorLog> queryWrapper = QueryGenerator.initQueryWrapper(kcZhihuijiaoshiMonitorLog, req.getParameterMap());
		 queryWrapper.ge(StringUtils.isNotBlank(kcZhihuijiaoshiMonitorLog.getStartTime()),"create_time",kcZhihuijiaoshiMonitorLog.getStartTime());
		 queryWrapper.le(StringUtils.isNotBlank(kcZhihuijiaoshiMonitorLog.getEndTime()),"create_time",kcZhihuijiaoshiMonitorLog.getEndTime());
		 Page<KcZhihuijiaoshiMonitorLog> page = new Page<KcZhihuijiaoshiMonitorLog>(pageNo, pageSize);
		 IPage<KcZhihuijiaoshiMonitorLog> pageList = kcZhihuijiaoshiMonitorLogService.staticList(page, queryWrapper);
		 return Result.OK(pageList);
	 }

	/**
	 * 导出word
	 *
	 * @param kcZhihuijiaoshiMonitorLog
	 * @param request
	 * @param response
	 */
//	 @RequiresPermissions("config:kc_export_config_tpkwcqkjzglx:exportXls")
	@RequestMapping(value = "/exportWord")
	public void exportWord(KcZhihuijiaoshiMonitorLog kcZhihuijiaoshiMonitorLog, HttpServletRequest request, HttpServletResponse response) throws Exception {
		Export export = new Export();
		WordOperator wo = export.export(kcZhihuijiaoshiMonitorLog);
		ExportWord.download_word(request, response, "file.doc", wo);
	}

	/**
	 * 导出word
	 *
	 * @param kcZhihuijiaoshiMonitorLog
	 * @param request
	 * @param response
	 */
//	 @RequiresPermissions("config:kc_export_config_tpkwcqkjzglx:exportXls")
	@RequestMapping(value = "/exportPdf")
	public void exportPdf(KcZhihuijiaoshiMonitorLog kcZhihuijiaoshiMonitorLog, HttpServletRequest request, HttpServletResponse response) throws Exception {
		Export export = new Export();
		WordOperator wo = export.export(kcZhihuijiaoshiMonitorLog);
		ExportWord.download_pdf(request, response, "file", wo);
	}



}
