package org.jeecg.modules.kc.kcAssessidentity.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.kcAssessidentity.entity.KcAssessidentity;
import org.jeecg.modules.kc.kcAssessidentity.service.IKcAssessidentityService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: kc_assessidentity
 * @Author: jeecg-boot
 * @Date:   2023-05-19
 * @Version: V1.0
 */
@Api(tags="kc_assessidentity")
@RestController
@RequestMapping("/kcAssessidentity/kcAssessidentity")
@Slf4j
public class KcAssessidentityController extends JeecgController<KcAssessidentity, IKcAssessidentityService> {
	@Autowired
	private IKcAssessidentityService kcAssessidentityService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcAssessidentity
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "kc_assessidentity-分页列表查询")
	@ApiOperation(value="kc_assessidentity-分页列表查询", notes="kc_assessidentity-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcAssessidentity>> queryPageList(KcAssessidentity kcAssessidentity,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcAssessidentity> queryWrapper = QueryGenerator.initQueryWrapper(kcAssessidentity, req.getParameterMap());
		queryWrapper.apply(StringUtils.isNotBlank(kcAssessidentity.getYwmc()),"assessl1 like concat('%','"+kcAssessidentity.getYwmc()+"','%') or assessl2 like concat('%','"+kcAssessidentity.getYwmc()+"','%') or demand like concat('%','"+kcAssessidentity.getYwmc()+"','%') or assesscode like concat('%','"+kcAssessidentity.getYwmc()+"','%')  ");

		Page<KcAssessidentity> page = new Page<KcAssessidentity>(pageNo, pageSize);
		IPage<KcAssessidentity> pageList = kcAssessidentityService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcAssessidentity
	 * @return
	 */
	@AutoLog(value = "kc_assessidentity-添加")
	@ApiOperation(value="kc_assessidentity-添加", notes="kc_assessidentity-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcAssessidentity kcAssessidentity) {
		kcAssessidentityService.save(kcAssessidentity);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcAssessidentity
	 * @return
	 */
	@AutoLog(value = "kc_assessidentity-编辑")
	@ApiOperation(value="kc_assessidentity-编辑", notes="kc_assessidentity-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcAssessidentity kcAssessidentity) {
		kcAssessidentityService.updateById(kcAssessidentity);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "kc_assessidentity-通过id删除")
	@ApiOperation(value="kc_assessidentity-通过id删除", notes="kc_assessidentity-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcAssessidentityService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "kc_assessidentity-批量删除")
	@ApiOperation(value="kc_assessidentity-批量删除", notes="kc_assessidentity-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcAssessidentityService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "kc_assessidentity-通过id查询")
	@ApiOperation(value="kc_assessidentity-通过id查询", notes="kc_assessidentity-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcAssessidentity> queryById(@RequestParam(name="id",required=true) String id) {
		KcAssessidentity kcAssessidentity = kcAssessidentityService.getById(id);
		if(kcAssessidentity==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcAssessidentity);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcAssessidentity
    */
    @RequiresPermissions("kcAssessidentity:kc_assessidentity:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcAssessidentity kcAssessidentity) {
        return super.exportXls(request, kcAssessidentity, KcAssessidentity.class, "kc_assessidentity");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kcAssessidentity:kc_assessidentity:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcAssessidentity.class);
    }

}
