package org.jeecg.modules.kc.kcAssessuser.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.kcAssessuser.entity.KcAssessuser;
import org.jeecg.modules.kc.kcAssessuser.service.IKcAssessuserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.List;

/**
 * @Description: kc_assessuser
 * @Author: jeecg-boot
 * @Date:   2023-05-22
 * @Version: V1.0
 */
@Api(tags="kc_assessuser")
@RestController
@RequestMapping("/kcAssessuser/kcAssessuser")
@Slf4j
public class KcAssessuserController extends JeecgController<KcAssessuser, IKcAssessuserService> {
	@Autowired
	private IKcAssessuserService kcAssessuserService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcAssessuser
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "kc_assessuser-分页列表查询")
	@ApiOperation(value="kc_assessuser-分页列表查询", notes="kc_assessuser-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcAssessuser>> queryPageList(KcAssessuser kcAssessuser,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcAssessuser> queryWrapper = QueryGenerator.initQueryWrapper(kcAssessuser, req.getParameterMap());
		Page<KcAssessuser> page = new Page<KcAssessuser>(pageNo, pageSize);
		IPage<KcAssessuser> pageList = kcAssessuserService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	 /**
	  * 分页列表查询
	  *
	  * @param kcAssessuser
	  * @param pageNo
	  * @param pageSize
	  * @param req
	  * @return
	  */
	 //@AutoLog(value = "kc_assessuser-分页列表查询")
	 @ApiOperation(value="kc_assessuser-分页列表查询", notes="kc_assessuser-分页列表查询")
	 @GetMapping(value = "/allList")
	 public Result<List<KcAssessuser>> allList(KcAssessuser kcAssessuser,
													  @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
													  @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
													  HttpServletRequest req) {
		 QueryWrapper<KcAssessuser> queryWrapper = QueryGenerator.initQueryWrapper(kcAssessuser, req.getParameterMap());
		 queryWrapper.setEntity(kcAssessuser);
		 List<KcAssessuser> pageList = kcAssessuserService.allList(queryWrapper);
		 return Result.OK(pageList);
	 }



	
	/**
	 *   添加
	 *
	 * @param kcAssessuser
	 * @return
	 */
	@AutoLog(value = "kc_assessuser-添加")
	@ApiOperation(value="kc_assessuser-添加", notes="kc_assessuser-添加")
	@RequiresPermissions("kcAssessuser:kc_assessuser:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcAssessuser kcAssessuser) {
		kcAssessuserService.save(kcAssessuser);
		return Result.OK("添加成功！");
	}

	/**
	 *   添加
	 *
	 * @param kcAssessuser
	 * @return
	 */
	@AutoLog(value = "kc_assessuser-添加")
	@ApiOperation(value="kc_assessuser-添加", notes="kc_assessuser-添加")
//	@RequiresPermissions("kcAssessuser:kc_assessuser:add")
	@PostMapping(value = "/addAll")
	public Result<String> addAll(@RequestBody KcAssessuser kcAssessuser) {
		kcAssessuserService.saveAll(kcAssessuser);
		return Result.OK("添加成功！");
	}

	/**
	 *  编辑
	 *
	 * @param kcAssessuser
	 * @return
	 */
	@AutoLog(value = "kc_assessuser-编辑")
	@ApiOperation(value="kc_assessuser-编辑", notes="kc_assessuser-编辑")
	@RequiresPermissions("kcAssessuser:kc_assessuser:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcAssessuser kcAssessuser) {
		kcAssessuserService.updateById(kcAssessuser);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "kc_assessuser-通过id删除")
	@ApiOperation(value="kc_assessuser-通过id删除", notes="kc_assessuser-通过id删除")
//	@RequiresPermissions("kcAssessuser:kc_assessuser:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcAssessuserService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "kc_assessuser-批量删除")
	@ApiOperation(value="kc_assessuser-批量删除", notes="kc_assessuser-批量删除")
//	@RequiresPermissions("kcAssessuser:kc_assessuser:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcAssessuserService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "kc_assessuser-通过id查询")
	@ApiOperation(value="kc_assessuser-通过id查询", notes="kc_assessuser-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcAssessuser> queryById(@RequestParam(name="id",required=true) String id) {
		KcAssessuser kcAssessuser = kcAssessuserService.getById(id);
		if(kcAssessuser==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcAssessuser);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcAssessuser
    */
    @RequiresPermissions("kcAssessuser:kc_assessuser:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcAssessuser kcAssessuser) {
        return super.exportXls(request, kcAssessuser, KcAssessuser.class, "kc_assessuser");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kcAssessuser:kc_assessuser:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcAssessuser.class);
    }

}
