package org.jeecg.modules.kc.kcErrorreport.controller;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.DateUtils;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.kcErrorreport.entity.KcErrorreport;
import org.jeecg.modules.kc.kcErrorreport.service.IKcErrorreportService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: kc_errorreport
 * @Author: jeecg-boot
 * @Date:   2023-04-05
 * @Version: V1.0
 */
@Api(tags="kc_errorreport")
@RestController
@RequestMapping("/kcErrorreport/kcErrorreport")
@Slf4j
public class KcErrorreportController extends JeecgController<KcErrorreport, IKcErrorreportService> {
	@Autowired
	private IKcErrorreportService kcErrorreportService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcErrorreport
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "kc_errorreport-分页列表查询")
	@ApiOperation(value="kc_errorreport-分页列表查询", notes="kc_errorreport-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcErrorreport>> queryPageList(KcErrorreport kcErrorreport,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		Page<KcErrorreport> page = new Page<KcErrorreport>(pageNo, pageSize);
//		if(StringUtils.isNotBlank(kcErrorreport.getEndTime())){
//			kcErrorreport.setEndTime(kcErrorreport.getEndTime()+" 23:59:59");
//		}
		IPage<KcErrorreport> pageList = kcErrorreportService.selectPageList(page, kcErrorreport);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcErrorreport
	 * @return
	 */
	@AutoLog(value = "kc_errorreport-添加")
	@ApiOperation(value="kc_errorreport-添加", notes="kc_errorreport-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcErrorreport kcErrorreport) {
		kcErrorreport.setReportstime(DateUtils.formatDate(new Date(),"yyyy-MM-dd HH:mm:ss"));
		kcErrorreport.setSkrq(DateUtils.formatDate(new Date(),"yyyy-MM-dd"));
		kcErrorreportService.save(kcErrorreport);
		return Result.OK("提交报错信息成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcErrorreport
	 * @return
	 */
	@AutoLog(value = "kc_errorreport-编辑")
	@ApiOperation(value="kc_errorreport-编辑", notes="kc_errorreport-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcErrorreport kcErrorreport) {
		kcErrorreportService.updateById(kcErrorreport);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "kc_errorreport-通过id删除")
	@ApiOperation(value="kc_errorreport-通过id删除", notes="kc_errorreport-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcErrorreportService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "kc_errorreport-批量删除")
	@ApiOperation(value="kc_errorreport-批量删除", notes="kc_errorreport-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcErrorreportService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "kc_errorreport-通过id查询")
	@ApiOperation(value="kc_errorreport-通过id查询", notes="kc_errorreport-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcErrorreport> queryById(@RequestParam(name="id",required=true) String id) {
		KcErrorreport kcErrorreport = kcErrorreportService.getById(id);
		if(kcErrorreport==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcErrorreport);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcErrorreport
    */
    @RequiresPermissions("kcErrorreport:kc_errorreport:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcErrorreport kcErrorreport) {
        return super.exportXls(request, kcErrorreport, KcErrorreport.class, "kc_errorreport");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kcErrorreport:kc_errorreport:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcErrorreport.class);
    }

}
