package org.jeecg.modules.kc.kcJieci.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.kcJieci.entity.KcJieci;
import org.jeecg.modules.kc.kcJieci.service.IKcJieciService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: kc_jieci
 * @Author: jeecg-boot
 * @Date:   2023-04-03
 * @Version: V1.0
 */
@Api(tags="kc_jieci")
@RestController
@RequestMapping("/kcJieci/kcJieci")
@Slf4j
public class KcJieciController extends JeecgController<KcJieci, IKcJieciService> {
	@Autowired
	private IKcJieciService kcJieciService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcJieci
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "kc_jieci-分页列表查询")
	@ApiOperation(value="kc_jieci-分页列表查询", notes="kc_jieci-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcJieci>> queryPageList(KcJieci kcJieci,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcJieci> queryWrapper = QueryGenerator.initQueryWrapper(kcJieci, req.getParameterMap());
		Page<KcJieci> page = new Page<KcJieci>(pageNo, pageSize);
		IPage<KcJieci> pageList = kcJieciService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcJieci
	 * @return
	 */
	@AutoLog(value = "kc_jieci-添加")
	@ApiOperation(value="kc_jieci-添加", notes="kc_jieci-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcJieci kcJieci) {
		kcJieciService.save(kcJieci);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcJieci
	 * @return
	 */
	@AutoLog(value = "kc_jieci-编辑")
	@ApiOperation(value="kc_jieci-编辑", notes="kc_jieci-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcJieci kcJieci) {
		kcJieciService.updateById(kcJieci);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "kc_jieci-通过id删除")
	@ApiOperation(value="kc_jieci-通过id删除", notes="kc_jieci-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcJieciService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "kc_jieci-批量删除")
	@ApiOperation(value="kc_jieci-批量删除", notes="kc_jieci-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcJieciService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "kc_jieci-通过id查询")
	@ApiOperation(value="kc_jieci-通过id查询", notes="kc_jieci-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcJieci> queryById(@RequestParam(name="id",required=true) String id) {
		KcJieci kcJieci = kcJieciService.getById(id);
		if(kcJieci==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcJieci);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcJieci
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcJieci kcJieci) {
        return super.exportXls(request, kcJieci, KcJieci.class, "kc_jieci");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kcJieci:kc_jieci:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcJieci.class);
    }


	 @ApiOperation(value="kc_jieci-首页获取节次信息", notes="kc_jieci-首页获取节次信息")
	 @GetMapping(value = "/getIndexJcList")
	 public Result<List<KcJieci>> getIndexJcList(KcJieci kcJieci) {
		 List<KcJieci> pageList = kcJieciService.getIndexJcList(kcJieci);
		 return Result.OK(pageList);
	 }

	 @ApiOperation(value="可线上听课课堂-提前半小时", notes="可线上听课课堂-提前半小时")
	 @GetMapping(value = "/getIndexJcXskcList")
	 public Result<List<KcJieci>> getIndexJcXskcList(KcJieci kcJieci) {
		 List<KcJieci> pageList = kcJieciService.getIndexJcXskcList(kcJieci);
		 return Result.OK(pageList);
	 }

}
