package org.jeecg.modules.kc.kcJieciPipei.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.kcJieciPipei.entity.KcJieciPipei;
import org.jeecg.modules.kc.kcJieciPipei.service.IKcJieciPipeiService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 节次匹配数据
 * @Author: jeecg-boot
 * @Date:   2024-03-21
 * @Version: V1.0
 */
@Api(tags="节次匹配数据")
@RestController
@RequestMapping("/kcJieciPipei/kcJieciPipei")
@Slf4j
public class KcJieciPipeiController extends JeecgController<KcJieciPipei, IKcJieciPipeiService> {
	@Autowired
	private IKcJieciPipeiService kcJieciPipeiService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcJieciPipei
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "节次匹配数据-分页列表查询")
	@ApiOperation(value="节次匹配数据-分页列表查询", notes="节次匹配数据-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcJieciPipei>> queryPageList(KcJieciPipei kcJieciPipei,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcJieciPipei> queryWrapper = QueryGenerator.initQueryWrapper(kcJieciPipei, req.getParameterMap());
		Page<KcJieciPipei> page = new Page<KcJieciPipei>(pageNo, pageSize);
		IPage<KcJieciPipei> pageList = kcJieciPipeiService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcJieciPipei
	 * @return
	 */
	@AutoLog(value = "节次匹配数据-添加")
	@ApiOperation(value="节次匹配数据-添加", notes="节次匹配数据-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcJieciPipei kcJieciPipei) {
		kcJieciPipeiService.save(kcJieciPipei);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcJieciPipei
	 * @return
	 */
	@AutoLog(value = "节次匹配数据-编辑")
	@ApiOperation(value="节次匹配数据-编辑", notes="节次匹配数据-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcJieciPipei kcJieciPipei) {
		kcJieciPipeiService.updateById(kcJieciPipei);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "节次匹配数据-通过id删除")
	@ApiOperation(value="节次匹配数据-通过id删除", notes="节次匹配数据-通过id删除")
	@RequiresPermissions("kcJieciPipei:kc_jieci_pipei:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcJieciPipeiService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "节次匹配数据-批量删除")
	@ApiOperation(value="节次匹配数据-批量删除", notes="节次匹配数据-批量删除")
	@RequiresPermissions("kcJieciPipei:kc_jieci_pipei:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcJieciPipeiService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "节次匹配数据-通过id查询")
	@ApiOperation(value="节次匹配数据-通过id查询", notes="节次匹配数据-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcJieciPipei> queryById(@RequestParam(name="id",required=true) String id) {
		KcJieciPipei kcJieciPipei = kcJieciPipeiService.getById(id);
		if(kcJieciPipei==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcJieciPipei);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcJieciPipei
    */
    @RequiresPermissions("kcJieciPipei:kc_jieci_pipei:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcJieciPipei kcJieciPipei) {
        return super.exportXls(request, kcJieciPipei, KcJieciPipei.class, "节次匹配数据");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kcJieciPipei:kc_jieci_pipei:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcJieciPipei.class);
    }

}
