package org.jeecg.modules.kc.kcKetangSuibi.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.kcKetangSuibi.entity.KcKetangSuibi;
import org.jeecg.modules.kc.kcKetangSuibi.service.IKcKetangSuibiService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 课堂随笔
 * @Author: jeecg-boot
 * @Date:   2023-05-04
 * @Version: V1.0
 */
@Api(tags="课堂随笔")
@RestController
@RequestMapping("/kc/kcKetangSuibi")
@Slf4j
public class KcKetangSuibiController extends JeecgController<KcKetangSuibi, IKcKetangSuibiService> {
	@Autowired
	private IKcKetangSuibiService kcKetangSuibiService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcKetangSuibi
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "课堂随笔-分页列表查询")
	@ApiOperation(value="课堂随笔-分页列表查询", notes="课堂随笔-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcKetangSuibi>> queryPageList(KcKetangSuibi kcKetangSuibi,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcKetangSuibi> queryWrapper = QueryGenerator.initQueryWrapper("a",kcKetangSuibi, req.getParameterMap());
		Page<KcKetangSuibi> page = new Page<KcKetangSuibi>(pageNo, pageSize);
		IPage<KcKetangSuibi> pageList = kcKetangSuibiService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcKetangSuibi
	 * @return
	 */
	@AutoLog(value = "课堂随笔-添加")
	@ApiOperation(value="课堂随笔-添加", notes="课堂随笔-添加")
//	@RequiresPermissions("kc:kc_ketang_suibi:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcKetangSuibi kcKetangSuibi) {
		if(StringUtils.isNotBlank(kcKetangSuibi.getKetangbiaoId())){
			QueryWrapper<KcKetangSuibi> kcKetangSuibiQueryWrapper = new QueryWrapper<>();
			kcKetangSuibiQueryWrapper.eq("ketangbiao_id",kcKetangSuibi.getKetangbiaoId());
			kcKetangSuibiQueryWrapper.eq("user_id",kcKetangSuibi.getUserId());
			kcKetangSuibiService.remove(kcKetangSuibiQueryWrapper);
			kcKetangSuibiService.save(kcKetangSuibi);
		}else{
			kcKetangSuibiService.save(kcKetangSuibi);
		}

		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcKetangSuibi
	 * @return
	 */
	@AutoLog(value = "课堂随笔-编辑")
	@ApiOperation(value="课堂随笔-编辑", notes="课堂随笔-编辑")
//	@RequiresPermissions("kc:kc_ketang_suibi:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcKetangSuibi kcKetangSuibi) {
		kcKetangSuibiService.updateById(kcKetangSuibi);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "课堂随笔-通过id删除")
	@ApiOperation(value="课堂随笔-通过id删除", notes="课堂随笔-通过id删除")
	@RequiresPermissions("kc:kc_ketang_suibi:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcKetangSuibiService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "课堂随笔-批量删除")
	@ApiOperation(value="课堂随笔-批量删除", notes="课堂随笔-批量删除")
	@RequiresPermissions("kc:kc_ketang_suibi:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcKetangSuibiService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "课堂随笔-通过id查询")
	@ApiOperation(value="课堂随笔-通过id查询", notes="课堂随笔-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcKetangSuibi> queryById(@RequestParam(name="id",required=true) String id) {
		KcKetangSuibi kcKetangSuibi = kcKetangSuibiService.getById(id);
		if(kcKetangSuibi==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcKetangSuibi);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcKetangSuibi
    */
    @RequiresPermissions("kc:kc_ketang_suibi:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcKetangSuibi kcKetangSuibi) {
        return super.exportXls(request, kcKetangSuibi, KcKetangSuibi.class, "课堂随笔");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kc:kc_ketang_suibi:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcKetangSuibi.class);
    }

}
