package org.jeecg.modules.kc.kcMessagelistcopy.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.kcMessagelistcopy.entity.KcMessagelistcopy;
import org.jeecg.modules.kc.kcMessagelistcopy.service.IKcMessagelistcopyService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 订阅信息表
 * @Author: jeecg-boot
 * @Date:   2023-04-25
 * @Version: V1.0
 */
@Api(tags="订阅信息表")
@RestController
@RequestMapping("/kc/kcMessagelistcopy")
@Slf4j
public class KcMessagelistcopyController extends JeecgController<KcMessagelistcopy, IKcMessagelistcopyService> {
	@Autowired
	private IKcMessagelistcopyService kcMessagelistcopyService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcMessagelistcopy
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "订阅信息表-分页列表查询")
	@ApiOperation(value="订阅信息表-分页列表查询", notes="订阅信息表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcMessagelistcopy>> queryPageList(KcMessagelistcopy kcMessagelistcopy,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcMessagelistcopy> queryWrapper = QueryGenerator.initQueryWrapper(kcMessagelistcopy, req.getParameterMap());
		Page<KcMessagelistcopy> page = new Page<KcMessagelistcopy>(pageNo, pageSize);
		IPage<KcMessagelistcopy> pageList = kcMessagelistcopyService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcMessagelistcopy
	 * @return
	 */
	@AutoLog(value = "订阅信息表-添加")
	@ApiOperation(value="订阅信息表-添加", notes="订阅信息表-添加")
	@RequiresPermissions("kc:kc_messagelistcopy:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcMessagelistcopy kcMessagelistcopy) {
		kcMessagelistcopyService.save(kcMessagelistcopy);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcMessagelistcopy
	 * @return
	 */
	@AutoLog(value = "订阅信息表-编辑")
	@ApiOperation(value="订阅信息表-编辑", notes="订阅信息表-编辑")
	@RequiresPermissions("kc:kc_messagelistcopy:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcMessagelistcopy kcMessagelistcopy) {
		kcMessagelistcopyService.updateById(kcMessagelistcopy);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "订阅信息表-通过id删除")
	@ApiOperation(value="订阅信息表-通过id删除", notes="订阅信息表-通过id删除")
	@RequiresPermissions("kc:kc_messagelistcopy:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcMessagelistcopyService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "订阅信息表-批量删除")
	@ApiOperation(value="订阅信息表-批量删除", notes="订阅信息表-批量删除")
	@RequiresPermissions("kc:kc_messagelistcopy:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcMessagelistcopyService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "订阅信息表-通过id查询")
	@ApiOperation(value="订阅信息表-通过id查询", notes="订阅信息表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcMessagelistcopy> queryById(@RequestParam(name="id",required=true) String id) {
		KcMessagelistcopy kcMessagelistcopy = kcMessagelistcopyService.getById(id);
		if(kcMessagelistcopy==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcMessagelistcopy);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcMessagelistcopy
    */
    @RequiresPermissions("kc:kc_messagelistcopy:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcMessagelistcopy kcMessagelistcopy) {
        return super.exportXls(request, kcMessagelistcopy, KcMessagelistcopy.class, "订阅信息表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kc:kc_messagelistcopy:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcMessagelistcopy.class);
    }

}
