package org.jeecg.modules.kc.kcNotice.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.kcNotice.entity.KcNotice;
import org.jeecg.modules.kc.kcNotice.service.IKcNoticeService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: kc_notice
 * @Author: jeecg-boot
 * @Date:   2023-04-02
 * @Version: V1.0
 */
@Api(tags="kc_notice")
@RestController
@RequestMapping("/kcNotice/kcNotice")
@Slf4j
public class KcNoticeController extends JeecgController<KcNotice, IKcNoticeService> {
	@Autowired
	private IKcNoticeService kcNoticeService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcNotice
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "kc_notice-分页列表查询")
	@ApiOperation(value="kc_notice-分页列表查询", notes="kc_notice-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcNotice>> queryPageList(KcNotice kcNotice,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcNotice> queryWrapper = QueryGenerator.initQueryWrapper(kcNotice, req.getParameterMap());
		Page<KcNotice> page = new Page<KcNotice>(pageNo, pageSize);
		IPage<KcNotice> pageList = kcNoticeService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcNotice
	 * @return
	 */
	@AutoLog(value = "kc_notice-添加")
	@ApiOperation(value="kc_notice-添加", notes="kc_notice-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcNotice kcNotice) {
		kcNoticeService.save(kcNotice);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcNotice
	 * @return
	 */
	@AutoLog(value = "kc_notice-编辑")
	@ApiOperation(value="kc_notice-编辑", notes="kc_notice-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcNotice kcNotice) {
		kcNoticeService.updateById(kcNotice);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "kc_notice-通过id删除")
	@ApiOperation(value="kc_notice-通过id删除", notes="kc_notice-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcNoticeService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "kc_notice-批量删除")
	@ApiOperation(value="kc_notice-批量删除", notes="kc_notice-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcNoticeService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "kc_notice-通过id查询")
	@ApiOperation(value="kc_notice-通过id查询", notes="kc_notice-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcNotice> queryById(@RequestParam(name="id",required=true) String id) {
		KcNotice kcNotice = kcNoticeService.getById(id);
		if(kcNotice==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcNotice);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcNotice
    */
    @RequiresPermissions("kcNotice:kc_notice:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcNotice kcNotice) {
        return super.exportXls(request, kcNotice, KcNotice.class, "kc_notice");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kcNotice:kc_notice:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcNotice.class);
    }

}
