package org.jeecg.modules.kc.kcSuggestions.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.kcSuggestions.entity.KcSuggestions;
import org.jeecg.modules.kc.kcSuggestions.service.IKcSuggestionsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: kc_suggestions
 * @Author: jeecg-boot
 * @Date:   2023-04-09
 * @Version: V1.0
 */
@Api(tags="kc_suggestions")
@RestController
@RequestMapping("/kcSuggestions/kcSuggestions")
@Slf4j
public class KcSuggestionsController extends JeecgController<KcSuggestions, IKcSuggestionsService> {
	@Autowired
	private IKcSuggestionsService kcSuggestionsService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcSuggestions
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "kc_suggestions-分页列表查询")
	@ApiOperation(value="kc_suggestions-分页列表查询", notes="kc_suggestions-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcSuggestions>> queryPageList(KcSuggestions kcSuggestions,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcSuggestions> queryWrapper = QueryGenerator.initQueryWrapper(kcSuggestions, req.getParameterMap());
		queryWrapper.ge(StringUtils.isNotBlank(kcSuggestions.getStartTime()),"suggestionstime",kcSuggestions.getStartTime());
		queryWrapper.le(StringUtils.isNotBlank(kcSuggestions.getEndTime()),"suggestionstime",kcSuggestions.getEndTime()+" 23:59:59");
		Page<KcSuggestions> page = new Page<KcSuggestions>(pageNo, pageSize);
		IPage<KcSuggestions> pageList = kcSuggestionsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcSuggestions
	 * @return
	 */
	@AutoLog(value = "kc_suggestions-添加")
	@ApiOperation(value="kc_suggestions-添加", notes="kc_suggestions-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcSuggestions kcSuggestions) {
		kcSuggestionsService.save(kcSuggestions);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcSuggestions
	 * @return
	 */
	@AutoLog(value = "kc_suggestions-编辑")
	@ApiOperation(value="kc_suggestions-编辑", notes="kc_suggestions-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcSuggestions kcSuggestions) {
		kcSuggestionsService.updateById(kcSuggestions);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "kc_suggestions-通过id删除")
	@ApiOperation(value="kc_suggestions-通过id删除", notes="kc_suggestions-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcSuggestionsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "kc_suggestions-批量删除")
	@ApiOperation(value="kc_suggestions-批量删除", notes="kc_suggestions-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcSuggestionsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "kc_suggestions-通过id查询")
	@ApiOperation(value="kc_suggestions-通过id查询", notes="kc_suggestions-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcSuggestions> queryById(@RequestParam(name="id",required=true) String id) {
		KcSuggestions kcSuggestions = kcSuggestionsService.getById(id);
		if(kcSuggestions==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcSuggestions);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcSuggestions
    */
    @RequiresPermissions("kcSuggestions:kc_suggestions:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcSuggestions kcSuggestions) {
        return super.exportXls(request, kcSuggestions, KcSuggestions.class, "kc_suggestions");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kcSuggestions:kc_suggestions:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcSuggestions.class);
    }

}
