package org.jeecg.modules.kc.kcSzkc.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.kcSzkc.entity.KcSzkc;
import org.jeecg.modules.kc.kcSzkc.service.IKcSzkcService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.kc.ktgl.entity.KcKechengbiao;
import org.jeecg.modules.kc.ktgl.entity.KcKetangbiao;
import org.jeecg.modules.kc.ktgl.service.IKcKechengbiaoService;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 思政课程
 * @Author: jeecg-boot
 * @Date:   2023-05-25
 * @Version: V1.0
 */
@Api(tags="思政课程")
@RestController
@RequestMapping("/kcSzkc/kcSzkc")
@Slf4j
public class KcSzkcController extends JeecgController<KcSzkc, IKcSzkcService> {
	@Autowired
	private IKcSzkcService kcSzkcService;
	@Autowired
	private IKcKechengbiaoService kcKechengbiaoService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcSzkc
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "思政课程-分页列表查询")
	@ApiOperation(value="思政课程-分页列表查询", notes="思政课程-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcSzkc>> queryPageList(KcSzkc kcSzkc,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcSzkc> queryWrapper = QueryGenerator.initQueryWrapper(kcSzkc, req.getParameterMap());
		Page<KcSzkc> page = new Page<KcSzkc>(pageNo, pageSize);
		IPage<KcSzkc> pageList = kcSzkcService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcSzkc
	 * @return
	 */
	@AutoLog(value = "思政课程-添加")
	@ApiOperation(value="思政课程-添加", notes="思政课程-添加")
	@RequiresPermissions("kcSzkc:kc_szkc:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcSzkc kcSzkc) {
		kcSzkcService.save(kcSzkc);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcSzkc
	 * @return
	 */
	@AutoLog(value = "思政课程-编辑")
	@ApiOperation(value="思政课程-编辑", notes="思政课程-编辑")
	@RequiresPermissions("kcSzkc:kc_szkc:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcSzkc kcSzkc) {
		kcSzkcService.updateById(kcSzkc);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "思政课程-通过id删除")
	@ApiOperation(value="思政课程-通过id删除", notes="思政课程-通过id删除")
	@RequiresPermissions("kcSzkc:kc_szkc:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcSzkcService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "思政课程-批量删除")
	@ApiOperation(value="思政课程-批量删除", notes="思政课程-批量删除")
	@RequiresPermissions("kcSzkc:kc_szkc:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcSzkcService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "思政课程-通过id查询")
	@ApiOperation(value="思政课程-通过id查询", notes="思政课程-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcSzkc> queryById(@RequestParam(name="id",required=true) String id) {
		KcSzkc kcSzkc = kcSzkcService.getById(id);
		if(kcSzkc==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcSzkc);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcSzkc
    */
    @RequiresPermissions("kcSzkc:kc_szkc:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcSzkc kcSzkc) {
        return super.exportXls(request, kcSzkc, KcSzkc.class, "思政课程");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kcSzkc:kc_szkc:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcSzkc.class);
    }


	 @AutoLog(value = "批量思政课程-添加")
	 @ApiOperation(value="批量思政课程-添加", notes="批量思政课程-添加")
	 @PostMapping(value = "/addBatch")
	 public Result<String> addBatch(@RequestBody KcSzkc kcSzkc) {
		 List<KcKechengbiao> list = kcKechengbiaoService.getSzkcList();
		 List<KcSzkc> arrayList = new ArrayList<>();
		 for(int i=0;i<list.size();i++){
			 KcSzkc kcSzkcPar = new KcSzkc();
			 KcKechengbiao kcKechengbiaopar = list.get(i);
			 kcSzkcPar.setId(null);
			 kcSzkcPar.setKcmc(kcKechengbiaopar.getKcmc());
			 kcSzkcPar.setKcbh(kcKechengbiaopar.getKcbh());
			 kcSzkcPar.setKkdw(kcKechengbiaopar.getKkdw());
			 arrayList.add(kcSzkcPar);
		 }
		 kcSzkcService.saveBatch(arrayList);
		 return Result.OK("添加成功！");
	 }

}
