package org.jeecg.modules.kc.qa.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.qa.entity.KcEvaluationans;
import org.jeecg.modules.kc.qa.service.IKcEvaluationansService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 调查问卷-答案表
 * @Author: jeecg-boot
 * @Date:   2023-04-09
 * @Version: V1.0
 */
@Api(tags="调查问卷-答案表")
@RestController
@RequestMapping("/qa/kcEvaluationans")
@Slf4j
public class KcEvaluationansController extends JeecgController<KcEvaluationans, IKcEvaluationansService> {
	@Autowired
	private IKcEvaluationansService kcEvaluationansService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcEvaluationans
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "调查问卷-答案表-分页列表查询")
	@ApiOperation(value="调查问卷-答案表-分页列表查询", notes="调查问卷-答案表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcEvaluationans>> queryPageList(KcEvaluationans kcEvaluationans,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcEvaluationans> queryWrapper = QueryGenerator.initQueryWrapper(kcEvaluationans, req.getParameterMap());
		Page<KcEvaluationans> page = new Page<KcEvaluationans>(pageNo, pageSize);
		IPage<KcEvaluationans> pageList = kcEvaluationansService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcEvaluationans
	 * @return
	 */
	@AutoLog(value = "调查问卷-答案表-添加")
	@ApiOperation(value="调查问卷-答案表-添加", notes="调查问卷-答案表-添加")
	@RequiresPermissions("qa:kc_evaluationans:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcEvaluationans kcEvaluationans) {
		kcEvaluationansService.save(kcEvaluationans);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcEvaluationans
	 * @return
	 */
	@AutoLog(value = "调查问卷-答案表-编辑")
	@ApiOperation(value="调查问卷-答案表-编辑", notes="调查问卷-答案表-编辑")
	@RequiresPermissions("qa:kc_evaluationans:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcEvaluationans kcEvaluationans) {
		kcEvaluationansService.updateById(kcEvaluationans);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "调查问卷-答案表-通过id删除")
	@ApiOperation(value="调查问卷-答案表-通过id删除", notes="调查问卷-答案表-通过id删除")
	@RequiresPermissions("qa:kc_evaluationans:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcEvaluationansService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "调查问卷-答案表-批量删除")
	@ApiOperation(value="调查问卷-答案表-批量删除", notes="调查问卷-答案表-批量删除")
	@RequiresPermissions("qa:kc_evaluationans:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcEvaluationansService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "调查问卷-答案表-通过id查询")
	@ApiOperation(value="调查问卷-答案表-通过id查询", notes="调查问卷-答案表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcEvaluationans> queryById(@RequestParam(name="id",required=true) String id) {
		KcEvaluationans kcEvaluationans = kcEvaluationansService.getById(id);
		if(kcEvaluationans==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcEvaluationans);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcEvaluationans
    */
    @RequiresPermissions("qa:kc_evaluationans:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcEvaluationans kcEvaluationans) {
        return super.exportXls(request, kcEvaluationans, KcEvaluationans.class, "调查问卷-答案表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("qa:kc_evaluationans:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcEvaluationans.class);
    }

	 /**
	  *   添加
	  *
	  * @param kcEvaluationans
	  * @return
	  */
	 @AutoLog(value = "调查问卷-答案表-添加")
	 @ApiOperation(value="调查问卷-答案表-添加", notes="调查问卷-答案表-添加")
//	 @RequiresPermissions("qa:kc_evaluationans:add")
	 @PostMapping(value = "/addQaAll")
	 public Result<String> addQaAll(@RequestBody KcEvaluationans kcEvaluationans) {
		 kcEvaluationansService.save(kcEvaluationans);
		 return Result.OK("添加成功！");
	 }

}
