package org.jeecg.modules.kc.qa.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.qa.entity.KcOldEvaluationans;
import org.jeecg.modules.kc.qa.service.IKcOldEvaluationansService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 答案表（老系统，答案与内容混合）
 * @Author: jeecg-boot
 * @Date:   2023-05-28
 * @Version: V1.0
 */
@Api(tags="答案表（老系统，答案与内容混合）")
@RestController
@RequestMapping("/qa/kcOldEvaluationans")
@Slf4j
public class KcOldEvaluationansController extends JeecgController<KcOldEvaluationans, IKcOldEvaluationansService> {
	@Autowired
	private IKcOldEvaluationansService kcOldEvaluationansService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcOldEvaluationans
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "答案表（老系统，答案与内容混合）-分页列表查询")
	@ApiOperation(value="答案表（老系统，答案与内容混合）-分页列表查询", notes="答案表（老系统，答案与内容混合）-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcOldEvaluationans>> queryPageList(KcOldEvaluationans kcOldEvaluationans,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcOldEvaluationans> queryWrapper = QueryGenerator.initQueryWrapper(kcOldEvaluationans, req.getParameterMap());
		Page<KcOldEvaluationans> page = new Page<KcOldEvaluationans>(pageNo, pageSize);
		IPage<KcOldEvaluationans> pageList = kcOldEvaluationansService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcOldEvaluationans
	 * @return
	 */
	@AutoLog(value = "答案表（老系统，答案与内容混合）-添加")
	@ApiOperation(value="答案表（老系统，答案与内容混合）-添加", notes="答案表（老系统，答案与内容混合）-添加")
	@RequiresPermissions("qa:kc_old_evaluationans:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcOldEvaluationans kcOldEvaluationans) {
		kcOldEvaluationansService.save(kcOldEvaluationans);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcOldEvaluationans
	 * @return
	 */
	@AutoLog(value = "答案表（老系统，答案与内容混合）-编辑")
	@ApiOperation(value="答案表（老系统，答案与内容混合）-编辑", notes="答案表（老系统，答案与内容混合）-编辑")
	@RequiresPermissions("qa:kc_old_evaluationans:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcOldEvaluationans kcOldEvaluationans) {
		kcOldEvaluationansService.updateById(kcOldEvaluationans);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "答案表（老系统，答案与内容混合）-通过id删除")
	@ApiOperation(value="答案表（老系统，答案与内容混合）-通过id删除", notes="答案表（老系统，答案与内容混合）-通过id删除")
	@RequiresPermissions("qa:kc_old_evaluationans:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcOldEvaluationansService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "答案表（老系统，答案与内容混合）-批量删除")
	@ApiOperation(value="答案表（老系统，答案与内容混合）-批量删除", notes="答案表（老系统，答案与内容混合）-批量删除")
	@RequiresPermissions("qa:kc_old_evaluationans:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcOldEvaluationansService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "答案表（老系统，答案与内容混合）-通过id查询")
	@ApiOperation(value="答案表（老系统，答案与内容混合）-通过id查询", notes="答案表（老系统，答案与内容混合）-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcOldEvaluationans> queryById(@RequestParam(name="id",required=true) String id) {
		KcOldEvaluationans kcOldEvaluationans = kcOldEvaluationansService.getById(id);
		if(kcOldEvaluationans==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcOldEvaluationans);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcOldEvaluationans
    */
    @RequiresPermissions("qa:kc_old_evaluationans:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcOldEvaluationans kcOldEvaluationans) {
        return super.exportXls(request, kcOldEvaluationans, KcOldEvaluationans.class, "答案表（老系统，答案与内容混合）");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("qa:kc_old_evaluationans:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcOldEvaluationans.class);
    }

}
