package org.jeecg.modules.kc.qa.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.qa.service.IKcOldEvaluationqueService;
import org.jeecg.modules.kc.qa.entity.KcOldEvaluationque;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 调查问卷问题表(老系统)
 * @Author: jeecg-boot
 * @Date:   2023-05-28
 * @Version: V1.0
 */
@Api(tags="调查问卷问题表(老系统)")
@RestController
@RequestMapping("/qa/kcOldEvaluationque")
@Slf4j
public class KcOldEvaluationqueController extends JeecgController<KcOldEvaluationque, IKcOldEvaluationqueService> {
	@Autowired
	private IKcOldEvaluationqueService kcOldEvaluationqueService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcOldEvaluationque
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "调查问卷问题表(老系统)-分页列表查询")
	@ApiOperation(value="调查问卷问题表(老系统)-分页列表查询", notes="调查问卷问题表(老系统)-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcOldEvaluationque>> queryPageList(KcOldEvaluationque kcOldEvaluationque,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcOldEvaluationque> queryWrapper = QueryGenerator.initQueryWrapper(kcOldEvaluationque, req.getParameterMap());
		Page<KcOldEvaluationque> page = new Page<KcOldEvaluationque>(pageNo, pageSize);
		IPage<KcOldEvaluationque> pageList = kcOldEvaluationqueService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcOldEvaluationque
	 * @return
	 */
	@AutoLog(value = "调查问卷问题表(老系统)-添加")
	@ApiOperation(value="调查问卷问题表(老系统)-添加", notes="调查问卷问题表(老系统)-添加")
	@RequiresPermissions("qa:kc_old_evaluationque:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcOldEvaluationque kcOldEvaluationque) {
		kcOldEvaluationqueService.save(kcOldEvaluationque);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcOldEvaluationque
	 * @return
	 */
	@AutoLog(value = "调查问卷问题表(老系统)-编辑")
	@ApiOperation(value="调查问卷问题表(老系统)-编辑", notes="调查问卷问题表(老系统)-编辑")
	@RequiresPermissions("qa:kc_old_evaluationque:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcOldEvaluationque kcOldEvaluationque) {
		kcOldEvaluationqueService.updateById(kcOldEvaluationque);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "调查问卷问题表(老系统)-通过id删除")
	@ApiOperation(value="调查问卷问题表(老系统)-通过id删除", notes="调查问卷问题表(老系统)-通过id删除")
	@RequiresPermissions("qa:kc_old_evaluationque:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcOldEvaluationqueService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "调查问卷问题表(老系统)-批量删除")
	@ApiOperation(value="调查问卷问题表(老系统)-批量删除", notes="调查问卷问题表(老系统)-批量删除")
	@RequiresPermissions("qa:kc_old_evaluationque:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcOldEvaluationqueService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "调查问卷问题表(老系统)-通过id查询")
	@ApiOperation(value="调查问卷问题表(老系统)-通过id查询", notes="调查问卷问题表(老系统)-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcOldEvaluationque> queryById(@RequestParam(name="id",required=true) String id) {
		KcOldEvaluationque kcOldEvaluationque = kcOldEvaluationqueService.getById(id);
		if(kcOldEvaluationque==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcOldEvaluationque);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcOldEvaluationque
    */
    @RequiresPermissions("qa:kc_old_evaluationque:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcOldEvaluationque kcOldEvaluationque) {
        return super.exportXls(request, kcOldEvaluationque, KcOldEvaluationque.class, "调查问卷问题表(老系统)");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("qa:kc_old_evaluationque:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcOldEvaluationque.class);
    }

}
