package org.jeecg.modules.kc.teachingunitcontent.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.kc.teachingunitcontent.entity.KcTeachingUnitContentThree;
import org.jeecg.modules.kc.teachingunitcontent.service.IKcTeachingUnitContentThreeService;
import org.jeecg.modules.tools.Global;
import org.jeecg.modules.zyk.entity.ZykInfo;
import org.jeecg.modules.zyk.service.IZykService;
import org.jeecg.modules.zyk.utils.WjlxEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Map;

 /**
 * @Description: 教学单元内容-第三层
 * @Author: jeecg-boot
 * @Date:   2024-05-15
 * @Version: V1.0
 */
@Api(tags="教学单元内容-第三层")
@RestController
@RequestMapping("/teachingunitcontent/kcTeachingUnitContentThree")
@Slf4j
public class KcTeachingUnitContentThreeController extends JeecgController<KcTeachingUnitContentThree, IKcTeachingUnitContentThreeService> {
	@Autowired
	private IKcTeachingUnitContentThreeService kcTeachingUnitContentThreeService;

	 @Value("${jeecg.path.upload}")
	 private String upLoadPath;
	 @Autowired
	 private IZykService zykService;
	 @Autowired
	 private Global global;
	 @Value(value="${jeecg.uploadType}")
	 private String uploadType;

	 /**
	 * 分页列表查询
	 *
	 * @param kcTeachingUnitContentThree
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "教学单元内容-第三层-分页列表查询")
	@ApiOperation(value="教学单元内容-第三层-分页列表查询", notes="教学单元内容-第三层-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcTeachingUnitContentThree>> queryPageList(KcTeachingUnitContentThree kcTeachingUnitContentThree,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcTeachingUnitContentThree> queryWrapper = QueryGenerator.initQueryWrapper(kcTeachingUnitContentThree, req.getParameterMap());
		Page<KcTeachingUnitContentThree> page = new Page<KcTeachingUnitContentThree>(pageNo, pageSize);
		IPage<KcTeachingUnitContentThree> pageList = kcTeachingUnitContentThreeService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcTeachingUnitContentThree
	 * @return
	 */
	@AutoLog(value = "教学单元内容-第三层-添加")
	@ApiOperation(value="教学单元内容-第三层-添加", notes="教学单元内容-第三层-添加")
//	@RequiresPermissions("teachingunitcontent:kc_teaching_unit_content_three:add")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody KcTeachingUnitContentThree kcTeachingUnitContentThree) {
		kcTeachingUnitContentThreeService.save(kcTeachingUnitContentThree);

		if(StringUtils.equals("sftp",uploadType)){
			ZykInfo zykInfo = new ZykInfo();
			zykInfo.setBizId(kcTeachingUnitContentThree.getId());
			zykInfo.setBizTable("kc_teaching_unit_content_three");
			zykInfo.setWjlx(WjlxEnum.JXDY.getType());
			zykInfo.setRwbh(kcTeachingUnitContentThree.getRwbh());
			zykInfo.setFileName(kcTeachingUnitContentThree.getFilePath());
			Map<String,String> map = zykService.saveToZykJxdg(zykInfo);
			zykService.disConnect();
		}else{
			ZykInfo zykInfo = new ZykInfo();
			zykInfo.setBizId(kcTeachingUnitContentThree.getId());
			zykInfo.setBizTable("kc_teaching_unit_content_three");
			zykInfo.setWjlx(WjlxEnum.JXDY.getType());
			zykInfo.setRwbh(kcTeachingUnitContentThree.getRwbh());
			zykInfo.setFileName(kcTeachingUnitContentThree.getFilePath());
			zykService.saveLocal(zykInfo);
		}


		Result<KcTeachingUnitContentThree> r = Result.OK("添加成功！");
		r.setResult(kcTeachingUnitContentThree);
		return r;
	}

	/**
	 *  编辑
	 *
	 * @param kcTeachingUnitContentThree
	 * @return
	 */
	@AutoLog(value = "教学单元内容-第三层-编辑")
	@ApiOperation(value="教学单元内容-第三层-编辑", notes="教学单元内容-第三层-编辑")
//	@RequiresPermissions("teachingunitcontent:kc_teaching_unit_content_three:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcTeachingUnitContentThree kcTeachingUnitContentThree) {
		kcTeachingUnitContentThreeService.updateById(kcTeachingUnitContentThree);
		return Result.OK("编辑成功!");
	}

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "教学单元内容-第三层-通过id删除")
	@ApiOperation(value="教学单元内容-第三层-通过id删除", notes="教学单元内容-第三层-通过id删除")
//	@RequiresPermissions("teachingunitcontent:kc_teaching_unit_content_three:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcTeachingUnitContentThreeService.removeById(id);
		return Result.OK("删除成功!");
	}
//
//	/**
//	 *  批量删除
//	 *
//	 * @param ids
//	 * @return
//	 */
//	@AutoLog(value = "教学单元内容-第三层-批量删除")
//	@ApiOperation(value="教学单元内容-第三层-批量删除", notes="教学单元内容-第三层-批量删除")
//	@RequiresPermissions("teachingunitcontent:kc_teaching_unit_content_three:deleteBatch")
//	@DeleteMapping(value = "/deleteBatch")
//	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
//		this.kcTeachingUnitContentThreeService.removeByIds(Arrays.asList(ids.split(",")));
//		return Result.OK("批量删除成功!");
//	}
//
//	/**
//	 * 通过id查询
//	 *
//	 * @param id
//	 * @return
//	 */
//	//@AutoLog(value = "教学单元内容-第三层-通过id查询")
//	@ApiOperation(value="教学单元内容-第三层-通过id查询", notes="教学单元内容-第三层-通过id查询")
//	@GetMapping(value = "/queryById")
//	public Result<KcTeachingUnitContentThree> queryById(@RequestParam(name="id",required=true) String id) {
//		KcTeachingUnitContentThree kcTeachingUnitContentThree = kcTeachingUnitContentThreeService.getById(id);
//		if(kcTeachingUnitContentThree==null) {
//			return Result.error("未找到对应数据");
//		}
//		return Result.OK(kcTeachingUnitContentThree);
//	}
//
//    /**
//    * 导出excel
//    *
//    * @param request
//    * @param kcTeachingUnitContentThree
//    */
//    @RequiresPermissions("teachingunitcontent:kc_teaching_unit_content_three:exportXls")
//    @RequestMapping(value = "/exportXls")
//    public ModelAndView exportXls(HttpServletRequest request, KcTeachingUnitContentThree kcTeachingUnitContentThree) {
//        return super.exportXls(request, kcTeachingUnitContentThree, KcTeachingUnitContentThree.class, "教学单元内容-第三层");
//    }
//
//    /**
//      * 通过excel导入数据
//    *
//    * @param request
//    * @param response
//    * @return
//    */
//    @RequiresPermissions("teachingunitcontent:kc_teaching_unit_content_three:importExcel")
//    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
//    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
//        return super.importExcel(request, response, KcTeachingUnitContentThree.class);
//    }

}
