package org.jeecg.modules.kc.teachingunitcontent.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.jeecg.modules.kc.teachingunitcontent.entity.KcTeachingUnitContentOne;
import org.jeecg.modules.kc.teachingunitcontent.entity.KcTeachingUnitContentThree;
import org.jeecg.modules.kc.teachingunitcontent.entity.KcTeachingUnitContentTwo;
import org.jeecg.modules.kc.teachingunitcontent.mapper.KcTeachingUnitContentOneMapper;
import org.jeecg.modules.kc.teachingunitcontent.service.IKcTeachingUnitContentOneService;
import org.jeecg.modules.kc.teachingunitcontent.service.IKcTeachingUnitContentThreeService;
import org.jeecg.modules.kc.teachingunitcontent.service.IKcTeachingUnitContentTwoService;
import org.jeecg.modules.kc.teachingunitcontent.vo.KcTeachingUnitContentSave;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @Description: 教学单元内容-第一层
 * @Author: jeecg-boot
 * @Date:   2024-05-15
 * @Version: V1.0
 */
@Service
public class KcTeachingUnitContentOneServiceImpl extends ServiceImpl<KcTeachingUnitContentOneMapper, KcTeachingUnitContentOne> implements IKcTeachingUnitContentOneService {

	@Autowired
	private IKcTeachingUnitContentTwoService kcTeachingUnitContentTwoService;

	@Autowired
	private IKcTeachingUnitContentThreeService kcTeachingUnitContentThreeService;

	@Transactional(rollbackFor = {java.lang.Exception.class})
	@Override
	public void saveAll(KcTeachingUnitContentSave teachingUnitContentSave) {
		String xqxn = teachingUnitContentSave.getXqxn();
		String rwbh = teachingUnitContentSave.getRwbh();
		teachingUnitContentSave.getTeachingUnitContentOneList().forEach(x -> {
			x.setXqxn(xqxn);
			x.setRwbh(rwbh);
		});
		//保存主表
		saveBatch(teachingUnitContentSave.getTeachingUnitContentOneList());

		//保存第二层
		teachingUnitContentSave.getTeachingUnitContentOneList().forEach(x1 -> {
			if(x1.getChildrenList() != null && !x1.getChildrenList().isEmpty()){
				x1.getChildrenList().forEach(x2 -> {
					x2.setPid(x1.getId());
					x2.setXqxn(xqxn);
					x2.setRwbh(rwbh);
				});
				kcTeachingUnitContentTwoService.saveBatch(x1.getChildrenList());
			}
		});


		//保存三层
		teachingUnitContentSave.getTeachingUnitContentOneList().forEach(x1 -> {
			if(x1.getChildrenList() != null && !x1.getChildrenList().isEmpty()){
				x1.getChildrenList().forEach(x2 -> {
					if(x2.getChildrenList() != null && !x2.getChildrenList().isEmpty()){
						x2.getChildrenList().forEach(x3 -> {
							x3.setPid(x2.getId());
							x3.setXqxn(xqxn);
							x3.setRwbh(rwbh);
						});
						kcTeachingUnitContentThreeService.saveBatch(x2.getChildrenList());
					}
				});
			}
		});
	}

	@Transactional(rollbackFor = {java.lang.Exception.class})
	@Override
	public void updateAllById(KcTeachingUnitContentSave teachingUnitContentSave) {
		String xqxn = teachingUnitContentSave.getXqxn();
		String rwbh = teachingUnitContentSave.getRwbh();

		QueryWrapper<KcTeachingUnitContentOne> oneQw = new QueryWrapper<>();
		oneQw.lambda().eq(KcTeachingUnitContentOne::getXqxn, xqxn);
		oneQw.lambda().eq(KcTeachingUnitContentOne::getRwbh, rwbh);
		QueryWrapper<KcTeachingUnitContentTwo> twoQw = new QueryWrapper<>();
		twoQw.lambda().eq(KcTeachingUnitContentTwo::getXqxn, xqxn);
		twoQw.lambda().eq(KcTeachingUnitContentTwo::getRwbh, rwbh);
		QueryWrapper<KcTeachingUnitContentThree> threeQw = new QueryWrapper<>();
		threeQw.lambda().eq(KcTeachingUnitContentThree::getXqxn, xqxn);
		threeQw.lambda().eq(KcTeachingUnitContentThree::getRwbh, rwbh);

		remove(oneQw);
		kcTeachingUnitContentTwoService.remove(twoQw);
		kcTeachingUnitContentThreeService.remove(threeQw);

		saveAll(teachingUnitContentSave);
	}

	@Override
	public List<KcTeachingUnitContentOne> getAllList(KcTeachingUnitContentOne kcTeachingUnitContentOne) {
		return baseMapper.getAllList(kcTeachingUnitContentOne);
	}
}
