package org.jeecg.modules.kc.tksf.kctkcstj.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.tksf.kctkcstj.entity.KcTkcstj;
import org.jeecg.modules.kc.tksf.kctkcstj.service.IKcTkcstjService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 听课次数统计
 * @Author: jeecg-boot
 * @Date:   2023-05-27
 * @Version: V1.0
 */
@Api(tags="听课次数统计")
@RestController
@RequestMapping("/kctkcstj/kcTkcstj")
@Slf4j
public class KcTkcstjController extends JeecgController<KcTkcstj, IKcTkcstjService> {
	@Autowired
	private IKcTkcstjService kcTkcstjService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcTkcstj
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "听课次数统计-分页列表查询")
	@ApiOperation(value="听课次数统计-分页列表查询", notes="听课次数统计-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcTkcstj>> queryPageList(KcTkcstj kcTkcstj,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcTkcstj> queryWrapper = QueryGenerator.initQueryWrapper(kcTkcstj, req.getParameterMap());
		Page<KcTkcstj> page = new Page<KcTkcstj>(pageNo, pageSize);
		IPage<KcTkcstj> pageList = kcTkcstjService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcTkcstj
	 * @return
	 */
	@AutoLog(value = "听课次数统计-添加")
	@ApiOperation(value="听课次数统计-添加", notes="听课次数统计-添加")
	@RequiresPermissions("kctkcstj:kc_tkcstj:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcTkcstj kcTkcstj) {
		kcTkcstjService.save(kcTkcstj);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcTkcstj
	 * @return
	 */
	@AutoLog(value = "听课次数统计-编辑")
	@ApiOperation(value="听课次数统计-编辑", notes="听课次数统计-编辑")
	@RequiresPermissions("kctkcstj:kc_tkcstj:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcTkcstj kcTkcstj) {
		kcTkcstjService.updateById(kcTkcstj);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "听课次数统计-通过id删除")
	@ApiOperation(value="听课次数统计-通过id删除", notes="听课次数统计-通过id删除")
	@RequiresPermissions("kctkcstj:kc_tkcstj:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcTkcstjService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "听课次数统计-批量删除")
	@ApiOperation(value="听课次数统计-批量删除", notes="听课次数统计-批量删除")
	@RequiresPermissions("kctkcstj:kc_tkcstj:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcTkcstjService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "听课次数统计-通过id查询")
	@ApiOperation(value="听课次数统计-通过id查询", notes="听课次数统计-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcTkcstj> queryById(@RequestParam(name="id",required=true) String id) {
		KcTkcstj kcTkcstj = kcTkcstjService.getById(id);
		if(kcTkcstj==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcTkcstj);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param kcTkcstj
    */
    @RequiresPermissions("kctkcstj:kc_tkcstj:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, KcTkcstj kcTkcstj) {
        return super.exportXls(request, kcTkcstj, KcTkcstj.class, "听课次数统计");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("kctkcstj:kc_tkcstj:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, KcTkcstj.class);
    }

}
