package org.jeecg.modules.kc.tksf.kctksfyq.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.tksf.kctksfyq.entity.KcTksfyq;
import org.jeecg.modules.kc.tksf.kctksfyq.service.IKcTksfyqService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 听课身份要求
 * @Author: jeecg-boot
 * @Date:   2023-05-27
 * @Version: V1.0
 */
@Api(tags="听课身份要求")
@RestController
@RequestMapping("/kctksfyq/kcTksfyq")
@Slf4j
public class KcTksfyqController extends JeecgController<KcTksfyq, IKcTksfyqService> {
	@Autowired
	private IKcTksfyqService kcTksfyqService;
	
	/**
	 * 分页列表查询
	 *
	 * @param kcTksfyq
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "听课身份要求-分页列表查询")
	@ApiOperation(value="听课身份要求-分页列表查询", notes="听课身份要求-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<KcTksfyq>> queryPageList(KcTksfyq kcTksfyq,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<KcTksfyq> queryWrapper = QueryGenerator.initQueryWrapper(kcTksfyq, req.getParameterMap());
		Page<KcTksfyq> page = new Page<KcTksfyq>(pageNo, pageSize);
		IPage<KcTksfyq> pageList = kcTksfyqService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param kcTksfyq
	 * @return
	 */
	@AutoLog(value = "听课身份要求-添加")
	@ApiOperation(value="听课身份要求-添加", notes="听课身份要求-添加")
//	@RequiresPermissions("kctksfyq:kc_tksfyq:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody KcTksfyq kcTksfyq) {

		kcTksfyqService.saveOrEdit(kcTksfyq);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param kcTksfyq
	 * @return
	 */
	@AutoLog(value = "听课身份要求-编辑")
	@ApiOperation(value="听课身份要求-编辑", notes="听课身份要求-编辑")
//	@RequiresPermissions("kctksfyq:kc_tksfyq:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody KcTksfyq kcTksfyq) {
		kcTksfyqService.updateById(kcTksfyq);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "听课身份要求-通过id删除")
	@ApiOperation(value="听课身份要求-通过id删除", notes="听课身份要求-通过id删除")
//	@RequiresPermissions("kctksfyq:kc_tksfyq:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		kcTksfyqService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "听课身份要求-批量删除")
	@ApiOperation(value="听课身份要求-批量删除", notes="听课身份要求-批量删除")
//	@RequiresPermissions("kctksfyq:kc_tksfyq:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.kcTksfyqService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "听课身份要求-通过id查询")
	@ApiOperation(value="听课身份要求-通过id查询", notes="听课身份要求-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<KcTksfyq> queryById(@RequestParam(name="id",required=true) String id) {
		KcTksfyq kcTksfyq = kcTksfyqService.getById(id);
		if(kcTksfyq==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(kcTksfyq);
	}
//
//    /**
//    * 导出excel
//    *
//    * @param request
//    * @param kcTksfyq
//    */
//    @RequiresPermissions("kctksfyq:kc_tksfyq:exportXls")
//    @RequestMapping(value = "/exportXls")
//    public ModelAndView exportXls(HttpServletRequest request, KcTksfyq kcTksfyq) {
//        return super.exportXls(request, kcTksfyq, KcTksfyq.class, "听课身份要求");
//    }
//
//    /**
//      * 通过excel导入数据
//    *
//    * @param request
//    * @param response
//    * @return
//    */
//    @RequiresPermissions("kctksfyq:kc_tksfyq:importExcel")
//    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
//    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
//        return super.importExcel(request, response, KcTksfyq.class);
//    }

}
