package org.jeecg.modules.kc.zyCcjg.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.common.util.text.StringUtils;
import org.jeecg.modules.kc.zyCcjg.entity.ZyCcjg;
import org.jeecg.modules.kc.zyCcjg.service.IZyCcjgService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 查重结果
 * @Author: jeecg-boot
 * @Date:   2024-05-07
 * @Version: V1.0
 */
@Api(tags="查重结果")
@RestController
@RequestMapping("/zyCcjg/zyCcjg")
@Slf4j
public class ZyCcjgController extends JeecgController<ZyCcjg, IZyCcjgService> {
	@Autowired
	private IZyCcjgService zyCcjgService;
	
	/**
	 * 分页列表查询
	 *
	 * @param zyCcjg
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "查重结果-分页列表查询")
	@ApiOperation(value="查重结果-分页列表查询", notes="查重结果-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ZyCcjg>> queryPageList(ZyCcjg zyCcjg,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ZyCcjg> queryWrapper = QueryGenerator.initQueryWrapper(zyCcjg, req.getParameterMap());
		Page<ZyCcjg> page = new Page<ZyCcjg>(pageNo, pageSize);
		IPage<ZyCcjg> pageList = zyCcjgService.page(page, queryWrapper);
		return Result.OK(pageList);
	}




	 @ApiOperation(value="查询作业检测问题数据", notes="查询作业检测问题数据")
	 @GetMapping(value = "/getQuaList")
	 public Result<IPage<ZyCcjg>> getQuaList(ZyCcjg zyCcjg,
												@RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
												@RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
												HttpServletRequest req) {

		 //查询作业查重结果
//		 zyCcjgService.getCcjg();

		 QueryWrapper<ZyCcjg> queryWrapper = QueryGenerator.initQueryWrapper("a",zyCcjg, req.getParameterMap());
		 if(StringUtils.isEmpty(zyCcjg.getFilestateid())){
			 queryWrapper.in("a.filestateid",1,3);
		 }
		 if(StringUtils.isNotEmpty(zyCcjg.getStuNo())){
			 queryWrapper.like("b.create_by",zyCcjg.getStuNo());
		 }
		 if(StringUtils.isNotEmpty(zyCcjg.getStuName())){
			 queryWrapper.like("b.student_name",zyCcjg.getStuName());
		 }
		 Page<ZyCcjg> page = new Page<ZyCcjg>(pageNo, pageSize);
		 IPage<ZyCcjg> pageList = zyCcjgService.getQuaList(page, queryWrapper);
		 return Result.OK(pageList);
	 }
	/**
	 *   添加
	 *
	 * @param zyCcjg
	 * @return
	 */
	@AutoLog(value = "查重结果-添加")
	@ApiOperation(value="查重结果-添加", notes="查重结果-添加")
	@RequiresPermissions("zyCcjg:zy_ccjg:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ZyCcjg zyCcjg) {
		zyCcjgService.save(zyCcjg);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param zyCcjg
	 * @return
	 */
	@AutoLog(value = "查重结果-编辑")
	@ApiOperation(value="查重结果-编辑", notes="查重结果-编辑")
	@RequiresPermissions("zyCcjg:zy_ccjg:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ZyCcjg zyCcjg) {
		zyCcjgService.updateById(zyCcjg);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "查重结果-通过id删除")
	@ApiOperation(value="查重结果-通过id删除", notes="查重结果-通过id删除")
	@RequiresPermissions("zyCcjg:zy_ccjg:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		zyCcjgService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "查重结果-批量删除")
	@ApiOperation(value="查重结果-批量删除", notes="查重结果-批量删除")
	@RequiresPermissions("zyCcjg:zy_ccjg:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.zyCcjgService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "查重结果-通过id查询")
	@ApiOperation(value="查重结果-通过id查询", notes="查重结果-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ZyCcjg> queryById(@RequestParam(name="id",required=true) String id) {
		ZyCcjg zyCcjg = zyCcjgService.getById(id);
		if(zyCcjg==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(zyCcjg);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param zyCcjg
    */
    @RequiresPermissions("zyCcjg:zy_ccjg:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ZyCcjg zyCcjg) {
        return super.exportXls(request, zyCcjg, ZyCcjg.class, "查重结果");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("zyCcjg:zy_ccjg:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ZyCcjg.class);
    }

	 @ApiOperation(value="查重结果-分页列表查询", notes="查重结果-分页列表查询")
	 @GetMapping(value = "/ccjglist")
	 public Result<List<ZyCcjg>> ccjglist(ZyCcjg zyCcjg, HttpServletRequest req) {
		 QueryWrapper<ZyCcjg> queryWrapper = QueryGenerator.initQueryWrapper(zyCcjg, req.getParameterMap());
		 List<ZyCcjg> pageList = zyCcjgService.ccjglist(queryWrapper);
		 return Result.OK(pageList);
	 }


	 @ApiOperation(value="查重结果-分页列表查询", notes="查重结果-分页列表查询")
	 @GetMapping(value = "/getCcjg")
	 public Result<ZyCcjg> getCcjg(ZyCcjg zyCcjg, HttpServletRequest req) {
		 QueryWrapper<ZyCcjg> queryWrapper = QueryGenerator.initQueryWrapper(zyCcjg, req.getParameterMap());
//		 queryWrapper.eq("zy_stu_id",zyCcjg.getZyStuId());
//		 queryWrapper.eq("cc_type",zyCcjg.getCcType());
		 queryWrapper.orderByDesc("checkdate");
		 queryWrapper.last("limit 1");
		 ZyCcjg par = zyCcjgService.getOne(queryWrapper);
		 return Result.OK(par);
	 }

}
