package org.jeecg.modules.kc.zyCjwt.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.zyCjwt.entity.ZyCjwt;
import org.jeecg.modules.kc.zyCjwt.service.IZyCjwtService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 常见问题
 * @Author: jeecg-boot
 * @Date:   2024-05-11
 * @Version: V1.0
 */
@Api(tags="常见问题")
@RestController
@RequestMapping("/zyCjwt/zyCjwt")
@Slf4j
public class ZyCjwtController extends JeecgController<ZyCjwt, IZyCjwtService> {
	@Autowired
	private IZyCjwtService zyCjwtService;
	
	/**
	 * 分页列表查询
	 *
	 * @param zyCjwt
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "常见问题-分页列表查询")
	@ApiOperation(value="常见问题-分页列表查询", notes="常见问题-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ZyCjwt>> queryPageList(ZyCjwt zyCjwt,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ZyCjwt> queryWrapper = QueryGenerator.initQueryWrapper(zyCjwt, req.getParameterMap());
		Page<ZyCjwt> page = new Page<ZyCjwt>(pageNo, pageSize);
		queryWrapper.eq(StringUtils.isNotBlank(zyCjwt.getTeano()),"create_by",zyCjwt.getTeano());
		IPage<ZyCjwt> pageList = zyCjwtService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param zyCjwt
	 * @return
	 */
	@AutoLog(value = "常见问题-添加")
	@ApiOperation(value="常见问题-添加", notes="常见问题-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ZyCjwt zyCjwt) {
		zyCjwtService.save(zyCjwt);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param zyCjwt
	 * @return
	 */
	@AutoLog(value = "常见问题-编辑")
	@ApiOperation(value="常见问题-编辑", notes="常见问题-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ZyCjwt zyCjwt) {
		zyCjwtService.updateById(zyCjwt);
		return Result.OK("操作成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "常见问题-通过id删除")
	@ApiOperation(value="常见问题-通过id删除", notes="常见问题-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		zyCjwtService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "常见问题-批量删除")
	@ApiOperation(value="常见问题-批量删除", notes="常见问题-批量删除")
	@RequiresPermissions("zyCjwt:zy_cjwt:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.zyCjwtService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "常见问题-通过id查询")
	@ApiOperation(value="常见问题-通过id查询", notes="常见问题-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ZyCjwt> queryById(@RequestParam(name="id",required=true) String id) {
		ZyCjwt zyCjwt = zyCjwtService.getById(id);
		if(zyCjwt==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(zyCjwt);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param zyCjwt
    */
    @RequiresPermissions("zyCjwt:zy_cjwt:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ZyCjwt zyCjwt) {
        return super.exportXls(request, zyCjwt, ZyCjwt.class, "常见问题");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("zyCjwt:zy_cjwt:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ZyCjwt.class);
    }

}
