package org.jeecg.modules.kc.zyDbtx.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.zyDbtx.entity.ZyDbtx;
import org.jeecg.modules.kc.zyDbtx.service.IZyDbtxService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 代办提醒
 * @Author: jeecg-boot
 * @Date:   2024-05-24
 * @Version: V1.0
 */
@Api(tags="代办提醒")
@RestController
@RequestMapping("/zyDbtx/zyDbtx")
@Slf4j
public class ZyDbtxController extends JeecgController<ZyDbtx, IZyDbtxService> {
	@Autowired
	private IZyDbtxService zyDbtxService;
	
	/**
	 * 分页列表查询
	 *
	 * @param zyDbtx
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "代办提醒-分页列表查询")
	@ApiOperation(value="代办提醒-分页列表查询", notes="代办提醒-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ZyDbtx>> queryPageList(ZyDbtx zyDbtx,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ZyDbtx> queryWrapper = QueryGenerator.initQueryWrapper(zyDbtx, req.getParameterMap());
		queryWrapper.orderByDesc("create_time");
		Page<ZyDbtx> page = new Page<ZyDbtx>(pageNo, pageSize);
		IPage<ZyDbtx> pageList = zyDbtxService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param zyDbtx
	 * @return
	 */
	@AutoLog(value = "代办提醒-添加")
	@ApiOperation(value="代办提醒-添加", notes="代办提醒-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ZyDbtx zyDbtx) {
		zyDbtxService.save(zyDbtx);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param zyDbtx
	 * @return
	 */
	@AutoLog(value = "代办提醒-编辑")
	@ApiOperation(value="代办提醒-编辑", notes="代办提醒-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ZyDbtx zyDbtx) {
		zyDbtxService.updateById(zyDbtx);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "代办提醒-通过id删除")
	@ApiOperation(value="代办提醒-通过id删除", notes="代办提醒-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		zyDbtxService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "代办提醒-批量删除")
	@ApiOperation(value="代办提醒-批量删除", notes="代办提醒-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.zyDbtxService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "代办提醒-通过id查询")
	@ApiOperation(value="代办提醒-通过id查询", notes="代办提醒-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ZyDbtx> queryById(@RequestParam(name="id",required=true) String id) {
		ZyDbtx zyDbtx = zyDbtxService.getById(id);
		if(zyDbtx==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(zyDbtx);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param zyDbtx
    */
    @RequiresPermissions("zyDbtx:zy_dbtx:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ZyDbtx zyDbtx) {
        return super.exportXls(request, zyDbtx, ZyDbtx.class, "代办提醒");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("zyDbtx:zy_dbtx:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ZyDbtx.class);
    }


	 @AutoLog(value = "代办提醒-通过rwbh修改已阅")
	 @ApiOperation(value="代办提醒-通过rwbh修改已阅", notes="代办提醒-通过rwbh修改已阅")
	 @PostMapping(value = "/deleteByRwbhCreate")
	 public Result<ZyDbtx> deleteByRwbhCreate(@RequestBody ZyDbtx zyDbtx) {
		String rwbh = zyDbtx.getRwbh();
		 LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
		 UpdateWrapper<ZyDbtx> zyDbtxDeleteMapping = new UpdateWrapper<>();
		 zyDbtxDeleteMapping.set("flag","1");
		 zyDbtxDeleteMapping.eq("rwbh", rwbh);
		 zyDbtxDeleteMapping.eq("create_by", sysUser.getUsername());
//		 zyDbtxDeleteMapping.eq("fbr", zyDbtx.getFbr());
		 zyDbtxService.update(zyDbtxDeleteMapping);
		 return Result.OK(null);
	 }

	 @AutoLog(value = "代办提醒-阅读信息")
	 @ApiOperation(value="代办提醒-阅读信息", notes="代办提醒-阅读信息")
	 @PostMapping(value = "/deleteById")
	 public Result<ZyDbtx> deleteById(@RequestBody ZyDbtx zyDbtx) {
		 zyDbtx.setFlag("1");
		 zyDbtxService.updateById(zyDbtx);
		 return Result.OK(null);
	 }
}
