package org.jeecg.modules.kc.zyInfoScjl.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.zyInfoScjl.entity.ZyInfoScjl;
import org.jeecg.modules.kc.zyInfoScjl.service.IZyInfoScjlService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 作业上传记录
 * @Author: jeecg-boot
 * @Date:   2024-09-03
 * @Version: V1.0
 */
@Api(tags="作业上传记录")
@RestController
@RequestMapping("/zyInfoScjl/zyInfoScjl")
@Slf4j
public class ZyInfoScjlController extends JeecgController<ZyInfoScjl, IZyInfoScjlService> {
	@Autowired
	private IZyInfoScjlService zyInfoScjlService;
	
	/**
	 * 分页列表查询
	 *
	 * @param zyInfoScjl
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "作业上传记录-分页列表查询")
	@ApiOperation(value="作业上传记录-分页列表查询", notes="作业上传记录-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ZyInfoScjl>> queryPageList(ZyInfoScjl zyInfoScjl,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ZyInfoScjl> queryWrapper = QueryGenerator.initQueryWrapper(zyInfoScjl, req.getParameterMap());
		Page<ZyInfoScjl> page = new Page<ZyInfoScjl>(pageNo, pageSize);
		IPage<ZyInfoScjl> pageList = zyInfoScjlService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param zyInfoScjl
	 * @return
	 */
	@AutoLog(value = "作业上传记录-添加")
	@ApiOperation(value="作业上传记录-添加", notes="作业上传记录-添加")
	@RequiresPermissions("zyInfoScjl:zy_info_scjl:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ZyInfoScjl zyInfoScjl) {
		zyInfoScjlService.save(zyInfoScjl);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param zyInfoScjl
	 * @return
	 */
	@AutoLog(value = "作业上传记录-编辑")
	@ApiOperation(value="作业上传记录-编辑", notes="作业上传记录-编辑")
	@RequiresPermissions("zyInfoScjl:zy_info_scjl:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ZyInfoScjl zyInfoScjl) {
		zyInfoScjlService.updateById(zyInfoScjl);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "作业上传记录-通过id删除")
	@ApiOperation(value="作业上传记录-通过id删除", notes="作业上传记录-通过id删除")
	@RequiresPermissions("zyInfoScjl:zy_info_scjl:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		zyInfoScjlService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "作业上传记录-批量删除")
	@ApiOperation(value="作业上传记录-批量删除", notes="作业上传记录-批量删除")
	@RequiresPermissions("zyInfoScjl:zy_info_scjl:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.zyInfoScjlService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "作业上传记录-通过id查询")
	@ApiOperation(value="作业上传记录-通过id查询", notes="作业上传记录-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ZyInfoScjl> queryById(@RequestParam(name="id",required=true) String id) {
		ZyInfoScjl zyInfoScjl = zyInfoScjlService.getById(id);
		if(zyInfoScjl==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(zyInfoScjl);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param zyInfoScjl
    */
    @RequiresPermissions("zyInfoScjl:zy_info_scjl:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ZyInfoScjl zyInfoScjl) {
        return super.exportXls(request, zyInfoScjl, ZyInfoScjl.class, "作业上传记录");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("zyInfoScjl:zy_info_scjl:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ZyInfoScjl.class);
    }

}
