package org.jeecg.modules.kc.zyInfoStudentPcz.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.zyInfo.entity.ZyInfo;
import org.jeecg.modules.kc.zyInfoStudent.entity.ZyInfoStudent;
import org.jeecg.modules.kc.zyInfoStudentPcz.entity.ZyInfoStudentPcz;
import org.jeecg.modules.kc.zyInfoStudentPcz.service.IZyInfoStudentPczService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 作业偏差值
 * @Author: jeecg-boot
 * @Date:   2024-07-31
 * @Version: V1.0
 */
@Api(tags="作业偏差值")
@RestController
@RequestMapping("/zyInfoStudentPcz/zyInfoStudentPcz")
@Slf4j
public class ZyInfoStudentPczController extends JeecgController<ZyInfoStudentPcz, IZyInfoStudentPczService> {
	@Autowired
	private IZyInfoStudentPczService zyInfoStudentPczService;
	
	/**
	 * 分页列表查询
	 *
	 * @param zyInfoStudentPcz
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "作业偏差值-分页列表查询")
	@ApiOperation(value="作业偏差值-分页列表查询", notes="作业偏差值-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ZyInfoStudentPcz>> queryPageList(ZyInfoStudentPcz zyInfoStudentPcz,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ZyInfoStudentPcz> queryWrapper = QueryGenerator.initQueryWrapper(zyInfoStudentPcz, req.getParameterMap());
		Page<ZyInfoStudentPcz> page = new Page<ZyInfoStudentPcz>(pageNo, pageSize);
		IPage<ZyInfoStudentPcz> pageList = zyInfoStudentPczService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param zyInfoStudentPcz
	 * @return
	 */
	@AutoLog(value = "作业偏差值-添加")
	@ApiOperation(value="作业偏差值-添加", notes="作业偏差值-添加")
	@RequiresPermissions("zyInfoStudentPcz:zy_info_student_pcz:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ZyInfoStudentPcz zyInfoStudentPcz) {
		zyInfoStudentPczService.save(zyInfoStudentPcz);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param zyInfoStudentPcz
	 * @return
	 */
	@AutoLog(value = "作业偏差值-编辑")
	@ApiOperation(value="作业偏差值-编辑", notes="作业偏差值-编辑")
	@RequiresPermissions("zyInfoStudentPcz:zy_info_student_pcz:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ZyInfoStudentPcz zyInfoStudentPcz) {
		zyInfoStudentPczService.updateById(zyInfoStudentPcz);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "作业偏差值-通过id删除")
	@ApiOperation(value="作业偏差值-通过id删除", notes="作业偏差值-通过id删除")
	@RequiresPermissions("zyInfoStudentPcz:zy_info_student_pcz:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		zyInfoStudentPczService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "作业偏差值-批量删除")
	@ApiOperation(value="作业偏差值-批量删除", notes="作业偏差值-批量删除")
	@RequiresPermissions("zyInfoStudentPcz:zy_info_student_pcz:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.zyInfoStudentPczService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "作业偏差值-通过id查询")
	@ApiOperation(value="作业偏差值-通过id查询", notes="作业偏差值-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ZyInfoStudentPcz> queryById(@RequestParam(name="id",required=true) String id) {
		ZyInfoStudentPcz zyInfoStudentPcz = zyInfoStudentPczService.getById(id);
		if(zyInfoStudentPcz==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(zyInfoStudentPcz);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param zyInfoStudentPcz
    */
    @RequiresPermissions("zyInfoStudentPcz:zy_info_student_pcz:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ZyInfoStudentPcz zyInfoStudentPcz) {
        return super.exportXls(request, zyInfoStudentPcz, ZyInfoStudentPcz.class, "作业偏差值");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("zyInfoStudentPcz:zy_info_student_pcz:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ZyInfoStudentPcz.class);
    }


	 /**
	  * 分页列表查询
	  *
	  * @return
	  */
	 //@AutoLog(value = "作业偏差值-分页列表查询")
	 @ApiOperation(value="计算偏差值", notes="计算偏差值")
	 @GetMapping(value = "/calculationPcz")
	 public Result<IPage<ZyInfoStudentPcz>> calculationPcz(ZyInfoStudentPcz zyInfoStudentPcz) {
		 ZyInfo jspc = new ZyInfo();
		zyInfoStudentPczService.calculationPcz(jspc);
		 return Result.OK();
	 }

}
