package org.jeecg.modules.kc.zyTlqContent.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.zyTlqContent.entity.ZyTlqContent;
import org.jeecg.modules.kc.zyTlqContent.service.IZyTlqContentService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 讨论内容
 * @Author: jeecg-boot
 * @Date:   2024-05-20
 * @Version: V1.0
 */
@Api(tags="讨论内容")
@RestController
@RequestMapping("/zyTlqContent/zyTlqContent")
@Slf4j
public class ZyTlqContentController extends JeecgController<ZyTlqContent, IZyTlqContentService> {
	@Autowired
	private IZyTlqContentService zyTlqContentService;
	
	/**
	 * 分页列表查询
	 *
	 * @param zyTlqContent
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "讨论内容-分页列表查询")
	@ApiOperation(value="讨论内容-分页列表查询", notes="讨论内容-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ZyTlqContent>> queryPageList(ZyTlqContent zyTlqContent,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ZyTlqContent> queryWrapper = QueryGenerator.initQueryWrapper(zyTlqContent, req.getParameterMap());
		Page<ZyTlqContent> page = new Page<ZyTlqContent>(pageNo, pageSize);
		IPage<ZyTlqContent> pageList = zyTlqContentService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param zyTlqContent
	 * @return
	 */
	@AutoLog(value = "讨论内容-添加")
	@ApiOperation(value="讨论内容-添加", notes="讨论内容-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ZyTlqContent zyTlqContent) {
		LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
		zyTlqContent.setStudentName(sysUser.getRealname());
		zyTlqContentService.save(zyTlqContent);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param zyTlqContent
	 * @return
	 */
	@AutoLog(value = "讨论内容-编辑")
	@ApiOperation(value="讨论内容-编辑", notes="讨论内容-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ZyTlqContent zyTlqContent) {
		zyTlqContentService.updateById(zyTlqContent);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "讨论内容-通过id删除")
	@ApiOperation(value="讨论内容-通过id删除", notes="讨论内容-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		zyTlqContentService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "讨论内容-批量删除")
	@ApiOperation(value="讨论内容-批量删除", notes="讨论内容-批量删除")
	@RequiresPermissions("zyTlqContent:zy_tlq_content:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.zyTlqContentService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "讨论内容-通过id查询")
	@ApiOperation(value="讨论内容-通过id查询", notes="讨论内容-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ZyTlqContent> queryById(@RequestParam(name="id",required=true) String id) {
		ZyTlqContent zyTlqContent = zyTlqContentService.getById(id);
		if(zyTlqContent==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(zyTlqContent);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param zyTlqContent
    */
    @RequiresPermissions("zyTlqContent:zy_tlq_content:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ZyTlqContent zyTlqContent) {
        return super.exportXls(request, zyTlqContent, ZyTlqContent.class, "讨论内容");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("zyTlqContent:zy_tlq_content:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ZyTlqContent.class);
    }

}
