package org.jeecg.modules.kc.zyZyxx.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kc.zyZyxx.entity.ZyZyxx;
import org.jeecg.modules.kc.zyZyxx.service.IZyZyxxService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 资源信息
 * @Author: jeecg-boot
 * @Date:   2024-09-19
 * @Version: V1.0
 */
@Api(tags="资源信息")
@RestController
@RequestMapping("/zyZyxx/zyZyxx")
@Slf4j
public class ZyZyxxController extends JeecgController<ZyZyxx, IZyZyxxService> {
	@Autowired
	private IZyZyxxService zyZyxxService;
	
	/**
	 * 分页列表查询
	 *
	 * @param zyZyxx
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "资源信息-分页列表查询")
	@ApiOperation(value="资源信息-分页列表查询", notes="资源信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ZyZyxx>> queryPageList(ZyZyxx zyZyxx,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ZyZyxx> queryWrapper = QueryGenerator.initQueryWrapper(zyZyxx, req.getParameterMap());
		Page<ZyZyxx> page = new Page<ZyZyxx>(pageNo, pageSize);
		IPage<ZyZyxx> pageList = zyZyxxService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param zyZyxx
	 * @return
	 */
	@AutoLog(value = "资源信息-添加")
	@ApiOperation(value="资源信息-添加", notes="资源信息-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ZyZyxx zyZyxx) {
		zyZyxxService.save(zyZyxx);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param zyZyxx
	 * @return
	 */
	@AutoLog(value = "资源信息-编辑")
	@ApiOperation(value="资源信息-编辑", notes="资源信息-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ZyZyxx zyZyxx) {
		zyZyxxService.updateById(zyZyxx);
		return Result.OK("操作成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "资源信息-通过id删除")
	@ApiOperation(value="资源信息-通过id删除", notes="资源信息-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		zyZyxxService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "资源信息-批量删除")
	@ApiOperation(value="资源信息-批量删除", notes="资源信息-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.zyZyxxService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "资源信息-通过id查询")
	@ApiOperation(value="资源信息-通过id查询", notes="资源信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ZyZyxx> queryById(@RequestParam(name="id",required=true) String id) {
		ZyZyxx zyZyxx = zyZyxxService.getById(id);
		if(zyZyxx==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(zyZyxx);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param zyZyxx
    */
    @RequiresPermissions("zyZyxx:zy_zyxx:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ZyZyxx zyZyxx) {
        return super.exportXls(request, zyZyxx, ZyZyxx.class, "资源信息");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("zyZyxx:zy_zyxx:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ZyZyxx.class);
    }

}
