package org.jeecg.modules.sys.jwms.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.sys.jwms.entity.Jwms;
import org.jeecg.modules.sys.jwms.service.IJwmsService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 教务秘书
 * @Author: jeecg-boot
 * @Date:   2023-06-17
 * @Version: V1.0
 */
@Api(tags="教务秘书")
@RestController
@RequestMapping("/sys/jwms")
@Slf4j
public class JwmsController extends JeecgController<Jwms, IJwmsService> {
	@Autowired
	private IJwmsService jwmsService;
	
	/**
	 * 分页列表查询
	 *
	 * @param jwms
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "教务秘书-分页列表查询")
	@ApiOperation(value="教务秘书-分页列表查询", notes="教务秘书-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<Jwms>> queryPageList(Jwms jwms,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<Jwms> queryWrapper = QueryGenerator.initQueryWrapper(jwms, req.getParameterMap());
		Page<Jwms> page = new Page<Jwms>(pageNo, pageSize);
		IPage<Jwms> pageList = jwmsService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param jwms
	 * @return
	 */
	@AutoLog(value = "教务秘书-添加")
	@ApiOperation(value="教务秘书-添加", notes="教务秘书-添加")
	@RequiresPermissions("sys:jwms:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody Jwms jwms) {
		jwmsService.save(jwms);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param jwms
	 * @return
	 */
	@AutoLog(value = "教务秘书-编辑")
	@ApiOperation(value="教务秘书-编辑", notes="教务秘书-编辑")
	@RequiresPermissions("sys:jwms:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody Jwms jwms) {
		jwmsService.updateById(jwms);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "教务秘书-通过id删除")
	@ApiOperation(value="教务秘书-通过id删除", notes="教务秘书-通过id删除")
	@RequiresPermissions("sys:jwms:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		jwmsService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "教务秘书-批量删除")
	@ApiOperation(value="教务秘书-批量删除", notes="教务秘书-批量删除")
	@RequiresPermissions("sys:jwms:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.jwmsService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "教务秘书-通过id查询")
	@ApiOperation(value="教务秘书-通过id查询", notes="教务秘书-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<Jwms> queryById(@RequestParam(name="id",required=true) String id) {
		Jwms jwms = jwmsService.getById(id);
		if(jwms==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(jwms);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param jwms
    */
    @RequiresPermissions("sys:jwms:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, Jwms jwms) {
        return super.exportXls(request, jwms, Jwms.class, "教务秘书");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("sys:jwms:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, Jwms.class);
    }

}
