package org.jeecg.modules.tools;

import java.io.Serializable;
import java.util.BitSet;
import java.util.regex.Pattern;

public class URLEncoder implements Serializable {
	private static final long serialVersionUID = 1L;
	public static final URLEncoder DEFAULT = createDefault();
	private final BitSet safeCharacters;

	public static URLEncoder createDefault() {
		URLEncoder encoder = new URLEncoder();
		encoder.addSafeCharacter('-');
		encoder.addSafeCharacter('.');
		encoder.addSafeCharacter('_');
		encoder.addSafeCharacter('~');
		encoder.addSafeCharacter('!');
		encoder.addSafeCharacter('$');
		encoder.addSafeCharacter('&');
		encoder.addSafeCharacter('\'');
		encoder.addSafeCharacter('(');
		encoder.addSafeCharacter(')');
		encoder.addSafeCharacter('*');
		encoder.addSafeCharacter('+');
		encoder.addSafeCharacter(',');
		encoder.addSafeCharacter(';');
		encoder.addSafeCharacter('=');
		encoder.addSafeCharacter(':');
		encoder.addSafeCharacter('@');
		encoder.addSafeCharacter('/');
		return encoder;
	}

	public URLEncoder() {
		this(new BitSet(256));

		char i;
		for(i = 'a'; i <= 'z'; ++i) {
			this.addSafeCharacter(i);
		}

		for(i = 'A'; i <= 'Z'; ++i) {
			this.addSafeCharacter(i);
		}

		for(i = '0'; i <= '9'; ++i) {
			this.addSafeCharacter(i);
		}

	}

	private URLEncoder(BitSet safeCharacters) {
		this.safeCharacters = safeCharacters;
	}


	public void addSafeCharacter(char c) {
		this.safeCharacters.set(c);
	}

	public String encode(String path) {
		StringBuilder rewrittenPath = new StringBuilder(path.length());
		String regexStr = "[\u4E00-\u9FA5]";
		for(int i = 0; i < path.length(); ++i) {
			int c = path.charAt(i);
			String _char = String.valueOf((char)c);
			if (this.safeCharacters.get(c)) {
				rewrittenPath.append((char)c);
			}else if(Pattern.matches(regexStr, _char)){
				rewrittenPath.append((char)c);
			}

		}
		return rewrittenPath.toString();
	}
}
