package org.jeecg.modules.tools.dbsdkfzpt;

import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.http.client.methods.HttpEntityEnclosingRequestBase;
import org.apache.http.client.methods.HttpUriRequest;
import org.springframework.http.*;
import org.springframework.http.client.ClientHttpResponse;
import org.springframework.http.client.HttpComponentsClientHttpRequestFactory;
import org.springframework.http.converter.FormHttpMessageConverter;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MimeType;
import org.springframework.util.MimeTypeUtils;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.ResponseErrorHandler;
import org.springframework.web.client.RestTemplate;

import javax.servlet.http.HttpServletResponse;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URI;
import java.nio.charset.Charset;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Class Name: RestTemplateUtils
 * Description:
 * @author: linweisen
 * @mail: linweisen@ly-sky.com
 * @date: 2017年8月23日
 * @version: 1.0
 *
 */
public class RestTemplateUtils {
	/**
	 * Class Name: HttpEntityEnclosingDeleteRequest
	 * Description: 重写delete方法 为了RestTemplate支持Delete方法
	 * @author: linweisen
	 * @mail: linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 * @version: 1.0
	 *
	 */
	public static class HttpEntityEnclosingDeleteRequest extends HttpEntityEnclosingRequestBase {

		public HttpEntityEnclosingDeleteRequest(final URI uri) {
			super();
			setURI(uri);
		}

		@Override
		public String getMethod() {
			return "DELETE";
		}
	}

	/**
	 * Class Name: DefaultResponseErrorHandler
	 * Description:
	 * @author: linweisen
	 * @mail: linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 * @version: 1.0
	 */
	private static class DefaultResponseErrorHandler implements ResponseErrorHandler {

		@Override
		public boolean hasError(ClientHttpResponse response) throws IOException {
			return response.getStatusCode().value() != HttpServletResponse.SC_OK;
		}

		@Override
		public void handleError(ClientHttpResponse response) throws IOException {
			BufferedReader br = new BufferedReader(new InputStreamReader(response.getBody()));
			StringBuilder sb = new StringBuilder();
			String str = null;
			while ((str = br.readLine()) != null) {
				sb.append(str);
			}
			try {
				throw new Exception(sb.toString());
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

	/**
	 * Method Name:  get
	 * Description:
	 * @param url
	 * @param params
	 * @return
	 * @return String
	 * @exception
	 * @author linweisen
	 * @mail linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 */
	public static String get(String url, JSONObject params) {
		RestTemplate restTemplate = new RestTemplate();
		restTemplate.setErrorHandler(new DefaultResponseErrorHandler());
		String response = restTemplate.getForObject(expandURL(url, params.keySet()), String.class, params);
		return response;
	}

	/**
	 * Method Name:  post
	 * Description:  将参数都拼接在url之后
	 * @param url
	 * @param params
	 * @param mediaType
	 * @return
	 * @return String
	 * @exception
	 * @author linweisen
	 * @mail linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 */
	public static String post(String url, JSONObject params, MediaType mediaType) {
		RestTemplate restTemplate = new RestTemplate();
		// 拿到header信息
		HttpHeaders requestHeaders = new HttpHeaders();
		requestHeaders.setContentType(mediaType);
		HttpEntity<JSONObject> requestEntity = (mediaType == MediaType.APPLICATION_JSON || mediaType == MediaType.APPLICATION_JSON_UTF8) ?
				new HttpEntity<JSONObject>(params, requestHeaders) : new HttpEntity<JSONObject>(null, requestHeaders);
		restTemplate.setErrorHandler(new DefaultResponseErrorHandler());
		String result = (mediaType == MediaType.APPLICATION_JSON || mediaType == MediaType.APPLICATION_JSON_UTF8) ?
				restTemplate.postForObject(url, requestEntity, String.class) :
				restTemplate.postForObject(expandURL(url, params.keySet()), requestEntity, String.class, params);
		return result;
	}

	/**
	 * Method Name:  post
	 * Description:  发送json格式数据
	 * @param url
	 * @param params
	 * @param mediaType
	 * @param clz
	 * @return
	 * @return T
	 * @exception
	 * @author linweisen
	 * @mail linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 */
	@SuppressWarnings("rawtypes")
	public static <T> T post(String url, String access_token, List list, MediaType mediaType, Class<T> clz) {
		RestTemplate restTemplate = new RestTemplate();
		// 这是为 MediaType.APPLICATION_FORM_URLENCODED 格式HttpEntity 数据 添加转换器
		// 还有就是，如果是APPLICATION_FORM_URLENCODED方式发送post请求，
		// 也可以直接HttpHeaders requestHeaders = new
		// HttpHeaders(createMultiValueMap(params)，true)，就不用增加转换器了
		restTemplate.getMessageConverters().add(new FormHttpMessageConverter());
		// 设置header信息
		HttpHeaders requestHeaders = new HttpHeaders();
		requestHeaders.setContentType(mediaType);
		url += "?access_token=" + access_token;

		/*HttpEntity<?> requestEntity = (mediaType == MediaType.APPLICATION_JSON || mediaType == MediaType.APPLICATION_JSON_UTF8) ? new HttpEntity<JSONObject>(params, requestHeaders) :
				(mediaType == MediaType.APPLICATION_FORM_URLENCODED ? new HttpEntity<MultiValueMap>(createMultiValueMap(params), requestHeaders) : new HttpEntity<>(null, requestHeaders));*/
		HttpEntity<?> requestEntity = new HttpEntity<List>(list, requestHeaders);
		restTemplate.setErrorHandler(new DefaultResponseErrorHandler());

		T result =  restTemplate.postForObject(url, requestEntity, clz);
		// T result = (mediaType == MediaType.APPLICATION_JSON || mediaType == MediaType.APPLICATION_JSON_UTF8) ? restTemplate.postForObject(url, requestEntity, clz)
		// 		: restTemplate.postForObject(mediaType == MediaType.APPLICATION_FORM_URLENCODED ? url : expandURL(url, params.keySet()), requestEntity, clz, params);

		return result;
	}

	/**
	 * Method Name:  put
	 * Description:
	 * @param url
	 * @param params
	 * @param mediaType
	 * @return
	 * @return String
	 * @exception
	 * @author linweisen
	 * @mail linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 */
	public static String put(String url, JSONObject params, MediaType mediaType) {
		try {
			RestTemplate restTemplate = new RestTemplate();
			// 拿到header信息
			HttpHeaders requestHeaders = new HttpHeaders();
			requestHeaders.setContentType(mediaType);
			HttpEntity<JSONObject> requestEntity = (mediaType == MediaType.APPLICATION_JSON || mediaType == MediaType.APPLICATION_JSON_UTF8) ? new HttpEntity<JSONObject>(params, requestHeaders) : new HttpEntity<JSONObject>(null, requestHeaders);
			restTemplate.setErrorHandler(new DefaultResponseErrorHandler());
			restTemplate.put(url, requestEntity, String.class);

			return "success";
		}
		catch (Exception e) {
			throw e;
		}
	}

	/**
	 * Method Name:  delete
	 * Description:
	 * @param url
	 * @param params
	 * @param mediaType
	 * @return
	 * @return String
	 * @exception
	 * @author linweisen
	 * @mail linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 */
	public static String delete(String url, JSONObject params, MediaType mediaType) {
		RestTemplate restTemplate = new RestTemplate();

		restTemplate.setRequestFactory(new HttpComponentsClientHttpRequestFactory() {
			@Override
			protected HttpUriRequest createHttpUriRequest(HttpMethod httpMethod, URI uri) {
				if (HttpMethod.DELETE == httpMethod) {
					return new HttpEntityEnclosingDeleteRequest(uri);
				}
				return super.createHttpUriRequest(httpMethod, uri);
			}
		});

		// 拿到header信息
		HttpHeaders requestHeaders = new HttpHeaders();
		requestHeaders.setContentType(mediaType);
		HttpEntity<JSONObject> requestEntity = (mediaType == MediaType.APPLICATION_JSON || mediaType == MediaType.APPLICATION_JSON_UTF8) ? new HttpEntity<JSONObject>(params, requestHeaders) : new HttpEntity<JSONObject>(null, requestHeaders);
		restTemplate.setErrorHandler(new DefaultResponseErrorHandler());
//		restTemplate.delete(url, requestEntity, Map.class);
		ResponseEntity<String> exchange = restTemplate.exchange(url, HttpMethod.DELETE, requestEntity, String.class);

		return exchange.getBody();
	}

	public static <T> T exchange(String url, HttpMethod method, JSONObject params, Class<T> bodyType) {
		// 请求头
		HttpHeaders headers = new HttpHeaders();
		MimeType mimeType = MimeTypeUtils.parseMimeType("application/json");
		MediaType mediaType = new MediaType(mimeType.getType(), mimeType.getSubtype(), Charset.forName("UTF-8"));
		// 请求体
		headers.setContentType(mediaType);
		// 提供json转化功能
		ObjectMapper mapper = new ObjectMapper();
		String str = null;
		try {
			if (!params.isEmpty()) {
				str = mapper.writeValueAsString(params);
			}
		} catch (JsonProcessingException e) {
			e.printStackTrace();
		}
		// 发送请求
		HttpEntity<String> entity = new HttpEntity<>(str, headers);
		RestTemplate restTemplate = new RestTemplate();
		ResponseEntity<T> resultEntity = restTemplate.exchange(url, method, entity, bodyType);
		return resultEntity.getBody();
	}

	/**
	 *
	 * Method Name:  createMultiValueMap
	 * Description:
	 * @param params
	 * @return
	 * @return MultiValueMap<String,String>
	 * @exception
	 * @author linweisen
	 * @mail linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 */
	@SuppressWarnings("unchecked")
	private static MultiValueMap<String, String> createMultiValueMap(JSONObject params) {
		MultiValueMap<String, String> map = new LinkedMultiValueMap<>();
		for (String key : params.keySet()) {
			if (params.get(key) instanceof List) {
				for (Iterator<String> it = ((List<String>) params.get(key)).iterator(); it.hasNext();) {
					String value = it.next();
					map.add(key, value);
				}
			} else {
				map.add(key, params.getString(key));
			}
		}
		return map;
	}

	/**
	 * Method Name:  expandURL
	 * Description:
	 * @param url
	 * @param keys
	 * @return
	 * @return String
	 * @exception
	 * @author linweisen
	 * @mail linweisen@ly-sky.com
	 * @date: 2017年8月23日
	 */
	private static String expandURL(String url, Set<?> keys) {
		final Pattern QUERY_PARAM_PATTERN = Pattern.compile("([^&=]+)(=?)([^&]+)?");
		Matcher mc = QUERY_PARAM_PATTERN.matcher(url);
		StringBuilder sb = new StringBuilder(url);
		if (!mc.find()) {
			sb.append("&");
		} else {
			sb.append("?");
		}

		for (Object key : keys) {
			sb.append(key).append("=").append("{").append(key).append("}").append("&");
		}
		return sb.deleteCharAt(sb.length() - 1).toString();
	}
}
