package org.jeecg.modules.tools.excel;

import cn.hutool.core.io.IoUtil;
import com.google.common.collect.Lists;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.*;
import org.jeecg.common.util.SpringContextUtils;
import org.jeecg.modules.tools.CommonUtil;
import org.jeecg.modules.tools.Global;
import org.jeecg.modules.tools.word.WordOperator;

import javax.imageio.ImageIO;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import java.util.Map;


/**
 * 导出excel工具类
 * @author binzec
 */
@Slf4j
public class ExportExcel {

	private static Global global = SpringContextUtils.getBean(Global.class);

	public void setGlobal(Global g){
		global = g;
	}

	/**
	 * 模板替换标签开头
	 */
	private final static String LABEL_STR = "{";
	/**
	 * 模板替换标签结尾
	 */
	private final static String LABEL_END = "}";

	/**
	 * 模板根路径
	 */
	private final static String FILE_PATH = "excelTemplates\\";

	private final static String OFFICE_FILE_PATH = "officetemplates\\";

	/**
	 * 获取XSSFWorkbook对象
	 * @param templateName	word模板名字（必须放在/src/main/resources/file/wordTemplates下）
	 */
	public static XSSFWorkbook getExcelOperator(String templateName) throws Exception {
		InputStream is = null;
		XSSFWorkbook wb = null;
		try {
			//从jar或war中读取资源文件流
			is = global.getResourceInputStream(OFFICE_FILE_PATH + templateName);
			//直接从路径中获取
//			is = new FileInputStream(new File(global.uploadPath + "/" + templateName));
			wb = new XSSFWorkbook(is);
			
		}finally {
			IoUtil.close(is);
		}
		return wb;
	}
	
	/**
	 * 获取Workbook对象
	 * @param templateName	word模板名字（必须放在/src/main/resources/file/wordTemplates下）
	 */
	public static Workbook getExcelOperator2(String templateName) throws Exception {
		InputStream is = null;
		Workbook workbook = null;
		try {
			//从jar或war中读取资源文件流
			is = global.getResourceInputStream(OFFICE_FILE_PATH + templateName);
			 workbook = WorkbookFactory.create(is);
			//直接从路径中获取
//			is = new FileInputStream(new File(global.uploadPath + "/" + templateName));
		}finally {
			IoUtil.close(is);
		}
		return workbook;
	}
	
	/**
	 * 获取Workbook对象
	 * @param templateName	word模板名字（必须放在/src/main/resources/file/wordTemplates下）
	 */
	public static InputStream getIs(String templateName) throws Exception {
		InputStream is = null;
		//从jar或war中读取资源文件流
		is = global.getResourceInputStream(OFFICE_FILE_PATH + templateName);
		return is;
	}
	
	/**
	 * 下载生成的excel文档
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 */
	public static void download(HttpServletRequest request, HttpServletResponse response, String fileName, String templateName) throws Exception {
		ServletOutputStream os = null;
		InputStream is = null;
		try {
			//从jar或war中读取资源文件流
			is = global.getResourceInputStream(OFFICE_FILE_PATH + templateName);
			// 设置好响应头，然后将文件保存到输出流里即可
//			response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
//			response.setHeader("Content-Disposition", "attachment;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".xlsx", request));
			os = response.getOutputStream();
			//IoUtil.copy(is, os);
//			byte[] b = IoUtil.readBytes(is);
			
			IoUtil.copy(is, os, IoUtil.DEFAULT_BUFFER_SIZE);
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			IoUtil.close(is);
			if(os != null) {
				IoUtil.close(os);
			}
		}
	}

	//根据模板创建表格对象
	public static XSSFWorkbook createByTemplate(String templateName) throws IOException {
		//直接从路径中获取
		XSSFWorkbook wb = null;
		InputStream is = null;
		//从jar或war中读取资源文件流
		try{
			is = global.getResourceInputStream(FILE_PATH + templateName);
			wb = new XSSFWorkbook(is);
		}finally {
			IoUtil.close(is);
		}
		return wb;
	}

	/**
	 * 替换其中的模板文字
	 * @param workbook
	 * @param replaceMap
	 */
	public static void replaceText(XSSFWorkbook workbook, Map<String,?> replaceMap){
		//获取每个Sheet表
		for (int i = 0; i < workbook.getNumberOfSheets(); i++) {
			log.info("┏ Sheet表{}",i);
			XSSFSheet sheet = workbook.getSheetAt(i);
			if(sheet != null){
				//获取每行
				for (int j = 0; j <= sheet.getLastRowNum(); j++) {
					log.info("┃\t┏ 第{}行",j);
					XSSFRow row = sheet.getRow(j);
					//中间如果没有数据，则会出现空行，跳过这些空行
					if(row != null){
						//获取每个单元格
						for (int k = 0; k < row.getLastCellNum(); k++) {
							XSSFCell cell = row.getCell(k);
							//按不同的类型取字符值
							String cellValue = getStringValue(cell);
							log.info("┃\t┃\t 第{}单元格\t单元格值为\t{}\t将要替换为\t{}",k,cell,cellValue);
							//单元格会存在空的情况，
							if(row.getCell(k) != null && StringUtils.isNotBlank(cellValue)){
								//将【{xxx},{yyy}】替换成【x数据，y数据】
								String txt = CommonUtil.getReplaceMapValue(cellValue,replaceMap,LABEL_STR,LABEL_END);
								//如果值是一致的，则不再替换，节省资源
								if(!StringUtils.equals(txt,cellValue)){
									log.info("┃\t┃\t 替换成功！");
									row.getCell(k).setCellValue(txt);
								}
							}
						}
					}
					log.info("┃\t┗ 处理完毕\t共计{}行",sheet.getLastRowNum());
				}
			}
			log.info("┗ 处理完毕\t共计{}个",workbook.getNumberOfSheets());
		}
	}

	/**
	 *
	 * @param workbook 工做表
	 * @param sheetIndex 第几个sheet页，从0开始
	 * @param tempRowIndex 模板row（行x）坐标，从0开始
	 * @param tempCellIndex 模板col（列y）坐标，从0开始
	 * @param isDeleteTempRow 是否删除模板行
	 * @param rowList 数据列表
	 */
	public static void insertTable(XSSFWorkbook workbook, int sheetIndex,int tempRowIndex,int tempCellIndex,boolean isDeleteTempRow,List<List<?>> rowList){
		insertTable(workbook, sheetIndex,tempRowIndex,tempCellIndex,isDeleteTempRow,false,rowList);
	}

	/**
	 *
	 * @param workbook 工做表
	 * @param sheetIndex 第几个sheet页，从0开始
	 * @param tempRowIndex 模板row（行x）坐标，从0开始
	 * @param tempCellIndex 模板col（列y）坐标，从0开始
	 * @param isDeleteTempRow 是否删除模板行
	 * @param isForceAddRow 是否强添加新行
	 * @param rowList 数据列表
	 */
	public static void insertTable(XSSFWorkbook workbook, int sheetIndex,int tempRowIndex,int tempCellIndex,boolean isDeleteTempRow,boolean isForceAddRow,List<List<?>> rowList){
		//获取sheet
		XSSFSheet sheet = workbook.getSheetAt(sheetIndex);
		if(sheet == null){
			log.error("sheet页不存在，请检查模板，sheetIndex: {}",sheetIndex);
			return;
		}
		//获取模板行
		XSSFRow tempRow = sheet.getRow(tempRowIndex);
		if(tempRow == null){
			log.error("模板row不存在，请检查模板，sheetIndex: {},tempRowIndex: {}",sheetIndex,tempRowIndex);
			return;
		}
		if(rowList.isEmpty()){
			//删除模板行
			if(isDeleteTempRow){
				//删除得偏移行
				sheet.removeRow(tempRow);
				if(sheet.getLastRowNum() >= tempRowIndex+1){
					sheet.shiftRows(tempRowIndex+1,sheet.getLastRowNum(),-1);
				}
			}
			log.info("没数据你还搁着寻思啥呢，退出吧！");
			return;
		}

		//往单元格里填数据
		for (int di = 0; di < rowList.size(); di++) {
			//数据行
			List<?> drow = rowList.get(di);
			//获取下一行，在模板行的下一行操作
			XSSFRow nextRow = sheet.getRow(tempRowIndex + di + 1);
			if(isForceAddRow){
				nextRow = null;
			}
			if(nextRow == null){
				//如果是新行，则偏移后面的行
				nextRow = sheet.createRow(tempRowIndex + di + 1);
				//如果最后一行比偏移的那一行要小，则不能再偏移会报错的
				if(tempRowIndex + di + 2 <= sheet.getLastRowNum()){
					//偏移的是模板行下的新行的下一行，为了避免底下的表格内容被当前的数据覆盖
					sheet.shiftRows(tempRowIndex + di + 2,sheet.getLastRowNum(),1);
				}
			}
			//具体的单元格部分
			for (int dj = 0; dj < drow.size(); dj++) {
				//取单元格
				XSSFCell nextCell = nextRow.getCell(tempCellIndex + dj);
				if(nextCell == null){
					nextCell = nextRow.createCell(tempCellIndex + dj);
				}
				Object o = drow.get(dj);
				if (o instanceof String){
					//复制模板行对应单元格的样式
					XSSFCell tempCell = tempRow.getCell(tempCellIndex + dj);
					if(tempCell != null){
						//塞入模板单元格的样式
						XSSFCellStyle tempStyle = tempCell.getCellStyle();
						nextCell.setCellStyle(tempStyle);
					}
					//添加值
					nextCell.setCellValue((String) drow.get(dj));
				}else if(o instanceof XSSFCellStyleAndValue){
					XSSFCellStyleAndValue val = (XSSFCellStyleAndValue) drow.get(dj);
					nextCell.setCellStyle(val.getStyle());
					nextCell.setCellValue(val.getValue());
				}else if(o instanceof  XSSFCellImage){
					//图片类型的
					XSSFCellImage img = (XSSFCellImage) drow.get(dj);
					//short defaultRowHeight = sheet.getDefaultRowHeight();
					//sheet.setDefaultRowHeight((short) 50);
					nextRow.setHeight((short) 1000);
					XSSFDrawing sxssfDrawing = sheet.createDrawingPatriarch();
					ByteArrayOutputStream byteArrayOut = new ByteArrayOutputStream();
					//anchor主要用于设置图片的属性
					XSSFClientAnchor anchor = img.getClientAnchor();
					//自动算出放在哪行哪列
					//img.getWidthCell()
					//img.getHeightCell()
					anchor.setCol1(nextCell.getColumnIndex());//开始x点
					anchor.setRow1(nextCell.getRowIndex()-1);//开始y点
					anchor.setCol2(nextCell.getColumnIndex()+img.getWidthCell());//结束x点
					anchor.setRow2(nextCell.getRowIndex()-1+img.getWidthCell());//结束y点


					anchor.setAnchorType(ClientAnchor.AnchorType.DONT_MOVE_DO_RESIZE);
					//将图片读到BufferedImage
					BufferedImage bufferedImage = null;
					try {
						bufferedImage = ImageIO.read(new File(img.getImagePath()));
						// 将图片写入流中
						ImageIO.write(bufferedImage, img.getImageType(), byteArrayOut);
						sxssfDrawing.createPicture(anchor, workbook.addPicture(byteArrayOut.toByteArray(), img.getXSSFWorkbookType()));
						//还原默认高度，但不知道能不能用
						//sheet.setDefaultRowHeight(defaultRowHeight);
					} catch (IOException e) {
						e.printStackTrace();
					}
				}
			}
		}

		//删除模板
		if(isDeleteTempRow){
			//删除得偏移行
			sheet.removeRow(tempRow);
			if(sheet.getLastRowNum() >= tempRowIndex+1) {
				sheet.shiftRows(tempRowIndex + 1, sheet.getLastRowNum(), -1);
			}
		}

	}

	@Data
	public class Coordinate{
		/**
		 * sheet页坐标，从0开始
		 */
		private int sheetIndex = 0;
		/**
		 * 行坐标，从0开始
		 */
		private int rowIndex = 0;
		/**
		 * 单元格列坐标，从0开始
		 */
		private int cellIndex = 0;
		public Coordinate(){
			super();
		}

		/**
		 * 默认设置sheet页坐标为0
		 * @param rowIndex 行坐标，从0开始
		 * @param cellIndex 单元格列坐标，从0开始
		 */
		public Coordinate(int rowIndex,int cellIndex){
			super();
			this.rowIndex = rowIndex;
			this.cellIndex = cellIndex;
		}

		/**
		 * 开放设置三维的构造
		 * @param sheetIndex sheet页坐标，从0开始
		 * @param rowIndex 行坐标，从0开始
		 * @param cellIndex 单元格列坐标，从0开始
		 */
		public Coordinate(int sheetIndex,int rowIndex,int cellIndex){
			super();
			this.sheetIndex = sheetIndex;
			this.rowIndex = rowIndex;
			this.cellIndex = cellIndex;
		}
	}

	/**
	 *
	 * @param workbook
	 * @param coordinate
	 * @return true: 存在| false: 不存在
	 */
	public static int checkCell(XSSFWorkbook workbook,Coordinate coordinate){
		//获取起始sheet
		XSSFSheet sheet = workbook.getSheetAt(coordinate.getSheetIndex());
		if(sheet == null){
			log.error("sheet不存在，请检查模板，sheetIndex: {}",coordinate.getSheetIndex());
			return -1;
		}
		XSSFRow row = sheet.getRow(coordinate.getRowIndex());
		if(row == null){
			log.error("row不存在，请检查模板，sheetIndex: {},rowIndex: {}",coordinate.getSheetIndex(),coordinate.getRowIndex());
			return -2;
		}

		XSSFCell cell = row.getCell(coordinate.getCellIndex());
		if(cell == null){
			log.error("cell不存在，请检查模板，sheetIndex: {},rowIndex: {},cellIndex: {} ",coordinate.getSheetIndex(),coordinate.getRowIndex(),coordinate.getCellIndex());
			return -3;
		}
		return 0;
	}

	public static void shiftColls(XSSFWorkbook workbook, Coordinate formStart,Coordinate formEnd,Coordinate toStart,Coordinate toEnd){
		//先行校验坐标合法性
		if(formStart == null && checkCell(workbook,formStart) != 0){
			log.error("起始坐标不正确");
			return;
		}
//		if(formEnd == null && checkCell(workbook,formEnd) != 0){
//			log.error("结束坐标不正确");
//			return;
//		}
//		if(toStart == null && checkCell(workbook,toStart) != 0){
//			log.error("到某处的起始坐标不正确");
//			return;
//		}
//		if(toEnd == null && checkCell(workbook,toEnd) != 0){
//			log.error("到某处的结束坐标不正确");
//			return;
//		}

		XSSFSheet formStartSheet = workbook.getSheetAt(formStart.getSheetIndex());
		XSSFRow formStartRow = formStartSheet.getRow(formStart.getRowIndex());
		XSSFCell formStartCell = formStartRow.getCell(formStart.getCellIndex());

//		XSSFSheet formEndSheet = workbook.getSheetAt(formEnd.getSheetIndex());
//		XSSFRow formEndRow = formEndSheet.getRow(formEnd.getRowIndex());
//		XSSFCell formEndCell = formEndRow.getCell(formEnd.getCellIndex());

	}

	/**
	 * 计算偏移量，按删除模板行计算
	 * @param absoluteRowNumber 相对模板的行号（从0开始计算）
	 * @param previousAddRowNumber 累计新增的行数,如果是0，则是第一个，不计算删除模板行
	 * @return
	 */
	public static int getDeviationRowNumber(int absoluteRowNumber, int previousAddRowNumber){
		return getDeviationRowNumber(absoluteRowNumber,previousAddRowNumber != 0,previousAddRowNumber);
	}

	/**
	 *
	 * @param absoluteRowNumber 相对模板的行号（从0开始计算）
	 * @param isDeleteTempRow 是否删除模板行
	 * @param previousAddRowNumber 累计新增的行数
	 * @return
	 */
	public static int getDeviationRowNumber(int absoluteRowNumber,boolean isDeleteTempRow, int previousAddRowNumber){
		return absoluteRowNumber + previousAddRowNumber + (isDeleteTempRow?-1:0);
	}



	/**
	 *
	 * 功能说明	: 补充空列
	 * 创建者		: byx
	 * 修改日期	: 2018年12月25日
	 * @param returnList:填充到这个list中
	 * @param inputList:输入的list，业务信息列表，用来计算空列的初始值
	 * @param endRowNum:总共N行
	 * @param colNum:拥有几列
	 */
	public static void fillNullCall(List<List<String>> returnList, List<?> inputList, int endRowNum, int colNum){
		WordOperator.fillNullCall(returnList,inputList,endRowNum,colNum);
	}

	/**
	 *
	 * 功能说明	: 补充空列
	 * 创建者		: byx
	 * 修改日期	: 2018年12月25日
	 * @param returnList:填充到这个list中
	 * @param startRowNum:从N开始循环
	 * @param endRowNum:总共N行
	 * @param colNum:拥有几列
	 */
	public static void fillNullCall(List<List<String>> returnList, int startRowNum, int endRowNum, int colNum){
		WordOperator.fillNullCall(returnList,startRowNum,endRowNum,colNum);
	}


	/**
	 * 从单元格里取值
	 * @param cell
	 * @return
	 */
	public static String getStringValue(XSSFCell cell){
		if(cell == null){ return ""; }
		String value = "";
		CellType type = cell.getCellTypeEnum();
		switch (type){
			case STRING:
				value = cell.getStringCellValue();
				break;
			case NUMERIC:
				value = String.valueOf(cell.getNumericCellValue());
				break;
			case BOOLEAN:
				value = String.valueOf(cell.getBooleanCellValue());
				break;
			case _NONE:
				//内部使用的，，
				break;
			case BLANK:
				//空白单元格
				break;
			case ERROR:
				//发生错误的单元格
				value = cell.getErrorCellString();
				break;
			case FORMULA:
				//公式单元格
				value = cell.getCellFormula();
				break;
			default:
				break;
		}
		return value;
	}




	public static void runTest(HttpServletRequest request, HttpServletResponse response) throws Exception{
		//以模板形式导出
		XSSFWorkbook workbook = ExportExcel.createByTemplate("test.xlsx");
		//指定复制区域，0,1,3 | 0,1,3 指定（复制/剪切）到，1,1,3 | 1,1,3
		//直接偏移，从 0,1,3 | 0,1,3 偏移x，y距离，
		//直接偏移，从 0,1,3 | ? 偏移x，y距离，
		XSSFSheet sheet = workbook.getSheetAt(0);
		XSSFRow row = sheet.getRow(1);
		XSSFCell cell = row.getCell(3);
		row.createCell(5).copyCellFrom(cell,new CellCopyPolicy());
		row.createCell(3).setCellValue("????什么颜色");
		row.createCell(4).setCellValue("????什么颜色2");










//		row.copyRowFrom();
//		Map<String,String> map2 = Maps.newHashMap();
//		map2.put("text1","666666");
//		map2.put("text2","777777");
		//模板替换
		//ExportExcel.replaceText(workbook,map2);
		List<List<?>> dlist = Lists.newArrayList();
		for (int i = 0; i < 20; i++) {
			List<String> ddlist = Lists.newArrayList();
			dlist.add(ddlist);
			for (int j = 0; j < 7; j++) {
				ddlist.add("这是数据！第" + (i+1) + "行，第" + (j+1) + "列");
			}
		}
		int deviationRow = 0;
		log.info("开始创建动态表格1...");
		ExportExcel.insertTable(workbook,0,ExportExcel.getDeviationRowNumber(2,deviationRow),1,true,dlist);
		//下载文件
		DownloadtExcelUtils.download("临时文件",workbook,request,response);
	}

}
