package org.jeecg.modules.tools.excel;

import lombok.Data;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.xssf.usermodel.XSSFClientAnchor;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.util.Locale;

@Data
public class XSSFCellImage {
	private String imagePath;//完整的图片路径
	//图片属性 //new XSSFClientAnchor(0, 0, 255, 255, 0, 0, 1, 1)????
	private XSSFClientAnchor clientAnchor;
	//图片类型
	private String imageType;

	private Integer widthCell;//占用几格
	private Integer heightCell;//占用几格

	public Integer getWidthCell() {
		if(widthCell == null) return 0;
		return widthCell;
	}

	public Integer getHeightCell() {
		if(heightCell == null) return 0;
		return heightCell;
	}

	public String getSuffixName(){
		if(StringUtils.isBlank(imagePath)) return null;
		int index = StringUtils.lastIndexOf(imagePath,".");
		if(index != -1){
			return imagePath.substring(index+1);
		}
		return null;
	}

	public String getImageType(){
		if(StringUtils.isBlank(imageType)){
			return "png";
		}
		return imageType;
	}
	//获取图片类型，默认是png
	public int getXSSFWorkbookType(){
		if(StringUtils.isBlank(imageType)){
			return XSSFWorkbook.PICTURE_TYPE_PNG;
		}
		int rType = XSSFWorkbook.PICTURE_TYPE_PNG;
		String type = imageType.toLowerCase(Locale.ROOT);
		switch (imageType){
			case "png":
				rType = XSSFWorkbook.PICTURE_TYPE_PNG;
				break;
			case "bmp":
				rType = XSSFWorkbook.PICTURE_TYPE_BMP;
				break;
			case "gif":
				rType = XSSFWorkbook.PICTURE_TYPE_GIF;
				break;
			case "dib":
				rType = XSSFWorkbook.PICTURE_TYPE_DIB;
				break;
			case "emf":
				rType = XSSFWorkbook.PICTURE_TYPE_EMF;
				break;
			case "eps":
				rType = XSSFWorkbook.PICTURE_TYPE_EPS;
				break;
			case "jpg":
				rType = XSSFWorkbook.PICTURE_TYPE_JPEG;
				break;
			case "jpeg":
				rType = XSSFWorkbook.PICTURE_TYPE_JPEG;
				break;
			case "pict":
				rType = XSSFWorkbook.PICTURE_TYPE_PICT;
				break;
			case "tiff":
				rType = XSSFWorkbook.PICTURE_TYPE_TIFF;
				break;
			case "wmf":
				rType = XSSFWorkbook.PICTURE_TYPE_WMF;
				break;
			case "wpg":
				rType = XSSFWorkbook.PICTURE_TYPE_WPG;
				break;
		}
		return rType;
	}

	public XSSFCellImage(){
		super();
	}

	public XSSFCellImage(String imagePath){
		super();
		this.imagePath = imagePath;
		this.imageType = getSuffixName();
		this.clientAnchor = new XSSFClientAnchor(0, 0, 255, 255, 0, 0, 1, 1);

	}
	/* 0, 0, 255, 255, 0, 0, 1, 1
		dx1 第一个单元格中的x坐标。
		dy1 第一个单元格中的y坐标。

		dx2 第二个单元格中的x坐标。
		dy2 第二个单元格中的y坐标。

		col1 第一个单元格的列(基于0)。
		row1 第一个单元格的行(基于0)。

		col2 第二个单元格的列(基于0)。
		row2 第二个单元格的行(基于0)
	 * @param dx1  the x coordinate within the first cell.
	 * @param dy1  the y coordinate within the first cell.
	 * @param dx2  the x coordinate within the second cell.
	 * @param dy2  the y coordinate within the second cell.
	 * @param col1 the column (0 based) of the first cell.
	 * @param row1 the row (0 based) of the first cell.
	 * @param col2 the column (0 based) of the second cell.
	 * @param row2 the row (0 based) of the second cell.
	 */
	public XSSFCellImage(String imagePath,int widthCell,int heightCell){
		super();
		this.imagePath = imagePath;
		this.imageType = getSuffixName();
		this.widthCell = widthCell;
		this.heightCell = heightCell;
		this.clientAnchor = new XSSFClientAnchor(0, 0, 255, 255, 0, 0,0, 0);
	}
	public XSSFCellImage(XSSFClientAnchor clientAnchor){
		super();
		this.clientAnchor = clientAnchor;
	}
	public XSSFCellImage(String imagePath,XSSFClientAnchor clientAnchor){
		super();
		this.imagePath = imagePath;
		this.imageType = getSuffixName();
		this.clientAnchor = clientAnchor;
	}
	public XSSFCellImage(String imagePath,XSSFClientAnchor clientAnchor,String imageType){
		super();
		this.imagePath = imagePath;
		this.clientAnchor = clientAnchor;
		this.imageType = imageType;
	}

}
