package org.jeecg.modules.tools.ffmpeg;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.RuntimeUtil;
import com.google.common.collect.Lists;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @ClassName FFmpegTools
 * @Description FFmpeg相关工具
 * @Author bai
 * @Date 2024/5/6 19:53
 * @Version 1.0
 **/
@Component
@Slf4j
public class FFmpegTools {

	/**
	 * 执行命令的核心文件
	 */
	@Value("${ffmpeg.executableFile}")
	public String executableFile;

	/**
	 * 日志等级，【 quiet | panic | fatal | error | warning | info | verbose | debug | trace】默认值为 info
	 */
	@Value("${ffmpeg.videoScreenshot.loglevel}")
	public String loglevel;

	/**
	 * 视频过滤器
	 */
	@Value("${ffmpeg.videoScreenshot.vf}")
	public String vf;

	/**
	 * 图片压缩比例
	 */
	@Value("${ffmpeg.videoScreenshot.compressionRatio}")
	public String compressionRatio;


	/**
	 * 是否覆盖输出文件【 y:覆盖 | n:不覆盖 】
	 */
	@Value("${ffmpeg.videoScreenshot.isOverwrite}")
	public String isOverwrite;



	/**
	 *
	 * @return [true: 压缩成功 | false: 压缩失败或是未压缩]
	 */
	public boolean videoScreenshot(String inputPath,String outPath){
		// -q:v 2 压缩比例，数越大，图越小
		// -vsync vfr 同步类型，，不知含义
		// -frames 1 截一帧
		// -vf 视频过滤器，select 选择器， scale缩放比例，-1:-1为原比例
		// ffmpeg -i https://kczx.nenu.edu.cn:9553/live_hls/wzl0236s_xsqj.m3u8 -q:v 2 -vf "select=not(mod(n\,15)),scale=-1:-1" -vsync vfr -frames:v 1 snapshot2.jpg

		List<String> command = Lists.newArrayList();
		command.add(executableFile);
		command.add("-i");
		command.add(inputPath);//输入的文件地址
		command.add("-vf");
		command.add(vf);//视频过滤器参数
		command.add("-vsync");
		command.add("vfr");//同步类型
		command.add("-frames:v");
		command.add("1");//截取一帧
		command.add("-q:v");
		command.add(compressionRatio);//压缩比
		command.add(outPath);//出的文件地址
		if(StringUtils.isNotBlank(loglevel)){
			command.add("-loglevel");//如果写了日志级别，则添加参数，不写默认是info
			command.add(loglevel);
		}
		if(StringUtils.isNotBlank(isOverwrite)){
			command.add("-" + isOverwrite);//是否覆盖【 y | n 】
		}

		String[] cmdArr = command.toArray(new String[]{});
		log.debug("命令行参数为：{}",command);
		log.debug("命令行参数为：{}",command.stream().collect(Collectors.joining(" ")));
		log.info("\n--FFmpegTools--\n开始截取一帧图片！\n输入文件地址：{}",inputPath);
		Process process = RuntimeUtil.exec(cmdArr);
		String res = RuntimeUtil.getResult(process);
		log.debug("脚本输出信息:\n{}",res);
		//没法判断返回值，信息贼多，且没有个成功标识
		if(FileUtil.exist(outPath)){
			log.info("\n--FFmpegTools--\n截取一帧图片成功！\n输出文件地址：{}",outPath);
			return true;
		}else{
			log.error("\n--FFmpegTools--\n截取一帧图片失败！\n输出文件不存在，输出文件地址：{}",outPath);
		}
		return false;
	}

	public static void main(String[] args) {
		FFmpegTools _FFmpegTools = new FFmpegTools();
		_FFmpegTools.executableFile = "D:\\ProgramGreeFile\\ffmpeg\\bin\\ffmpeg.exe";
		_FFmpegTools.loglevel = "info";
		_FFmpegTools.vf = "\"select=not(mod(n\\,15)),scale=-1:-1\"";
//		_FFmpegTools.vf = " -vsync vfr -frames:v 1";
		_FFmpegTools.compressionRatio = "2";
		_FFmpegTools.isOverwrite = "y";

		boolean res = _FFmpegTools.videoScreenshot("https://kczx.nenu.edu.cn:9553/live_hls/wzl0236s_xsqj.m3u8","F:\\temp\\000\\11\\jietu22.jpeg");
		log.debug("最终结果：{}",res);
	}

}
