package org.jeecg.modules.tools.image;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.RuntimeUtil;
import com.google.common.collect.Lists;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 压缩图片
 */
@Component
@Slf4j
public class ZipImage {

	/**
	 * 执行命令的核心文件
	 */
	@Value("${ffmpeg.executableFile}")
	public String executableFile;

	/**
	 * 是否开启压缩【true:开启压缩 | false:关闭压缩 】
	 */
	@Value("${ffmpeg.compress.enable}")
	public boolean enable;

	/**
	 * 压缩比,正整数，数越大压缩比越高
	 */
	@Value("${ffmpeg.compress.compressionRatio}")
	public String compressionRatio;

	/**
	 * 日志等级，【 quiet | panic | fatal | error | warning | info | verbose | debug | trace】默认值为 info
	 */
	@Value("${ffmpeg.compress.loglevel}")
	public String loglevel;

	/**
	 * 是否覆盖输出文件【 y:覆盖 | n:不覆盖 】
	 */
	@Value("${ffmpeg.compress.isOverwrite}")
	public String isOverwrite;

	/**
	 * 是否删除源文件【 true:删除源文件 | false:不删除源文件 】
	 */
	@Value("${ffmpeg.compress.isDeleteSourceFile}")
	public boolean isDeleteSourceFile;

	/**
	 * 是否删除源文件【 true:删除源文件 | false:不删除源文件 】
	 */
	@Value("${ffmpeg.compress.extensionFilter}")
	public String[] extensionFilter;




	/**
	 *
	 * @return [true: 压缩成功 | false: 压缩失败或是未压缩]
	 */
	public boolean compress(String inputPath,String outPath){
		if(enable){
			//计算扩展名是否在支持列表中
			String extName = FileUtil.extName(inputPath);
			if(!StringUtils.equalsAnyIgnoreCase(extName,extensionFilter)){
				log.info("\n--zipImage--\n拒绝压缩该类型的文件！\n输入文件类型：{}\n输入文件地址：",extName,inputPath);
				return false;
			}
			List<String> command = Lists.newArrayList();
			command.add(executableFile);
			command.add("-i");
			command.add(inputPath);//入的文件地址
			command.add("-q");
			command.add(compressionRatio);//压缩比
			command.add(outPath);//出的文件地址
			if(StringUtils.isNotBlank(loglevel)){
				command.add("-loglevel");//如果写了日志级别，则添加参数，不写默认是info
				command.add(loglevel);
			}
			if(StringUtils.isNotBlank(isOverwrite)){
				command.add("-" + isOverwrite);//是否覆盖【 y | n 】
			}

			String[] cmdArr = command.toArray(new String[]{});
			log.debug("命令行参数为：{}",command);
			log.info("\n--zipImage--\n开始压缩！\n输入文件地址：{}",inputPath);
			Process process = RuntimeUtil.exec(cmdArr);
			String res = RuntimeUtil.getResult(process);
			log.debug("脚本输出信息:\n{}",res);
			//没法判断返回值，信息贼多，且没有个成功标识
			if(FileUtil.exist(outPath)){
				log.info("\n--zipImage--\n压缩成功！\n输出文件地址：{}",outPath);
				return true;
			}else{
				log.error("\n--zipImage--\n压缩失败！\n输出文件不存在，输出文件地址：{}",outPath);
			}
//			String error = RuntimeUtil.getErrorResult(process);
//			log.error(error);
//			process.

		}else{
			log.info("\n--zipImage--\n跳过压缩！\n输入文件地址：{}",inputPath);
		}
		return false;
	}

	public static void main(String[] args) {
		ZipImage compressImage = new ZipImage();
		compressImage.enable = true;
		compressImage.executableFile = "D:\\ProgramGreeFile\\ffmpeg\\bin\\ffmpeg.exe";
		compressImage.compressionRatio = "50";
		compressImage.loglevel = "error";
		compressImage.isOverwrite = "y";

		boolean res = compressImage.compress("E:\\111tupian\\戚慧森2_1644453980410.jpg","E:\\111tupian\\戚慧森2_1644453980410_mini.jpg");
		log.debug("最终结果：{}",res);
	}
}
