package org.jeecg.modules.tools.office.convert;

import lombok.extern.slf4j.Slf4j;
import org.apache.poi.poifs.filesystem.FileMagic;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.usermodel.WorkbookFactory;
import org.apache.poi.util.IOUtils;
import org.jeecg.common.util.SpringContextUtils;
import org.jeecg.modules.tools.Global;
import org.jodconverter.core.DocumentConverter;
import org.jodconverter.core.document.DefaultDocumentFormatRegistry;
import org.jodconverter.core.document.DocumentFormat;
import org.jodconverter.core.job.ConversionJobWithOptionalSourceFormatUnspecified;
import org.jodconverter.core.job.ConversionJobWithSourceSpecified;
import org.jodconverter.core.office.OfficeException;

import java.io.*;
import java.nio.file.Files;
import java.util.UUID;

/**
 * 文档转化工具统一入口
 */
@Slf4j
public final class OfficeConvertHelper {


	private static Global global = SpringContextUtils.getBean(Global.class);
	public void setGlobal(Global g){
		global = g;
	}

	private static String TMP_DIRECTORY = global.getTmpDickPath();

	private OfficeConvertHelper () {}

	public static OfficeConverterBox converter(DocumentConverter documentConverter) {
		return new OfficeConverterBox(documentConverter);
	}

	/**
	 * 转换
	 * @param outputHelper 输出对象
	 * @throws IOException io异常
	 * @throws OfficeException office异常
	 */
	static void execute(OfficeOutputBox outputHelper) throws IOException, OfficeException {
		OfficeInputBox officeInputBox = outputHelper.getOfficeInputBox();
		OfficeConverterBox officeConverterBox = officeInputBox.getOfficeConverterBox();

		DocumentConverter documentConverter = officeConverterBox.getDocumentConverter();

		File inpFile = officeInputBox.getInpFile();
		InputStream inp = officeInputBox.getInp();
		boolean inpCloseStream = officeInputBox.isCloseStream();
		DocumentFormat inpDocumentFormat = officeInputBox.getInpDocumentFormat();
		OfficeInputExcelPrintSetup inputExcelPrintSetup = officeInputBox.getOfficeInputExcelPrintSetup();

		File outFile = outputHelper.getOutFile();
		OutputStream outp = outputHelper.getOutp();
		boolean outpCloseStream = outputHelper.isCloseStream();
		DocumentFormat outDocumentFormat = outputHelper.getOutDocumentFormat();

		if (inpFile != null) {
			DocumentFormat isDocFormat = inpDocumentFormat;
			if (MyOfficeUtils.isExcel03(inpFile)) {
				isDocFormat = DefaultDocumentFormatRegistry.XLS;
			} else if (MyOfficeUtils.isExcel07(inpFile)) {
				isDocFormat = DefaultDocumentFormatRegistry.XLSX;
			}
			if (DefaultDocumentFormatRegistry.XLS == isDocFormat || DefaultDocumentFormatRegistry.XLSX == isDocFormat) {
				File file = new File(TMP_DIRECTORY, "xls" + UUID.randomUUID().toString().replace("-", "") + ".tmp");
				try {
					try (
						OutputStream tmpOs = toBufferedOutputStream(Files.newOutputStream(file.toPath()));
						Workbook workbook = WorkbookFactory.create(inpFile);
					) {
						MyOfficeUtils.setExcelPrintScale(workbook, inputExcelPrintSetup);
						workbook.write(tmpOs);
					}
					ConversionJobWithSourceSpecified as = documentConverter.convert(file).as(isDocFormat);
					if (outFile != null) {
						if (outDocumentFormat != null) {
							as.to(outFile).as(outDocumentFormat).execute();
						} else {
							as.to(outFile).execute();
						}
					} else {
						OutputStream bufferedOs = toBufferedOutputStream(outp);
						as.to(bufferedOs, outpCloseStream).as(outDocumentFormat).execute();
					}
				} finally {
					try {
						Files.delete(file.toPath());
					} catch (Exception e) {
						log.error("文档转换出现问题：" + e.getMessage(),e);
					}
				}
			} else {
				if (inpDocumentFormat != null) {
					ConversionJobWithSourceSpecified as = documentConverter.convert(inpFile).as(inpDocumentFormat);
					if (outFile != null) {
						if (outDocumentFormat != null) {
							as.to(outFile).as(outDocumentFormat).execute();
						} else {
							as.to(outFile).execute();
						}
					} else {
						OutputStream bufferedOs = toBufferedOutputStream(outp);
						as.to(bufferedOs, outpCloseStream).as(outDocumentFormat).execute();
					}
				} else {
					ConversionJobWithOptionalSourceFormatUnspecified as = documentConverter.convert(inpFile);
					if (outFile != null) {
						if (outDocumentFormat != null) {
							as.to(outFile).as(outDocumentFormat).execute();
						} else {
							as.to(outFile).execute();
						}
					} else {
						OutputStream bufferedOs = toBufferedOutputStream(outp);
						as.to(bufferedOs, outpCloseStream).as(outDocumentFormat).execute();
					}
				}
			}
		} else {
			File unknownFile = new File(TMP_DIRECTORY, "unknown" + UUID.randomUUID().toString().replace("-", "") + ".tmp");
			try {
				InputStream bufferedIs = null;
				try {
					bufferedIs = FileMagic.prepareToCheckMagic(inp);
					IOUtils.copy(bufferedIs, unknownFile);
				} finally {
					if (inpCloseStream) {
						if (bufferedIs != null) {
							try {
								bufferedIs.close();
								bufferedIs = null;
							} catch (Exception e) {
								log.error("文档转换出现问题：" + e.getMessage(),e);
							}
						} else {
							try {
								inp.close();
							} catch (Exception e) {
								log.error("文档转换出现问题：" + e.getMessage(),e);
							}
						}
					} else {
						if (bufferedIs != null) {
							try {
								bufferedIs.reset();
							} catch (Exception e) {
								log.error("文档转换出现问题：" + e.getMessage(),e);
							}
						}
					}
				}

				DocumentFormat isDocFormat = inpDocumentFormat;
				if (MyOfficeUtils.isExcel03(unknownFile)) {
					isDocFormat = DefaultDocumentFormatRegistry.XLS;
				} else if (MyOfficeUtils.isExcel07(unknownFile)) {
					isDocFormat = DefaultDocumentFormatRegistry.XLSX;
				}
				if (DefaultDocumentFormatRegistry.XLS == isDocFormat || DefaultDocumentFormatRegistry.XLSX == isDocFormat) {
					File file = new File(TMP_DIRECTORY, "xls" + UUID.randomUUID().toString().replace("-", "") + ".tmp");
					try {
						try (
							OutputStream tmpOs = toBufferedOutputStream(Files.newOutputStream(file.toPath()));
							Workbook workbook = WorkbookFactory.create(unknownFile);
						) {
							MyOfficeUtils.setExcelPrintScale(workbook, inputExcelPrintSetup);
							workbook.write(tmpOs);
						}
						ConversionJobWithSourceSpecified as = documentConverter.convert(file).as(isDocFormat);
						if (outFile != null) {
							if (outDocumentFormat != null) {
								as.to(outFile).as(outDocumentFormat).execute();
							} else {
								as.to(outFile).execute();
							}
						} else {
							OutputStream bufferedOs = toBufferedOutputStream(outp);
							as.to(bufferedOs, outpCloseStream).as(outDocumentFormat).execute();
						}
					} finally {
						try {
							Files.delete(file.toPath());
						} catch (Exception e) {
							log.error("文档转换出现问题：" + e.getMessage(),e);
						}
					}
				} else {
					if (inpDocumentFormat != null) {
						ConversionJobWithSourceSpecified as = documentConverter.convert(unknownFile).as(inpDocumentFormat);
						if (outFile != null) {
							if (outDocumentFormat != null) {
								as.to(outFile).as(outDocumentFormat).execute();
							} else {
								as.to(outFile).execute();
							}
						} else {
							OutputStream bufferedOs = toBufferedOutputStream(outp);
							as.to(bufferedOs, outpCloseStream).as(outDocumentFormat).execute();
						}
					} else {
						ConversionJobWithOptionalSourceFormatUnspecified as = documentConverter.convert(unknownFile);
						if (outFile != null) {
							if (outDocumentFormat != null) {
								as.to(outFile).as(outDocumentFormat).execute();
							} else {
								as.to(outFile).execute();
							}
						} else {
							OutputStream bufferedOs = toBufferedOutputStream(outp);
							as.to(bufferedOs, outpCloseStream).as(outDocumentFormat).execute();
						}
					}
				}
			} finally {
				try {
					Files.delete(unknownFile.toPath());
				} catch (Exception e) {
					log.error("文档转换出现问题：" + e.getMessage(),e);
				}
			}

		}
	}

	private static OutputStream toBufferedOutputStream(OutputStream stream) {
		if (stream instanceof BufferedOutputStream) {
			return stream;
		}
		return new BufferedOutputStream(stream);
	}

}
