package org.jeecg.modules.tools.office.convert;

import org.jodconverter.core.document.DefaultDocumentFormatRegistry;
import org.jodconverter.core.document.DocumentFormat;

import java.io.File;
import java.io.InputStream;
import java.io.OutputStream;

public class OfficeInputBox {

	private final OfficeConverterBox officeConverterBox;

	private File inpFile;

	private InputStream inp;

	private boolean closeStream = true;

	private DocumentFormat inpDocumentFormat;

	private OfficeInputExcelPrintSetup officeInputExcelPrintSetup;

	OfficeInputBox(OfficeConverterBox officeConverterBox, File inpFile) {
		this.officeConverterBox = officeConverterBox;
		this.inpFile = inpFile;
	}

	/**
	 *
	 * @param officeConverterBox 转换对象
	 * @param inp 输入流
	 * @param closeStream 是否关闭输入流，默认true
	 */
	OfficeInputBox(OfficeConverterBox officeConverterBox, InputStream inp, boolean closeStream) {
		this.officeConverterBox = officeConverterBox;
		this.inp = inp;
		this.closeStream = closeStream;
	}

	/**
	 *
	 * @param documentFormat @see {org.jodconverter.core.document.DefaultDocumentFormatRegistry}
	 * @return this
	 */
	public OfficeInputBox as(DocumentFormat documentFormat) {
		this.inpDocumentFormat = documentFormat;
		return this;
	}

	/**
	 *
	 * @param extension @see {org.jodconverter.core.document.DefaultDocumentFormatRegistry}
	 * @return this
	 */
	public OfficeInputBox asExtension(String extension) {
		this.inpDocumentFormat = DefaultDocumentFormatRegistry.getFormatByExtension(extension);
		return this;
	}

	/**
	 *
	 * @param mediaType @see {org.jodconverter.core.document.DefaultDocumentFormatRegistry}
	 * @return this
	 */
	public OfficeInputBox asMediaType(String mediaType) {
		this.inpDocumentFormat = DefaultDocumentFormatRegistry.getFormatByMediaType(mediaType);
		return this;
	}

	public OfficeInputExcelPrintSetup excel() {
		if (this.officeInputExcelPrintSetup == null) {
			this.officeInputExcelPrintSetup = new OfficeInputExcelPrintSetup(this);
		}
		return this.officeInputExcelPrintSetup;
	}

	public OfficeOutputBox to(File outFile) {
		return new OfficeOutputBox(this, outFile);
	}

	public OfficeOutputStreamBox to(OutputStream outp) {
		return new OfficeOutputStreamBox(this, outp, true);
	}

	public OfficeOutputStreamBox to(OutputStream outp, boolean closeStream) {
		return new OfficeOutputStreamBox(this, outp, closeStream);
	}

	OfficeConverterBox getOfficeConverterBox() {
		return officeConverterBox;
	}

	File getInpFile() {
		return inpFile;
	}

	InputStream getInp() {
		return inp;
	}

	boolean isCloseStream() {
		return closeStream;
	}

	DocumentFormat getInpDocumentFormat() {
		return inpDocumentFormat;
	}

	OfficeInputExcelPrintSetup getOfficeInputExcelPrintSetup() {
		return this.officeInputExcelPrintSetup;
	}

}
