package org.jeecg.modules.tools.office.convert;

import org.apache.poi.ss.usermodel.PrintSetup;

public class OfficeInputExcelPrintSetup {

	private final OfficeInputBox officeInputBox;

	/**
	 * 默认A4纸
	 */
	private short paperSize = PrintSetup.A4_PAPERSIZE;
	/**
	 * 默认横版
	 */
	private boolean landscape = true;
	/**
	 * 默认水平内容在一页上
	 */
	private short fitWidth = 1;
	/**
	 * 默认垂直内容分页
	 */
	private short fitHeight = 0;
	/**
	 * 默认铺满纸张
	 */
	private boolean fitToPage = true;
	/**
	 * 默认内容水平居中
	 */
	private boolean horizontallyCenter = true;
	/**
	 * 默认内容垂直与顶部对齐
	 */
	private boolean verticallyCenter = false;
	/**
	 * 默认不打印excel的行号和列号
	 */
	private boolean printRowAndColumnHeadings = false;

	OfficeInputExcelPrintSetup(OfficeInputBox officeInputBox) {
		this.officeInputBox = officeInputBox;
	}

	public OfficeInputBox end() {
		return this.officeInputBox;
	}

	/**
	 * 设置打印纸张大小
	 * @param paperSize @see {org.apache.poi.ss.usermodel.PrintSetup}
	 * @return this
	 */
	public OfficeInputExcelPrintSetup setPaperSize(short paperSize) {
		this.paperSize = paperSize;
		return this;
	}

	/**
	 * 设置打印方向，默认true
	 * @param landscape 是否横版打印
	 * @return this
	 */
	public OfficeInputExcelPrintSetup setLandscape(boolean landscape) {
		this.landscape = landscape;
		return this;
	}

	/**
	 * 设置打印宽度
	 * @param fitWidth 是否打印宽度方向的内容在一页上
	 * @return this
	 */
	public OfficeInputExcelPrintSetup setFitWidth(boolean fitWidth) {
		if (fitWidth) {
			this.fitWidth = 1;
		} else {
			this.fitWidth = 0;
		}
		return this;
	}

	/**
	 * 设置打印高度
	 * @param fitHeight 是否打印高度方向的内容在一页上
	 * @return this
	 */
	public OfficeInputExcelPrintSetup setFitHeight(boolean fitHeight) {
		if (fitHeight) {
			this.fitHeight = 1;
		} else {
			this.fitHeight = 0;
		}
		return this;
	}

	/**
	 * 设置是否铺满
	 * @param fitToPage 内容是否铺满页面
	 * @return this
	 */
	public OfficeInputExcelPrintSetup setFitToPage(boolean fitToPage) {
		this.fitToPage = fitToPage;
		return this;
	}

	/**
	 * 设置水平居中
	 * @param horizontallyCenter 内容是否水平居中
	 * @return this
	 */
	public OfficeInputExcelPrintSetup setHorizontallyCenter(boolean horizontallyCenter) {
		this.horizontallyCenter = horizontallyCenter;
		return this;
	}

	/**
	 * 设置垂直居中
	 * @param verticallyCenter 内容是否垂直居中
	 * @return this
	 */
	public OfficeInputExcelPrintSetup setVerticallyCenter(boolean verticallyCenter) {
		this.verticallyCenter = verticallyCenter;
		return this;
	}

	/**
	 * 设置是否打印行号和列号，默认false
	 * @param show 设置是否打印行号和列号
	 * @return this
	 */
	public OfficeInputExcelPrintSetup setPrintRowAndColumnHeadings(boolean show) {
		this.printRowAndColumnHeadings = show;
		return this;
	}

	short getPaperSize() {
		return paperSize;
	}

	boolean isLandscape() {
		return landscape;
	}

	short getFitWidth() {
		return fitWidth;
	}

	short getFitHeight() {
		return fitHeight;
	}

	boolean isFitToPage() {
		return fitToPage;
	}

	boolean isHorizontallyCenter() {
		return horizontallyCenter;
	}

	boolean isVerticallyCenter() {
		return verticallyCenter;
	}

	boolean isPrintRowAndColumnHeadings() {
		return printRowAndColumnHeadings;
	}

}
