package org.jeecg.modules.tools.view;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.io.IoUtil;
import cn.hutool.core.util.ZipUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.servlet.view.AbstractView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.Map;

@Controller("FileDownloadView")
@Slf4j
public class ZipDownloadView extends AbstractView {
	private static final String CONTENT_TYPE = "application/x-zip-compressed";

	/**
	 * 构造函数，设置为下载
	 */
	public ZipDownloadView() {
		this.setContentType("application/x-zip-compressed");
	}

	/**
	 * 是不是IE
	 * @param request
	 * @return
	 */
	public boolean isIE(HttpServletRequest request) {
		return request.getHeader("USER-AGENT").toLowerCase().indexOf("msie") > 0 || request.getHeader("USER-AGENT").toLowerCase().indexOf("rv:11.0") > 0;
	}

	/**
	 * 返回的内容
	 * @param model
	 * @param request
	 * @param response
	 * @throws Exception
	 */
	protected void renderMergedOutputModel(Map<String, Object> model, HttpServletRequest request, HttpServletResponse response) throws Exception {
		String codedFileName = "临时文件.zip";
		//如果存在文件名，则使用传进来的文件名
		if (model.containsKey("fileName")) {
			codedFileName = model.get("fileName") + ".docx";
		}

		//兼容IE
		if (this.isIE(request)) {
			codedFileName = URLEncoder.encode(codedFileName, "UTF8");
		} else {
			codedFileName = new String(codedFileName.getBytes(StandardCharsets.UTF_8), StandardCharsets.ISO_8859_1);
		}

		response.setHeader("content-disposition", "attachment;filename=" + codedFileName);
		OutputStream out = response.getOutputStream();
		//第一种压缩，根据实际文件压缩
		String zipFilePath = (String) model.get("zipFilePath");
		File zip = FileUtil.file(zipFilePath + ".zip");
		if (model.containsKey("zipPath")) {
			String zipPath = (String) model.get("zipPath");
			//****************************************生成zip压缩包***********************************************************//
			File zipDir = FileUtil.file(zipPath);
			//FileUtil.mkdir(zipDir);
			FileUtil.touch(zip);
			ZipUtil.zip(zip,false, zipDir);
			//删除临时文件夹
	//		FileUtil.del(zipDir);
			//files.forEach(FileUtil::del);
			//****************************************生成zip压缩包END********************************************************//

			InputStream is = new FileInputStream(zip);

	//		InputStream is = Files.newInputStream(Paths.get(zipFilePath + "zip"));

			IoUtil.write(out,true,IoUtil.readBytes(is));
			IoUtil.close(is);
			IoUtil.close(out);
			boolean isDelFile = (boolean) model.get("isDelFile");
			if(isDelFile){
				FileUtil.del(zip);
				FileUtil.del(zipDir);
			}
			log.info("打包完毕！准备下载!");
		}else{
			List<InputStream> inList = (List<InputStream>) model.get("inList");
			List<InputStream> nameList = (List<InputStream>) model.get("nameList");
			ZipUtil.zip(zip,nameList.toArray(new String[]{}),inList.toArray(new InputStream[]{}));

			InputStream is = new FileInputStream(zip);
			IoUtil.write(out,true,IoUtil.readBytes(is));
			IoUtil.close(is);
			IoUtil.close(out);
			boolean isDelFile = (boolean) model.get("isDelFile");
			if(isDelFile){
				FileUtil.del(zip);
			}
			log.info("打包完毕！准备下载!");

		}
	}
}
