package org.jeecg.modules.tools.word;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.io.IoUtil;
import com.google.common.collect.Lists;
import org.apache.commons.io.IOUtils;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.jeecg.common.util.SpringContextUtils;
import org.jeecg.modules.tools.FileUtils;
import org.jeecg.modules.tools.Global;
import org.jeecg.modules.tools.IdGen;
import org.jeecg.modules.tools.office.pdf.PDFUtil;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

/**
 * 导出word工具类
 * @author binzec
 */
public class ExportWord {

	private static Global global = SpringContextUtils.getBean(Global.class);

	public void setGlobal(Global g){
		global = g;
	}

	/**
	 * 模板根路径
	 */
	private final static String FILE_PATH = "officetemplates\\";

	public static WordOperator getWordOperator(String templateName) throws Exception {
		return getWordOperator(templateName,true);
	}

	/**
	 * 获取WordOperator对象
	 * @param templateName word模板名字（必须放在/src/main/resources/file/wordTemplates下）
	 * @param isResource   false时，从上传文件位置取数据   ture是从jar或war中读取资源文件流
	 * @return
	 * @throws Exception
	 */
	public static WordOperator getWordOperator(String templateName,boolean isResource) throws Exception {
		InputStream is = null;
		WordOperator wo = null;
		try {
			//从jar或war中读取资源文件流
			if(isResource){
				is = global.getResourceInputStream(FILE_PATH + templateName);
			}else{
				//直接从路径中获取
				is = new FileInputStream(new File(global.uploadPath + "/" + templateName));
			}
			wo = getWordOperator(is);
		}finally {
			IoUtil.close(is);
		}
		return wo;
//		return getWordOperator(new FileInputStream(Global.getResourceFile(FILE_PATH + templateName)));
	}

	public static WordOperator getWordOperator(InputStream is) throws Exception {
		return new WordOperator(is);
	}

	/**
	 * 下载生成的word文档
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param wordOperator	文档操作对象
	 */
	public static void download_word(HttpServletRequest request, HttpServletResponse response, String fileName, WordOperator wordOperator) throws Exception {
		ServletOutputStream os = null;
		try {
			// 设置好响应头，然后将文件保存到输出流里即可
			response.setContentType("application/vnd.openxmlformats-officedocument.wordprocessingml.document");
			response.setHeader("Content-Disposition", "attachment;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".docx", request));
			os = response.getOutputStream();
			wordOperator.write(os);
			os.flush();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			// 关闭输出流
			if (os != null) {
				os.close();
			}
		}
	}
	
	/**
	 * 下载生成的excel文档
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param wb	文档操作对象
	 */
	public static void download_excel(HttpServletRequest request, HttpServletResponse response, String fileName, XSSFWorkbook wb) throws Exception {
		ServletOutputStream os = null;
		try {
			// 设置好响应头，然后将文件保存到输出流里即可
			response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
			response.setHeader("Content-Disposition", "attachment;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".xlsx", request));
			os = response.getOutputStream();
			wb.write(os);
			os.flush();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			// 关闭输出流
			if (os != null) {
				os.close();
			}
		}
	}
	/**
	 * 下载生成的excel文档
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param workbook	文档操作对象
	 */
	public static void download_excel2(HttpServletRequest request, HttpServletResponse response, String fileName, Workbook workbook) throws Exception {
		ServletOutputStream os = null;
		try {
			// 设置好响应头，然后将文件保存到输出流里即可
			response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
			response.setHeader("Content-Disposition", "attachment;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".xlsx", request));
			os = response.getOutputStream();
			workbook.write(os);
			os.flush();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			// 关闭输出流
			if (os != null) {
				os.close();
			}
		}
	}
	/**
	 * 下载生成的excel文档
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param is	输入流
	 */
	public static void download_by_is(HttpServletRequest request, HttpServletResponse response, String fileName, InputStream is) throws Exception {
		ServletOutputStream os = null;
		try {
			// 设置好响应头，然后将文件保存到输出流里即可
			response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
			response.setHeader("Content-Disposition", "attachment;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".xlsx", request));
			os = response.getOutputStream();
			IoUtil.copy(is, os);
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			IoUtil.close(is);
			if(os != null) {
				IoUtil.close(os);
			}
		}
	}
	
	/**
	 * 下载生成的word文档（多文件合并）
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param woList		文档操作对象集合（合并顺序）
	 */
	public static void download_word(HttpServletRequest request, HttpServletResponse response, String fileName, WordOperator...woList) throws Exception {
		download_word(request,response,fileName,".docx",woList);
	}
	
	/**
	 * 下载生成的word文档（多文件合并）
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param suffix		新文档的后缀名
	 * @param woList		文档操作对象集合（合并顺序）
	 */
	public static void download_word(HttpServletRequest request, HttpServletResponse response, String fileName, String suffix, WordOperator...woList) throws Exception {
		ServletOutputStream os = null;
		List<String> tempDocList = new ArrayList<>();
		try {
			// 设置响应头
			response.setContentType("application/vnd.openxmlformats-officedocument.wordprocessingml.document");
			response.setHeader("Content-Disposition", "attachment;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + suffix, request));
			os = response.getOutputStream();
			// 一个ow对应一份文档，循环保存下来
			for (WordOperator wo : woList) {
				String tempDoc = global.getTmpDickPath() + IdGen.uuid() + suffix;
				FileUtil.touch(tempDoc);
				FileOutputStream fo = new FileOutputStream(tempDoc);
				wo.write(fo);
				IoUtil.close(fo);
				tempDocList.add(tempDoc);
			}
			// 然后把上面保存的文档合并起来
			String tempDoc = global.getTmpDickPath() + mergeDocx(tempDocList);
			tempDocList.add(tempDoc);
			// 将这份文档以流的形式保存到输出流中
			IOUtils.copy(new FileInputStream(new File(tempDoc)), os);
			os.flush();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			// 关闭输出流
			if (os != null) {
				os.close();
			}
			// 将全部临时文档删除掉
			for (String tempDoc : tempDocList) {
				FileUtils.delFile(tempDoc);
			}
		}
	}

	/**
	 * 下载生成的pdf文档
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param wordOperator	文档操作对象
	 */
	public static void download_pdf(HttpServletRequest request, HttpServletResponse response, String fileName, WordOperator wordOperator) throws Exception {
		ServletOutputStream os = null;
		String tempDoc = null;
		String tempPdf = null;
		try {
			// 设置响应头
			response.setContentType("application/vnd.openxmlformats-officedocument.wordprocessingml.document");
			response.setContentType(MimeUtils.getByExtension("pdf") + ";charset=UTF-8");
			response.setHeader("Content-Disposition", "attachment;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".pdf", request));
			// 先将生成的word文档保存起来
			tempDoc = global.getTmpDickPath() + IdGen.uuid() + ".docx";
			FileUtil.touch(tempDoc);
			FileOutputStream fo = new FileOutputStream(tempDoc);
			wordOperator.write(fo);
			IoUtil.close(fo);

			// 然后将word转成pdf保存起来
			tempPdf = global.getTmpDickPath() + IdGen.uuid() + ".pdf";
			PDFUtil.office2PDF(tempDoc,tempPdf);
//			FilePreviewUtils.word2ToPdf(tempDoc,tempPdf);
//			PDFUtils.office2PDF(tempDoc, tempPdf);
			// 将这份文档以流的形式保存到输出流中
			os = response.getOutputStream();
			FileUtils.copyFile(new File(tempPdf), os);
			os.flush();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			// 关闭输出流
			if (os != null) {
				os.close();
			}
			// 将临时文档删除掉
			if (tempDoc != null) {
				FileUtils.delFile(tempDoc);
			}
			// 将临时文档删除掉
			if (tempPdf != null) {
				FileUtils.delFile(tempPdf);
			}
		}
	}
	
	/**
	 * 下载生成的pdf文档（多文件合并）
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param woList		文档操作对象集合（合并顺序）
	 */
	public static void download_pdf(HttpServletRequest request, HttpServletResponse response, String fileName, WordOperator... woList) throws Exception {
		List<String> tempDocList = new ArrayList<String>();
		ServletOutputStream os = null;
		try {
			// 设置响应头
			response.setContentType("application/vnd.openxmlformats-officedocument.wordprocessingml.document");
			response.setContentType(MimeUtils.getByExtension("pdf") + ";charset=UTF-8");
			response.setHeader("Content-Disposition", "attachment;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".pdf", request));
			// 一个ow对应一份文档，循环保存下来
			for (WordOperator ow : woList) {
				String tempDoc = global.getTmpDickPath() + IdGen.uuid() + ".docx";
				FileUtil.touch(tempDoc);
				FileOutputStream fo = new FileOutputStream(tempDoc);
				ow.write(fo);
				IoUtil.close(fo);
				tempDocList.add(tempDoc);
			}
			// 然后把上面保存的文档合并起来
			String tempDoc = global.getTmpDickPath() + mergeDocx(tempDocList);
			tempDocList.add(tempDoc);
			// 再把这份合并好的文档转成pdf
			String tempPdf = global.getTmpDickPath() + IdGen.uuid() + ".pdf";
			PDFUtil.office2PDF(tempDoc,tempPdf);
//			FilePreviewUtils.word2ToPdf(tempDoc,tempPdf);
			tempDocList.add(tempPdf);
			// 将这份文档以流的形式保存到输出流中
			os = response.getOutputStream();
			FileUtils.copyFile(new File(tempPdf), os);
			os.flush();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			// 关闭输出流
			if (os != null) {
				os.close();
			}
			// 将全部临时文档删除掉
			for (String tempDoc : tempDocList) {
				FileUtils.delFile(tempDoc);
			}
		}
	}

	/**
	 * 预览生成的pdf文档
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param wordOperator	文档操作对象
	 * @throws Exception
	 */
	public static void preview_pdf(HttpServletRequest request, HttpServletResponse response, String fileName, WordOperator wordOperator) throws Exception {
		String tempDoc = null;
		String tempPdf = null;
		ServletOutputStream os = null;
		try {
//			FileUtils.createDirectory(global.getTmpDickPath());
			// 设置响应头
			response.setContentType(MimeUtils.getByExtension("pdf") + ";charset=UTF-8");
			response.setHeader("Content-Disposition", "inline;filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".pdf", request));
			// 先将生成的word文档保存起来
			// 2018年7月19日修改， 原方法读取word文件会报错   wy
//			tempDoc = global.getTmpDickPath() + IdGen.uuid() + ".docx";
			tempDoc = global.getTmpDickPath() + IdGen.uuid() + ".docx";
			FileUtil.touch(tempDoc);
			FileOutputStream fo = new FileOutputStream(tempDoc);
			wordOperator.write(fo);
			IoUtil.close(fo);
//			tempDoc = global.getTmpDickPath() + IdGen.uuid() + ".docx";
//			wordOperator.write(new FileOutputStream(tempDoc));
			// 然后将word转成pdf保存起来
			tempPdf = global.getTmpDickPath() + IdGen.uuid() + ".pdf";
			PDFUtil.office2PDF(tempDoc,tempPdf);
//			FilePreviewUtils.word2ToPdf(tempDoc,tempPdf);
//			PDFUtils.office2PDF(tempDoc, tempPdf);
			// 将pdf文档以流的形式输送给response
			os = response.getOutputStream();
			//是否将文件地址返回
//			if(returnHeadFile){
//				response.addHeader("Access-Control-Expose-Headers","pdfPath");
//				response.addHeader("Access-Control-Expose-Headers","wordPath");
//				response.setHeader("pdfPath",tempPdf);
//				response.setHeader("wordPath",tempDoc);
//			}
			FileUtils.copyFile(new File(tempPdf), os);

//			File pdfFile = new File(tempPdf);
//			FileUtils.copyFile(pdfFile, os);
			os.flush();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			// 关闭输出流
			if (os != null) {
				os.close();
			}
//			if(fileDelete){
			// 将word和pdf两个临时文件删除掉
			if (tempDoc != null) {
				FileUtils.delFile(tempDoc);
			}
			if (tempPdf != null) {
				FileUtils.delFile(tempPdf);
			}
//			}
		}
	}

	/**
	 * 预览生成的pdf文档（多文件合并）
	 * @param request		请求
	 * @param response		响应
	 * @param fileName		新文档名字（不带后缀名）
	 * @param woList		文档操作对象集合（合并顺序）
	 */
	public static void preview_pdf(HttpServletRequest request, HttpServletResponse response, String fileName, WordOperator... woList) throws Exception {
		List<String> tempDocList = Lists.newArrayList();
		ServletOutputStream os = null;
		try {
			// 设置响应头
			response.setContentType(MimeUtils.getByExtension("pdf") + ";charset=UTF-8");
			response.setHeader("Content-Disposition", "inline; filename=" + FileUtils.encodeFileName(FileUtils.addRandom(fileName) + ".pdf", request));
			// 一个ow对应一份文档，循环保存下来
			for (WordOperator ow : woList) {
				String tempDoc = global.getTmpDickPath() + IdGen.uuid() + ".docx";
				FileUtil.touch(tempDoc);
				FileOutputStream fo = new FileOutputStream(tempDoc);
				ow.write(fo);
				IoUtil.close(fo);
				tempDocList.add(tempDoc);
			}
			// 然后把上面保存的文档合并起来
			String tempDoc = global.getTmpDickPath() + mergeDocx(tempDocList);
			tempDocList.add(tempDoc);
			// 再把这份合并好的文档转成pdf
			String tempPdf = global.getTmpDickPath() + IdGen.uuid() + ".pdf";
			PDFUtil.office2PDF(tempDoc,tempPdf);
//			FilePreviewUtils.word2ToPdf(tempDoc,tempPdf);
//			PDFUtils.office2PDF(tempDoc, tempPdf);
			tempDocList.add(tempPdf);
			// 将这份文档以流的形式保存到输出流中
			os = response.getOutputStream();
			FileUtils.copyFile(new File(tempPdf), os);
			os.flush();
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			// 关闭输出流
			if (os != null) {
				os.close();
			}
			// 将全部临时文档删除掉
			for (String tempDoc : tempDocList) {
				FileUtils.delFile(tempDoc);
			}
		}
	}

	public static String mergeDocx(List<String> fileNames) throws Exception {
		return MergeDoc.mergeDocx(fileNames,global.getTmpDickPath());
	}

}
