/**********************************************************************
* $Id: MergeDoc.java MergeDoc ,v0.1 2019年4月26日 下午7:12:00 byx Exp $
* Copyright ©2019 ccqnsoft . All rights reserved
***********************************************************************/

package org.jeecg.modules.tools.word;

import cn.hutool.core.io.IoUtil;
import com.google.common.collect.Lists;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.xwpf.usermodel.BreakType;
import org.apache.poi.xwpf.usermodel.Document;
import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.apache.poi.xwpf.usermodel.XWPFPictureData;
import org.apache.xmlbeans.XmlOptions;
import org.jeecg.modules.tools.IdGen;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTBody;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/** 
 * @author: Max 
 *   
 * @Date: 2018/6/8 
 *   
 * @name: 多个word文件合并，采用poi实现,兼容图片的迁移 
 * 
 * @Description:
 */  
public class MergeDoc {

	/**
	 * 合并若干个文档（按顺序合并），默认的方法，带分页
	 * @param fileNames	需要合并的几个word文档全路径
	 * @param tempPath	临时文件放在哪
	 * @return 返回合并好的文档名称，位置在DICK下
	 */
	public static String mergeDocx(List<String> fileNames,String tempPath) throws Exception {
		return mergeDocx(fileNames,tempPath,true);
	}

	/**
	 * 合并若干个文档（按顺序合并）
	 * @param fileNames	需要合并的几个word文档全路径
	 * @param tempPath	临时文件放在哪
	 * @param isAddBreak	是否自动分页，true：带分页，false:不带分页
	 * @return 返回合并好的文档名称，位置在DICK下
	 */
	public static String mergeDocx(List<String> fileNames,String tempPath,boolean isAddBreak) throws Exception {
		String tmpFileName = IdGen.uuid() + ".docx";
		OutputStream dest = new FileOutputStream(tempPath + tmpFileName);
		ArrayList<XWPFDocument> documentList = new ArrayList<>();
		
		XWPFDocument doc = null;
		for (int i = 0; i < fileNames.size(); i++) {
			FileInputStream in = new FileInputStream(fileNames.get(i));
			OPCPackage open = OPCPackage.open(in);
			XWPFDocument document = new XWPFDocument(open);
			documentList.add(document);
		}
		
		for (int i = 0; i < documentList.size(); i++) {
			doc = documentList.get(0);
			if(i == 0){//首页直接分页，不再插入首页文档内容
				if(isAddBreak){
				    System.out.println("第【" + i + "】表格！");
					documentList.get(i).createParagraph().createRun().addBreak(BreakType.PAGE);
				}
			}else if(i == documentList.size()-1){//尾页不再分页，直接插入最后文档内容
			    System.out.println("第【" + i + "】表格！");
				appendBody(doc,documentList.get(i));
			}else{
			    System.out.println("第【" + i + "】表格！");
				if(isAddBreak) {
					documentList.get(i).createParagraph().createRun().addBreak(BreakType.PAGE);
				}
				appendBody(doc,documentList.get(i));
			}
		}
		doc.write(dest);
		IoUtil.close(dest);
		System.out.println("*****合并文档成功********");
		return tmpFileName;
	}

	public static void appendBody(XWPFDocument src, XWPFDocument append) throws Exception {
		CTBody src1Body = src.getDocument().getBody();
		CTBody src2Body = append.getDocument().getBody();

		List<XWPFPictureData> allPictures = append.getAllPictures();
		// 记录图片合并前及合并后的ID
		Map<String,String> map = new HashMap<>();
		for (XWPFPictureData picture : allPictures) {
			String before = append.getRelationId(picture);
			//将原文档中的图片加入到目标文档中
			String after = src.addPictureData(picture.getData(), Document.PICTURE_TYPE_PNG);
			map.put(before, after);
		}
		appendBody(src1Body, src2Body,map);
	}

	private static void appendBody(CTBody src, CTBody append,Map<String,String> map) throws Exception {
		XmlOptions optionsOuter = new XmlOptions();
		optionsOuter.setSaveOuter();
		String appendString = append.xmlText(optionsOuter);

		
		String srcString = src.xmlText();
		String rgex = "<[\\s]*?w:sectPr[^>]*?>[\\s\\S]*?<[\\s]*?\\/[\\s]*?w:sectPr[\\s]*?>";
		appendString = appendString.replaceAll(rgex, "");
		String prefix = srcString.substring(0,srcString.indexOf(">")+1);
		String mainPart = srcString.substring(srcString.indexOf(">")+1,srcString.lastIndexOf("<"));
		String sufix = srcString.substring( srcString.lastIndexOf("<") );
		String addPart = appendString.substring(appendString.indexOf(">") + 1, appendString.lastIndexOf("<"));
		if (map != null && !map.isEmpty()) {
			//对xml字符串中图片ID进行替换
			for (Map.Entry<String, String> set : map.entrySet()) {
				addPart = addPart.replace(set.getKey(), set.getValue());
			}
		}
		//将两个文档的xml内容进行拼接
		CTBody makeBody = CTBody.Factory.parse(prefix+mainPart+addPart+sufix);
		src.set(makeBody);
	}

	//获取文档的xml内容
	public static String getWordXml(File file) throws Exception {
		FileInputStream in = new FileInputStream(file);
		OPCPackage open = OPCPackage.open(in);
		XWPFDocument document = new XWPFDocument(open);
		CTBody body = document.getDocument().getBody();
		return body.xmlText();
	}
	
	public static void main(String[] args) {
	    String file0 = "D:/opt/upFiles/pdfTemp/yb/0.docx";
	    String file1 = "D:/opt/upFiles/pdfTemp/yb/3.docx";
	    List<String> files = Lists.newArrayList();
	    files.add(file0);
	    files.add(file1);
	    try {
	        MergeDoc.mergeDocx(files,"D:/opt/upFiles/pdfTemp/hb",false);
            System.out.println("0 =>" + getWordXml(new File(file0)));
            System.out.println("1 =>" + getWordXml(new File(file1)));
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }

}