/**********************************************************************
* $Id: WordImageLabel.java WordImageLabel ,v0.1 2018年9月19日 下午8:50:48 byx Exp $
* Copyright ©2018 sida . All rights reserved
***********************************************************************/

package org.jeecg.modules.tools.word;


import lombok.Data;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.xwpf.usermodel.UnderlinePatterns;
import org.apache.poi.xwpf.usermodel.VerticalAlign;
import org.apache.poi.xwpf.usermodel.XWPFRun;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTShd;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.STHighlightColor;

/**
* 功能说明：从标签中读取键值，宽高和后缀内容
* 创建者：byx
* 创建时间：2018年9月19日
* <pre>
* 修改时间:       修改者:            
* 修改内容：
* </pre>
*/
@Data
public class WordTextStyle {

	/**
	 * 颜色
	 */
	private String color;

	public void runColor(XWPFRun run){
		if(run != null && StringUtils.isNotBlank(color)){
			run.setColor(color);
		}
	}

	/**
	 * 加粗
	 */
	private Boolean isBold;

	public void runBold(XWPFRun run){
		if(run != null && isBold != null){
			run.setBold(isBold);
		}
	}

	/**
	 * 背景色(文本突出显示颜色)
	 */
	private STHighlightColor.Enum bColor;

	public void runBColor(XWPFRun run){
		if(run != null && bColor != null){
			run.getCTR().addNewRPr().addNewHighlight().setVal(bColor);
		}
	}

	/**
	 * 底纹
	 */
	private String shading;

	public void runShading(XWPFRun run){
		if(run != null && StringUtils.isNotBlank(shading)){
			CTShd shd = run.getCTR().addNewRPr().addNewShd();
			shd.setFill(shading);
		}
	}

	/**
	 * 字体
	 */
	private String fontFamily;

	public void runFontFamily(XWPFRun run){
		if(run != null && StringUtils.isNotBlank(fontFamily)){
			run.setFontFamily(fontFamily);
		}
	}

	/**
	 * 字体大小
	 */
	private Integer fontSize;

	public void runFontSize(XWPFRun run){
		if(run != null && fontSize != null){
			run.setFontSize(fontSize);
		}
	}

	/**
	 * 阴影
	 */
	private Boolean shadow;

	public void runShadow(XWPFRun run){
		if(run != null && shadow != null){
			run.setShadow(shadow);
		}
	}

	/**
	 * 浮雕？？？？
	 */
	private Boolean embossed;

	public void runEmbossed(XWPFRun run){
		if(run != null && embossed != null){
			run.setEmbossed(embossed);
		}
	}

	/**
	 * 删除线
	 */
	private Boolean strikeThrough;

	public void runStrikeThrough(XWPFRun run){
		if(run != null && strikeThrough != null){
			run.setStrikeThrough(strikeThrough);
		}
	}

	/**
	 * 双删除线
	 */
	private Boolean doubleStrikethrough;

	public void runDoubleStrikethrough(XWPFRun run){
		if(run != null && doubleStrikethrough != null){
			run.setDoubleStrikethrough(doubleStrikethrough);
		}
	}

	/**
	 * 大写？？？？
	 */
	private Boolean capitalized;

	public void runCapitalizedg(XWPFRun run){
		if(run != null && capitalized != null){
			run.setCapitalized(capitalized);
		}
	}

	/**
	 * 印记？？？？
	 */
	private Boolean imprinted;

	public void runImprinted(XWPFRun run){
		if(run != null && imprinted != null){
			run.setImprinted(imprinted);
		}
	}

	/**
	 * 斜体
	 */
	private Boolean italic;

	public void runItalic(XWPFRun run){
		if(run != null && italic != null){
			run.setItalic(italic);
		}
	}
	/**
	 * 小型大写字母??
	 */
	private Boolean smallCaps;

	public void runSmallCaps(XWPFRun run){
		if(run != null && smallCaps != null){
			run.setSmallCaps(smallCaps);
		}
	}
	/**
	 * 字符间距
	 */
	private Integer kerning;

	public void runKerning(XWPFRun run){
		if(run != null && kerning != null){
			run.setKerning(kerning);
		}
	}

	/**
	 * 文本位置
	 */
	private Integer textPosition;

	public void runTextPosition(XWPFRun run){
		if(run != null && textPosition != null){
			run.setTextPosition(textPosition);
		}
	}

	/**
	 * 下标
	 */
	private VerticalAlign subscript;

	public void runSubscript(XWPFRun run){
		if(run != null && subscript != null){
			run.setSubscript(subscript);
		}
	}

	/**
	 * 下划线
	 */
	private UnderlinePatterns underline;

	public void runUnderline(XWPFRun run){
		if(run != null && underline != null){
			run.setUnderline(underline);
		}
	}

	/**
	 *
	 * @param run
	 */
	public void run(XWPFRun run){
		runColor(run);
		runBold(run);
		runBColor(run);
		runShading(run);
		runFontFamily(run);
		runFontSize(run);
		runShadow(run);
		runEmbossed(run);
		runStrikeThrough(run);
		runDoubleStrikethrough(run);
		runCapitalizedg(run);
		runImprinted(run);
		runItalic(run);
		runSmallCaps(run);
		runKerning(run);
		runTextPosition(run);
		runSubscript(run);
		runUnderline(run);

	}




}
