package org.jeecg.modules.wps.controller;

import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import java.io.*;
import java.nio.charset.StandardCharsets;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import com.alibaba.fastjson.JSONObject;
import org.apache.http.HttpEntity;
import org.apache.http.NameValuePair;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import java.util.*;

public class KsoSign {
    private final String accessKey;
    private final String secretKey;

    public KsoSign(String accessKey, String secretKey) {
        this.accessKey = accessKey;
        this.secretKey = secretKey;
    }

    public static final class Out {
        private final String date;  // X-Kso-Date
        private final String authorization;  // X-Kso-Authorization

        public Out(String date, String authorization) {
            this.date = date;
            this.authorization = authorization;
        }

        public String getDate() {
            return date;
        }

        public String getAuthorization() {
            return authorization;
        }
    }

    public Out kso1Sign(String method, String uri, String contentType, String ksoDate, byte[] requestBody) throws NoSuchAlgorithmException, InvalidKeyException {
        String ksoSignature = getKso1Signature(method, uri, contentType, ksoDate, requestBody);
        String authorization = String.format("KSO-1 %s:%s", accessKey, ksoSignature);
        return new Out(ksoDate, authorization);
    }

    private String getKso1Signature(String method, String uri, String contentType, String ksoDate, byte[] requestBody) throws NoSuchAlgorithmException, InvalidKeyException {
        String sha256Hex = "";
        if (requestBody != null && requestBody.length > 0) {
            MessageDigest digest = MessageDigest.getInstance("SHA-256");
            byte[] hash = digest.digest(requestBody);
            sha256Hex = bytesToHex(hash);
        }

        System.out.println("sha256: " + sha256Hex);

        String dataToSign = "KSO-1" + method + uri + contentType + ksoDate + sha256Hex;
        Mac mac = Mac.getInstance("HmacSHA256");
        SecretKeySpec secretKeySpec = new SecretKeySpec(secretKey.getBytes(StandardCharsets.UTF_8), "HmacSHA256");
        mac.init(secretKeySpec);
        byte[] macBytes = mac.doFinal(dataToSign.getBytes(StandardCharsets.UTF_8));
        return bytesToHex(macBytes);
    }

    private String bytesToHex(byte[] bytes) {
        StringBuilder result = new StringBuilder();
        for (byte b : bytes) {
            result.append(String.format("%02x", b));
        }
        return result.toString();
    }


    /**
     * 获取签名
     * @return
     */
    public static Map<String,String> getAuthorization(){
        Map<String,String> map = new HashMap<>();
//        final String accessKey = "SX20241118WSUGQN";
//        final String secretKey = "IbRfANAvtsOoSAeKASHfiOMYlBpeVTqg";
        final String accessKey = "AK20241118LLGJYF";
        final String secretKey = "ce3e6d90a27c1ef238ce1b0b81a8d902";
        final String method = "POST";
        final String uri = "/v7/test/body";
        final String contentType = "application/json";
        final String contentDate = new Date().toString();
        final byte[] requestBody = "{\"key\": \"value\"}".getBytes(StandardCharsets.UTF_8);

        KsoSign kso = new KsoSign(accessKey, secretKey);
        try {
             KsoSign.Out out = kso.kso1Sign(method, uri, contentType, contentDate, requestBody);
            System.out.println(out.getDate());
            System.out.println(out.getAuthorization());
            String data = out.getDate();
            String authorization = out.getAuthorization();
            map.put("data",data);
            map.put("authorization",authorization);
             return map;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 获取token
     * @return
     * @throws IOException
     */
    public static Map<String,String> getToken() throws IOException {
        String httpsURL = "https://openapi.wps.cn/oauth2/token";
        CloseableHttpClient httpClient = HttpClients.createDefault();
        HttpPost httpPost = new HttpPost(httpsURL);

        // 设置请求头
        httpPost.setHeader("Content-Type", "application/x-www-form-urlencoded");

        // 创建请求内容
        List<NameValuePair> params = new ArrayList<>();
        params.add(new BasicNameValuePair("grant_type", "client_credentials"));
        params.add(new BasicNameValuePair("client_id", "AK20241118LLGJYF"));
        params.add(new BasicNameValuePair("client_secret", "ce3e6d90a27c1ef238ce1b0b81a8d902"));
        HttpEntity entity = new UrlEncodedFormEntity(params,"UTF-8");
        System.out.println("entity ： "+entity.toString());
        httpPost.setEntity(entity);

        // 发送请求并获取响应
        CloseableHttpResponse response = httpClient.execute(httpPost);

        // 打印响应状态
        System.out.println("Response Code : " + response.getStatusLine().getStatusCode());

        // 获取响应内容并关闭
        String responseBody = EntityUtils.toString(response.getEntity());
        System.out.println("responseBody : "+responseBody);

        // 关闭HttpClient和response
        httpClient.close();
        response.close();
        Map<String,String> map = new HashMap<>();
        if(response.getStatusLine().getStatusCode() == 200){
            JSONObject jsonObject = JSONObject.parseObject(responseBody);
            map.put("code","200");
            map.put("access_token",jsonObject.getString("access_token"));
            map.put("msg","获取token成功");
        }else{
            map.put("code","500");
            map.put("msg","获取token失败");
        }
        return map;
    }




    public static void main(String[] args) throws Exception {
        //------------------获取token----------------------------
        Map<String,String> mapToken = getToken();//获取token
        System.out.println("code---" + mapToken.get("code"));
        System.out.println("access_token---" + mapToken.get("access_token"));
        //------------------获取token----------------------------

        //------------------获取Authorization----------------------------
       Map<String,String> mapAuthorization = getAuthorization();
        //------------------获取Authorization----------------------------

    }

}



