package org.jeecg.modules.wps.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.kc.kcCasusers.entity.KcCasusers;
import org.jeecg.modules.kc.kcCasusers.service.IKcCasusersService;
import org.jeecg.modules.kc.zyInfoStudent.entity.ZyInfoStudent;
import org.jeecg.modules.kc.zyInfoStudent.service.IZyInfoStudentService;
import org.jeecg.modules.kc.zyZyxx.entity.ZyZyxx;
import org.jeecg.modules.system.controller.CommonController;
import org.jeecg.modules.system.entity.SysUser;
import org.jeecg.modules.system.service.ISysUserService;
import org.jeecg.modules.wps.entity.WpsEnti;
import org.jeecg.modules.wps.entity.WpsUploadEnti;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.util.*;

/**
 * @Description: kc_casusers
 * @Author: jeecg-boot
 * @Date: 2023-05-22
 * @Version: V1.0
 */
@RestController
@RequestMapping("/v3/3rd")
@Slf4j
public class WpsController extends JeecgController<KcCasusers, IKcCasusersService> {
    @Autowired
    private IZyInfoStudentService zyInfoStudentService;

    @Autowired
    private ISysUserService sysUserService;

    @Autowired
    private CommonController commonController;

    /**
     * 文档预览
     *
     * @param fileId
     * @return
     */
    @RequestMapping(value = "/files/{fileId}", method = {RequestMethod.GET})
    public Map<String, Object> files(@PathVariable("fileId") String fileId) {

        ZyInfoStudent zyInfoStudent = zyInfoStudentService.getById(fileId);
        WpsEnti map = new WpsEnti();
        map.setId(zyInfoStudent.getId());
        map.setName(zyInfoStudent.getFilePath());
        map.setVersion(1);
        map.setSize(1);
        map.setName(zyInfoStudent.getFilePath().substring(zyInfoStudent.getFilePath().lastIndexOf("/") + 1));
        Long createTime = zyInfoStudent.getCreateTime().getTime() / 1000;
        Long updateTime = zyInfoStudent.getUpdateTime().getTime() / 1000;
        map.setCreate_time(Integer.parseInt(createTime + ""));
        map.setModify_time(Integer.parseInt(updateTime + ""));
        map.setCreator_id(zyInfoStudent.getCreateBy());
        map.setModifier_id(zyInfoStudent.getUpdateBy());
        Map<String, Object> mapRet = new HashMap<>();
        mapRet.put("code", 0);
        mapRet.put("data", map);
        return mapRet;
    }

    /**
     * 文件下载地址
     *
     * @param fileId
     * @return
     */
    @RequestMapping(value = "/files/{fileId}/download", method = {RequestMethod.GET})
    public Map<String, Object> download(@PathVariable("fileId") String fileId) {
        log.info("~~~~~~~~~~~~>>>>>>>>>>>");
        log.info("download--fileId=" + fileId);
        log.info("~~~~~~~~~~~~<<<<<<<<<<<");
        ZyInfoStudent zyInfoStudent = zyInfoStudentService.getById(fileId);
        Map<String, Object> mapRet = new HashMap<>();
        Map<String, Object> mapRet2 = new HashMap<>();
        mapRet2.put("url", "https://kczxcs.nenu.edu.cn/jeecg-boot/sys/common/static/" + zyInfoStudent.getFilePath());
        Map<String, String> headers = new HashMap<>();
        mapRet.put("code", 0);
        mapRet.put("data", mapRet2);
        return mapRet;
    }


    /**
     * 获取文档用户权限
     *
     * @param fileId
     * @return
     */
    @RequestMapping(value = "/files/{fileId}/permission", method = {RequestMethod.GET})
    public Map<String, Object> permission(@PathVariable("fileId") String fileId,
                                          @RequestHeader(value = "X-WebOffice-Token", required = false) String webOfficeToken) {
        ZyInfoStudent zyInfoStudent = zyInfoStudentService.getById(fileId);
        Map<String, Object> mapRet = new HashMap<>();
        Map<String, Object> mapRet2 = new HashMap<>();
        mapRet.put("code", 0);
        mapRet2.put("comment", 1);
//        mapRet2.put("copy",1);
        mapRet2.put("download", 1);
        mapRet2.put("history", 1);
        mapRet2.put("print", 1);
        mapRet2.put("read", 1);
//        mapRet2.put("rename",1);
//        mapRet2.put("saveas",1);
        mapRet2.put("update", webOfficeToken.equals(zyInfoStudent.getCreateBy()) ? 0 : 1);
//        mapRet2.put("user_id",zyInfoStudent.getCreateBy());
        mapRet2.put("user_id", webOfficeToken);
        mapRet.put("data", mapRet2);
        return mapRet;
    }


    /**
     * 文档预览
     *
     * @param fileId
     * @return
     */
    @RequestMapping(value = "/files/{fileId}/versions", method = {RequestMethod.GET})
    public Map<String, Object> versions(@PathVariable("fileId") String fileId) {

        ZyInfoStudent zyInfoStudent = zyInfoStudentService.getById(fileId);
        WpsEnti map = new WpsEnti();
        map.setId(zyInfoStudent.getId());
        map.setName(zyInfoStudent.getFilePath());
        map.setVersion(1);
        map.setSize(1);
        map.setName(zyInfoStudent.getFilePath().substring(zyInfoStudent.getFilePath().lastIndexOf("/") + 1));
        Long createTime = zyInfoStudent.getCreateTime().getTime() / 1000;
        Long updateTime = zyInfoStudent.getUpdateTime().getTime() / 1000;
        map.setCreate_time(Integer.parseInt(createTime + ""));
        map.setModify_time(Integer.parseInt(updateTime + ""));
        map.setCreator_id(zyInfoStudent.getCreateBy());
        map.setModifier_id(zyInfoStudent.getUpdateBy());
        Map<String, Object> mapRet = new HashMap<>();
        mapRet.put("code", 0);
        mapRet.put("data", map);
        return mapRet;
    }


    @GetMapping(value = "/users")
    public Map<String, Object> users(@RequestParam(name = "user_ids", required = true) String user_ids) {
        System.out.println("user_ids : " + user_ids);
        String userIds[] = user_ids.split(",");
        List<Map<String, Object>> list = new ArrayList<>();
        Map<String, Object> mapRet = new HashMap<>();
        mapRet.put("code", 0);
        for (String userId : userIds) {
            SysUser sysUser = sysUserService.getUserByName(userId);
            System.out.println("sysUser : " + sysUser);
            Map<String, Object> map = new HashMap<>();
            map.put("id", sysUser.getUsername());
            map.put("name", sysUser.getRealname());
            list.add(map);
        }

        mapRet.put("data", list);
        return mapRet;
    }


    /**
     * 准备上传阶段
     *
     * @param fileId
     * @return
     */
    @RequestMapping(value = "/files/{fileId}/upload/prepare", method = {RequestMethod.GET})
    public Map<String, Object> prepare(@PathVariable("fileId") String fileId) {
        Map<String, Object> mapRet = new HashMap<>();
        mapRet.put("code", 0);
        Map<String, Object> mapRet2 = new HashMap<>();
        String jmArr[] = {"sha1"};
        mapRet2.put("digest_types", jmArr);
        mapRet.put("data", mapRet2);
        mapRet.put("message", "");
        return mapRet;
    }


    @RequestMapping(value = "/files/{fileId}/upload/address", method = {RequestMethod.POST})
    public Map<String, Object> address(@PathVariable("fileId") String fileId, @RequestBody WpsUploadEnti wpsUploadEnti) {
        ZyInfoStudent zyInfoStudent = zyInfoStudentService.getById(fileId);
        Map<String, Object> mapRet = new HashMap<>();
        mapRet.put("code", 0);
        Map<String, Object> mapRet2 = new HashMap<>();
        mapRet2.put("url", "https://kczxcs.nenu.edu.cn/jeecg-boot/v3/3rd/static/" + zyInfoStudent.getFilePath());
        mapRet2.put("method", "POST");
        mapRet.put("data", mapRet2);
        mapRet.put("message", "");
        return mapRet;
    }

    @RequestMapping(value = "/files/{fileId}/upload/complete", method = {RequestMethod.POST})
    public Map<String, Object> complete(@PathVariable("fileId") String fileId, @RequestBody WpsUploadEnti wpsUploadEnti, HttpServletRequest request, HttpServletResponse response) {
        ZyInfoStudent zyInfoStudent = zyInfoStudentService.getById(fileId);
        Map<String, Object> mapRet = new HashMap<>();
        mapRet.put("code", 0);
        WpsEnti map = new WpsEnti();
        map.setId(zyInfoStudent.getId());
        map.setName(zyInfoStudent.getFilePath());
        map.setVersion(2);
        map.setSize(1);
        map.setName(zyInfoStudent.getFilePath().substring(zyInfoStudent.getFilePath().lastIndexOf("/") + 1));
        Long createTime = zyInfoStudent.getCreateTime().getTime() / 1000;
        Long updateTime = zyInfoStudent.getUpdateTime().getTime() / 1000;
        map.setCreate_time(Integer.parseInt(createTime + ""));
        map.setModify_time(Integer.parseInt(updateTime + ""));
        map.setCreator_id(zyInfoStudent.getCreateBy());
        map.setModifier_id(zyInfoStudent.getUpdateBy());
        mapRet.put("data", map);
        mapRet.put("message", "");
        return mapRet;
    }

    @PostMapping("/static/temp/{fileName}")
    public ResponseEntity<String> downloadFile(@PathVariable String fileName
            , @RequestParam(value = "file", required = false) MultipartFile file) {
        log.info(">>>>>>>>>");
        log.info("fileName=" + fileName);
        String newFileName = fileName.substring(0, fileName.indexOf("_")) + "_" + System.currentTimeMillis() + fileName.substring(fileName.indexOf("."));
        log.info("fileName222处理后=", newFileName);
        String savePath = commonController.uploadLocal(file, newFileName, "temp");
        log.info("savePath=" + savePath);
        log.info("<<<<<<<<<");
        //TODO 存数据库 不能旧的不删除然后每次都新存  前端关闭弹窗时调用保存方法来触发这个接口
        return null;
    }

}
