package org.jeecg.modules.zyk.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.util.AntPathMatcher;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.constant.SymbolConstant;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.util.DySmsHelper;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.zyk.entity.ZykInfo;
import org.jeecg.modules.zyk.service.IZykService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.HandlerMapping;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.util.Arrays;
import java.util.Date;
import java.util.Map;

/**
* @Description: 资源库信息
* @Author: jeecg-boot
* @Date:   2024-05-16
* @Version: V1.0
*/
@Api(tags="资源库信息")
@RestController
@RequestMapping("/zyk/zykInfo")
@Slf4j
public class ZykController extends JeecgController<ZykInfo, IZykService> {

    private final static Logger logger= LoggerFactory.getLogger(ZykController.class);

    @Autowired
    private IZykService zykService;

    @AutoLog(value = "资源库信息-分页列表查询")
    @ApiOperation(value="资源库信息-分页列表查询", notes="资源库信息-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<ZykInfo>> queryPageList(ZykInfo zykInfo,
                                           @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
                                           @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
                                           HttpServletRequest req) {
        Page<ZykInfo> pageList = zykService.findPage(zykInfo,new Page<ZykInfo>(pageNo, pageSize));
        return Result.OK(pageList);
    }

    @AutoLog(value = "资源库信息-添加")
    @ApiOperation(value="资源库信息-添加", notes="资源库信息-添加")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody ZykInfo zykInfo) {
        String res = zykService.saveInfo(zykInfo);
        return Result.OK(res);
    }

    /**
     *  编辑
     * @param zykInfo
     * @return
     */
    @AutoLog(value = "资源库信息-编辑")
    @ApiOperation(value="资源库信息-编辑", notes="资源库信息-编辑")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
    public Result<String> edit(@RequestBody ZykInfo zykInfo) {
        String res = zykService.modifyInfo(zykInfo);
//        Map<String,String> res = zykService.saveToZyk(zykInfo);
        return Result.OK(res);
    }

    /**
     *   通过id删除
     * @param id
     * @return
     */
    @AutoLog(value = "资源库信息-通过id删除")
    @ApiOperation(value="资源库信息-通过id删除", notes="资源库信息-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name="id",required=true) String id) {
        String res = zykService.removeById(id);
        return Result.OK(res);
    }

    /**
     *  批量删除
     * @param ids
     * @return
     */
    @AutoLog(value = "资源库信息-批量删除")
    @ApiOperation(value="资源库信息-批量删除", notes="资源库信息-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
        String res = zykService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK(res);
    }

    /**
     * 预览图片&下载文件
     * 请求地址：http://localhost:8080/common/static/{user/20190119/e1fe9925bc315c60addea1b98eb1cb1349547719_1547866868179.jpg}
     * @param request
     * @param response
     */
    @GetMapping(value = "/static/**")
    public void view(HttpServletRequest request, HttpServletResponse response) {
        logger.info("zyk/zykInfo/static/SFTP下载 ..."+new Date());
        // ISO-8859-1 ==> UTF-8 进行编码转换
        String filePath = extractPathFromPattern(request);
        if(oConvertUtils.isEmpty(filePath) || CommonConstant.STRING_NULL.equals(filePath)){
            return;
        }
        // 其余处理略
        InputStream inputStream = null;
        OutputStream outputStream = null;
        try {
            filePath = filePath.replace("..", "").replace("../","");
            if (filePath.endsWith(SymbolConstant.COMMA)) {
                filePath = filePath.substring(0, filePath.length() - 1);
            }
            Map<String,String> map = zykService.downloadRemoteFile(filePath);
            if(!map.get("code").equals("0")){
                throw new RuntimeException(map.get("msg"));
            }
            String localFilePath = map.get("data");
            File file = new File(localFilePath);
            if(!file.exists()){
                response.setStatus(404);
                throw new RuntimeException("文件["+filePath+"]不存在..");
            }
            // 设置强制下载不打开
//            response.setContentType("application/force-download");
            response.addHeader("Content-Disposition", "attachment;fileName=" + new String(file.getName().getBytes("UTF-8"),"iso-8859-1"));
            inputStream = new BufferedInputStream(new FileInputStream(localFilePath));
            outputStream = response.getOutputStream();
            byte[] buf = new byte[1024];
            int len;
            while ((len = inputStream.read(buf)) > 0) {
                outputStream.write(buf, 0, len);
            }
            response.flushBuffer();
        } catch (IOException e) {
            log.error("预览文件失败" + e.getMessage());
            response.setStatus(404);
            e.printStackTrace();
        } finally {
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    log.error(e.getMessage(), e);
                }
            }
            if (outputStream != null) {
                try {
                    outputStream.close();
                } catch (IOException e) {
                    log.error(e.getMessage(), e);
                }
            }
        }
    }

//    @GetMapping(value = "/static/**")
//    public void view(HttpServletRequest request, HttpServletResponse response) {
//        logger.info("SFTP下载 ..."+new Date());
//        // ISO-8859-1 ==> UTF-8 进行编码转换
//        String filePath = extractPathFromPattern(request);
//        if(oConvertUtils.isEmpty(filePath) || CommonConstant.STRING_NULL.equals(filePath)){
//            return;
//        }
//        try {
//            filePath = filePath.replace("..", "").replace("../","");
//            if (filePath.endsWith(SymbolConstant.COMMA)) {
//                filePath = filePath.substring(0, filePath.length() - 1);
//            }
//            zykService.downloadRes(filePath,response);
//        } catch (Exception e) {
//            log.error("预览文件失败" + e.getMessage());
//            e.printStackTrace();
//        }
//    }

    /**
     *  把指定URL后的字符串全部截断当成参数
     *  这么做是为了防止URL中包含中文或者特殊字符（/等）时，匹配不了的问题
     * @param request
     * @return
     */
    private static String extractPathFromPattern(final HttpServletRequest request) {
        String path = (String) request.getAttribute(HandlerMapping.PATH_WITHIN_HANDLER_MAPPING_ATTRIBUTE);
        String bestMatchPattern = (String) request.getAttribute(HandlerMapping.BEST_MATCHING_PATTERN_ATTRIBUTE);
        return new AntPathMatcher().extractPathWithinPattern(bestMatchPattern, path);
    }

}
