package org.jeecg.modules.zyk.service.impl;

import com.baomidou.mybatisplus.core.incrementer.DefaultIdentifierGenerator;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.DateUtils;
import org.jeecg.common.util.SFTPUtil;
import org.jeecg.common.util.SftpConfig;
import org.jeecg.common.util.SpringContextHolder;
import org.jeecg.common.util.text.StringUtils;
import org.jeecg.modules.kc.ktgl.entity.KcKechengbiao;
import org.jeecg.modules.kc.ktgl.service.IKcKechengbiaoService;
import org.jeecg.modules.tools.Global;
import org.jeecg.modules.tools.office.pdf.PDFUtil;
import org.jeecg.modules.zyk.entity.ZykInfo;
import org.jeecg.modules.zyk.mapper.ZykMapper;
import org.jeecg.modules.zyk.service.IZykService;
import org.jeecg.modules.zyk.utils.FileHandleUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.mock.web.MockMultipartFile;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description: 资源库信息
 * @Author: jeecg-boot
 * @Date:   2024-05-16
 * @Version: V1.0
 */
@Service
public class ZykServiceImpl extends ServiceImpl<ZykMapper, ZykInfo> implements IZykService {

    @Autowired
    private FileHandleUtil fileHandleUtil;

    @Autowired
    IKcKechengbiaoService kcKechengbiaoService;

    @Autowired
    private ZykMapper zykMapper;

    @Autowired
    SftpConfig sftpConfig;

    private static String uploadpath;

    @Value("${jeecg.path.upload}")
    public void setUploadPath(String uploadPath) {
        this.uploadpath = uploadPath;
    }


    @Override
    public Page<ZykInfo> findPage(ZykInfo zykInfo, Page<ZykInfo> page){
        List<ZykInfo> list = zykMapper.findPage(page,zykInfo);
        page.setRecords(list);
        return page;
    }

    @Override
    public String saveInfo(ZykInfo zykInfo){
//        Map<String,String> map = fileHandleUtil.uploadFile(zykInfo);
        Map<String,String> map = fileHandleUtil.moveFiles(zykInfo);
        if(!map.get("code").equals("0")){
            return map.get("msg");
        }
        if(StringUtils.isNotNull(map.get("data"))){
            String fileName = map.get("data");
            zykInfo.setFileName(fileName);
        }
        if(StringUtils.isNotNull(map.get("pdfData"))){
            String pdfName = map.get("pdfData");
            zykInfo.setPdfName(pdfName);
        }
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        zykInfo.setCreateBy(user.getUsername());
        zykInfo.setCreateTime(new Date());
        Long id = new DefaultIdentifierGenerator().nextId(new ZykInfo());
        zykInfo.setId(id.toString());
        zykMapper.addInfo(zykInfo);
        return "添加成功！";
    }

    @Override
    public String modifyInfo(ZykInfo zykInfo){
//        Map<String,String> map = fileHandleUtil.uploadFile(zykInfo);
        Map<String,String> map = fileHandleUtil.moveFiles(zykInfo);
        if(!map.get("code").equals("0")){
            return map.get("msg");
        }
        if(StringUtils.isNotNull(map.get("data"))){
            String fileName = map.get("data");
            zykInfo.setFileName(fileName);
        }
        if(StringUtils.isNotNull(map.get("pdfData"))){
            String pdfName = map.get("pdfData");
            zykInfo.setPdfName(pdfName);
        }
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        zykInfo.setUpdateBy(user.getUsername());
        zykInfo.setUpdateTime(new Date());
        zykMapper.modifyInfo(zykInfo);
        return "编辑成功!";
    }

    @Override
    public String removeById(String id){
        ZykInfo zykInfo = zykMapper.getById(id);
        if(!StringUtils.isEmpty(zykInfo.getFileName())){
            String[] df = fileHandleUtil.getDirectoryAndFileName(zykInfo.getFileName());
            if(!StringUtils.isEmpty(df[0])&&!StringUtils.isEmpty(df[1])){
                fileHandleUtil.delete(df[0],df[1]);
            }
        }
        if(!StringUtils.isEmpty(zykInfo.getPdfName())){
            String[] df = fileHandleUtil.getDirectoryAndFileName(zykInfo.getPdfName());
            if(!StringUtils.isEmpty(df[0])&&!StringUtils.isEmpty(df[1])){
                fileHandleUtil.delete(df[0],df[1]);
            }
        }
        fileHandleUtil.disConnect();
        zykMapper.deleteById(id);
        return "删除成功!";
    }

    @Override
    public String removeByIds(List<String> list){
        for(int i=0;i<list.size();i++){
            String id = list.get(i);
            ZykInfo zykInfo = zykMapper.getById(id);
            if(!StringUtils.isEmpty(zykInfo.getFileName())){
                String[] df = fileHandleUtil.getDirectoryAndFileName(zykInfo.getFileName());
                if(!StringUtils.isEmpty(df[0])&&!StringUtils.isEmpty(df[1])){
                    fileHandleUtil.delete(df[0],df[1]);
                }
            }
            if(!StringUtils.isEmpty(zykInfo.getPdfName())){
                String[] df = fileHandleUtil.getDirectoryAndFileName(zykInfo.getPdfName());
                if(!StringUtils.isEmpty(df[0])&&!StringUtils.isEmpty(df[1])){
                    fileHandleUtil.delete(df[0],df[1]);
                }
            }
            zykMapper.deleteById(id);
        }
        fileHandleUtil.disConnect();
        return "批量删除成功!";
    }

    /**
     * 文件下载（预留）
     * @param filePath
     * @return 下载结果
     */
    @Override
    public Map<String,String> downloadRemoteFile(String filePath){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        if(filePath == null || filePath.equals("")){
            map.put("code","1");
            map.put("msg","文件路径不能为空！");
        }
        if(filePath.lastIndexOf("/")==-1){
            map.put("code","1");
            map.put("msg","文件路径不存在！");
        }
        String[] df = fileHandleUtil.getDirectoryAndFileName(filePath);
        if(df[0].equals("")){
            map.put("code","1");
            map.put("msg","文件路径不存在！");
        }
        if(df[1].equals("")){
            map.put("code","1");
            map.put("msg","文件不存在！");
        }
        Map<String,String> downloadMap = fileHandleUtil.download(filePath,df[1]);
        if(!downloadMap.get("code").equals("0")){
            return downloadMap;
        }
        map.put("data",downloadMap.get("fileName"));
        return map;
    }

    /**
     * 下载远端文件流（含接口）
     * @param filePath
     */
    @Override
    public void downloadRes(String filePath, HttpServletResponse response) throws Exception {
        if(StringUtils.isEmpty(filePath)){
            throw new RuntimeException("文件["+filePath+"]不存在！");
        }
        if(filePath.lastIndexOf("/")==-1){
            throw new RuntimeException("文件路径不存在！");
        }
        fileHandleUtil.downloadRes(filePath,response);
    }

    /**
     * 更新到资源库（接口）
     * @param zykInfo
     * @return 上传结果
     */
    @Override
    public Map<String,String> saveToZyk(ZykInfo zykInfo){
        KcKechengbiao kcb = new KcKechengbiao();
        kcb.setRwbh(zykInfo.getRwbh());
        kcb = kcKechengbiaoService.getKcbhByRwbh(kcb);
        zykInfo.setXqxn(kcb.getXqxn());
        zykInfo.setKkdw(kcb.getKkdw());
        zykInfo.setKcmc(kcb.getKcmc());
        zykInfo.setSkjs(kcb.getSkjs());
//        Map<String,Object> map = fileHandleUtil.uploadFile(zykInfo);
        Map<String,String> map = fileHandleUtil.moveFiles(zykInfo);
        if(!map.get("code").equals("0")){
            return map;
        }
        if(StringUtils.isNotNull(map.get("data"))){
            String fileName = map.get("data");
            zykInfo.setFileName(fileName);
        }
        if(StringUtils.isNotNull(map.get("pdfData"))){
            String pdfName = map.get("pdfData");
            zykInfo.setPdfName(pdfName);
        }
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        zykInfo.setCreateBy(user.getUsername());
        zykInfo.setCreateTime(new Date());
        Long id = new DefaultIdentifierGenerator().nextId(new ZykInfo());
        zykInfo.setId(id.toString());
        zykMapper.addInfo(zykInfo);
        return map;
    }

    /**
     * 更新到资源库-教学大纲（接口）
     * @param zykInfo
     * @return 上传结果
     */
    @Override
    public Map<String,String> saveToZykJxdg(ZykInfo zykInfo){
        KcKechengbiao kcb = new KcKechengbiao();
        kcb.setRwbh(zykInfo.getRwbh());
        kcb = kcKechengbiaoService.getKcbhByRwbh(kcb);
        zykInfo.setXqxn(kcb.getXqxn());
        zykInfo.setKkdw(kcb.getKkdw());
        zykInfo.setKcmc(kcb.getKcmc());
        zykInfo.setSkjs(kcb.getSkjs());
        Map<String,String> downloadMap = downloadRemoteFile(zykInfo.getFileName());
        if(!downloadMap.get("code").equals("0")){
            return downloadMap;
        }


        Map<String,String> map = fileHandleUtil.moveFiles(zykInfo);
        if(!map.get("code").equals("0")){
            return map;
        }
        if(StringUtils.isNotNull(map.get("data"))){
            String fileName = map.get("data");
            zykInfo.setFileName(fileName);
        }else{
            map.put("data","");
        }



        String fileType = zykInfo.getFileName().substring(zykInfo.getFileName().lastIndexOf(".") + 1);
        if(StringUtils.equals(fileType,"doc")||StringUtils.equals(fileType,"docx")){
            Global global = SpringContextHolder.getBean(Global.class);
            String dd = DateUtils.formatDate(new Date(),"yyyyMMddHHmmss");
            String namePath = dd + ".pdf";
            String pdfPath = global.getContractDickPath() + namePath;

            PDFUtil.office2PDF(downloadMap.get("data"),pdfPath);
            Map<String,String> uploadMap = uploadFileToSftp("contract/"+namePath);
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            zykInfo.setPdfName(uploadMap.get("data"));
            if(StringUtils.isNotNull(uploadMap.get("data"))){
                String pdfName = uploadMap.get("data");
                zykInfo.setPdfName(pdfName);
                map.put("pdfData",uploadMap.get("data"));
            }else{
                map.put("pdfData","");
            }
        }

        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        zykInfo.setCreateBy(user.getUsername());
        zykInfo.setCreateTime(new Date());
        Long id = new DefaultIdentifierGenerator().nextId(new ZykInfo());
        zykInfo.setId(id.toString());
        zykMapper.addInfo(zykInfo);
        return map;
    }

    /**
     * 更新到资源库（接口）
     * @param filePath
     * @return 上传结果
     */
    @Override
    public Map<String,String> uploadFileToSftp(String filePath){
        Map<String,String> map = fileHandleUtil.uploadFileToSftp(filePath);
        if(!map.get("code").equals("0")){
            return map;
        }
        return map;
    }

    /**
     * 删除资源库（接口）
     * @param zykInfo
     * @return 上传结果
     */
    @Override
    public Map<String,String> deleteZyk(ZykInfo zykInfo){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        ZykInfo entity = zykMapper.getByBiz(zykInfo);
        if(!StringUtils.isEmpty(entity.getFileName())){
            String[] df = fileHandleUtil.getDirectoryAndFileName(entity.getFileName());
            if(!StringUtils.isEmpty(df[0])&&!StringUtils.isEmpty(df[1])){
                fileHandleUtil.delete(df[0],df[1]);
            }
        }
        if(!StringUtils.isEmpty(entity.getPdfName())){
            String[] df = fileHandleUtil.getDirectoryAndFileName(entity.getPdfName());
            if(!StringUtils.isEmpty(df[0])&&!StringUtils.isEmpty(df[1])){
                fileHandleUtil.delete(df[0],df[1]);
            }
        }
        zykMapper.deleteById(entity.getId());
        map.put("msg","删除成功!");
        return map;
    }

    @Override
    public void disConnect(){
        fileHandleUtil.disConnect();
    }

    @Override
    public void saveLocal(ZykInfo zykInfo) {
        KcKechengbiao kcb = new KcKechengbiao();
        kcb.setRwbh(zykInfo.getRwbh());
        kcb = kcKechengbiaoService.getKcbhByRwbh(kcb);
        zykInfo.setXqxn(kcb.getXqxn());
        zykInfo.setKkdw(kcb.getKkdw());
        zykInfo.setKcmc(kcb.getKcmc());
        zykInfo.setSkjs(kcb.getSkjs());

        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        zykInfo.setCreateBy(user.getUsername());
        zykInfo.setCreateTime(new Date());
        Long id = new DefaultIdentifierGenerator().nextId(new ZykInfo());
        zykInfo.setId(id.toString());
        zykMapper.addInfo(zykInfo);
    }

    @Override
    public Map<String, String> saveToStufile(ZykInfo zykInfo) {

        String bizPath = "";
        MultipartFile file = null;
        try {
            file = this.convert(uploadpath+"/"+zykInfo.getFileName());
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        this.uploadSftp(file,bizPath);
//        Map<String,String> downloadMap = downloadRemoteFile(zykInfo.getFileName());
//        if(!downloadMap.get("code").equals("0")){
//            return downloadMap;
//        }


        Map<String,String> map = new HashMap<>();
        String fileType = zykInfo.getFileName().substring(zykInfo.getFileName().lastIndexOf(".") + 1);
        if(StringUtils.equals(fileType,"doc")||StringUtils.equals(fileType,"docx")){
            Global global = SpringContextHolder.getBean(Global.class);
            String dd = DateUtils.formatDate(new Date(),"yyyyMMddHHmmss");
            String namePath = dd + ".pdf";
            String pdfPath = global.getContractDickPath() + namePath;

            PDFUtil.office2PDF(zykInfo.getFileName(),pdfPath);
            Map<String,String> uploadMap = uploadFileToSftp("contract/"+namePath);
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            zykInfo.setPdfName(uploadMap.get("data"));
            if(StringUtils.isNotNull(uploadMap.get("data"))){
                String pdfName = uploadMap.get("data");
                zykInfo.setPdfName(pdfName);
                map.put("pdfData",uploadMap.get("data"));
            }else{
                map.put("pdfData","");
            }
        }
        return map;
    }

    public static MultipartFile convert(String path) throws IOException {
        File file = new File(path);
        FileInputStream input = new FileInputStream(file);
        MultipartFile multipartFile = new MockMultipartFile("file",file.getName(), "text/plain", input);

        return multipartFile;
    }

    private String uploadSftp(MultipartFile mf, String bizPath){
        try {
            Map<String,String> uploadMap = SFTPUtil.upload(sftpConfig,mf,bizPath);
            SFTPUtil.disChannel();
            SFTPUtil.disSession();
            if(uploadMap.get("code").equals("0")){
                return uploadMap.get("data");
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }finally {
            SFTPUtil.disChannel();
            SFTPUtil.disSession();
        }
        return "";
    }
}
