package org.jeecg.modules.zyk.utils;

import com.jcraft.jsch.ChannelSftp;
import org.apache.commons.compress.utils.Lists;
import org.jeecg.common.util.SFTPUtil;
import org.jeecg.common.util.text.StringUtils;
import org.jeecg.modules.zyk.entity.ZykInfo;

import org.jeecg.common.util.SftpConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.util.*;

@Service
public class FileHandleUtil {

    @Autowired
    SftpConfig sftpConfig;

    @Value(value = "${jeecg.path.upload}")
    private String uploadpath;

    @Value(value = "${jeecg.path.webapp}")
    private String downloadpath;

    public Map<String,String> uploadFile(ZykInfo zykInfo){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        Map<String,String> directoryMap = getDirectory(zykInfo);
        if(!directoryMap.get("code").equals("0")){
            return directoryMap;
        }
        //资源库文件路径
        String directory = directoryMap.get("directory");

        if(!StringUtils.isEmpty(zykInfo.getFileName())) {
            //源文件路径
            Map<String,String> fileNameMap = getFileName(zykInfo);
            if(!fileNameMap.get("code").equals("0")){
                return fileNameMap;
            }
            //上传文件
            Map<String,String> uploadMap = SFTPUtil.upload(sftpConfig,true,directory,fileNameMap.get("filePath").toString(),fileNameMap.get("fileName").toString());
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            map.put("data",uploadMap.get("data"));
        }

        if(!StringUtils.isEmpty(zykInfo.getPdfName())) {
            //源文件路径
            Map<String,String> fileNameMap = getPdfName(zykInfo);
            if(!fileNameMap.get("code").equals("0")){
                return fileNameMap;
            }
            //上传文件
            Map<String,String> uploadMap = SFTPUtil.upload(sftpConfig,true,directory,fileNameMap.get("filePath").toString(),fileNameMap.get("pdfName").toString());
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            map.put("pdfData",uploadMap.get("data"));
        }
        SFTPUtil.disChannel();
        SFTPUtil.disSession();
        return map;
    }

    public Map<String,String> uploadFileToSftp(String filePath){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        if(!StringUtils.isEmpty(filePath)) {
            //源文件路径
            Map<String,String> fileNameMap = getFileName(filePath);
            if(!fileNameMap.get("code").equals("0")){
                return fileNameMap;
            }
            //上传文件
            Map<String,String> uploadMap = SFTPUtil.upload(sftpConfig,false,"temp/",fileNameMap.get("filePath").toString(),fileNameMap.get("fileName").toString());
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            map.put("data",uploadMap.get("data"));
        }
//        SFTPUtil.disChannel();
//        SFTPUtil.disSession();
        return map;
    }


    public String[] getDirectoryAndFileName(String fileName) {
        String[] ss = new String[2];
        String path = fileName.substring(0,fileName.lastIndexOf("/"));
        String name = fileName.substring(fileName.lastIndexOf("/")+1);
        ss[0] = path;
        ss[1] = name;
        return ss;
    }

    public Map<String,String> download(String directory, String downloadFile){
        Map<String,String> map = SFTPUtil.download(sftpConfig,directory,downloadFile,getDownloadPath("temp"));
//        SFTPUtil.disChannel();
//        SFTPUtil.disSession();
        return map;
    }

    public void downloadRes(String downloadFile,HttpServletResponse response) throws Exception{
        SFTPUtil.writeFileToRes(sftpConfig,downloadFile,response);
//        SFTPUtil.disChannel();
//        SFTPUtil.disSession();
    }

    public Map<String,String> moveFile(ZykInfo zykInfo){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        Map<String,String> directoryMap = getDirectory(zykInfo);
        if(!directoryMap.get("code").equals("0")){
            return directoryMap;
        }
        //资源库文件路径
        String directory = directoryMap.get("directory");

        if(!StringUtils.isEmpty(zykInfo.getFileName())) {
            //源文件路径
            String newname = getName(zykInfo,false);
            Map<String,String> uploadMap = SFTPUtil.moveFile(sftpConfig,zykInfo.getFileName(),directory,newname);
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            map.put("data",uploadMap.get("data"));
        }

        if(!StringUtils.isEmpty(zykInfo.getPdfName())) {
            String newname = getName(zykInfo,true);
            Map<String,String> uploadMap = SFTPUtil.moveFile(sftpConfig,zykInfo.getFileName(),directory,newname);
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            map.put("pdfData",uploadMap.get("data"));
        }
        SFTPUtil.disChannel();
        SFTPUtil.disSession();
        return map;
    }

    public Map<String,String> moveFiles(ZykInfo zykInfo){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        Map<String,String> directoryMap = getDirectory(zykInfo);
        if(!directoryMap.get("code").equals("0")){
            return directoryMap;
        }
        //资源库文件路径
        String directory = directoryMap.get("directory");

        if(!StringUtils.isEmpty(zykInfo.getFileName())) {
            List<String[]> list = getPathsAndNames(zykInfo,false);
            Map<String,String> uploadMap = SFTPUtil.moveFiles(sftpConfig,directory,list);
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            map.put("data",uploadMap.get("data"));
        }
        if(!StringUtils.isEmpty(zykInfo.getPdfName())) {
            List<String[]> list = getPathsAndNames(zykInfo,true);
            Map<String,String> uploadMap = SFTPUtil.moveFiles(sftpConfig,directory,list);
            if(!uploadMap.get("code").equals("0")){
                return uploadMap;
            }
            map.put("pdfData",uploadMap.get("data"));
        }
//        SFTPUtil.disChannel();
//        SFTPUtil.disSession();
        return map;
    }

    public void delete(String directory, String downloadFile){
        SFTPUtil.delete(sftpConfig,directory,downloadFile);
    }

    public void disConnect(){
        SFTPUtil.disChannel();
        SFTPUtil.disSession();
    }

    /**
     * 资源库文件路径
     * @param zykInfo
     * @return
     */
    private Map<String,String> getDirectory(ZykInfo zykInfo){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        StringBuffer sb = new StringBuffer();
        if(StringUtils.isEmpty(zykInfo.getXqxn())){
            map.put("code","1");
            map.put("msg","学期学年不能为空！");
            return map;
        }
        sb.append(zykInfo.getXqxn());
        sb.append("/");
        if(StringUtils.isEmpty(zykInfo.getKkdw())){
            map.put("code","1");
            map.put("msg","开课单位不能为空！");
            return map;
        }
        sb.append(zykInfo.getKkdw());
        sb.append("/");
        if(StringUtils.isEmpty(zykInfo.getKcmc())){
            map.put("code","1");
            map.put("msg","课程名称不能为空！");
            return map;
        }
        sb.append(zykInfo.getKcmc());
        sb.append("/");
        if(StringUtils.isEmpty(zykInfo.getSkjs())){
            map.put("code","1");
            map.put("msg","授课教师不能为空！");
            return map;
        }
        sb.append(zykInfo.getSkjs());
        sb.append("/");
        if(StringUtils.isEmpty(zykInfo.getWjlx())){
            map.put("code","1");
            map.put("msg","文件类型不能为空！");
            return map;
        }
        sb.append(zykInfo.getWjlx());
        sb.append("/");
        map.put("directory",sb.toString());
        return map;
    }

    /**
     * 获取文件路径和新文件名称
     * @param zykInfo
     * @return
     */
    private Map<String,String> getFileName(ZykInfo zykInfo){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        String uploadFileName = getRealFileFullPath(zykInfo.getFileName());
        if(StringUtils.isEmpty(uploadFileName)){
            map.put("code","1");
            map.put("msg","文件路径不能为空！");
            return map;
        }
        File file = new File(uploadFileName);
        if(!file.exists()){
            map.put("code","1");
            map.put("msg","文件["+uploadFileName+"]不存在..");
            return map;
        }
        map.put("filePath",uploadFileName);
        String fileName = uploadFileName.substring(uploadFileName.lastIndexOf('/')+1, uploadFileName.indexOf("_"));
        String suffix = uploadFileName.substring(uploadFileName.lastIndexOf("."));
        fileName = fileName + suffix;
//        if(zykInfo.getWjlx().equals(WjlxEnum.JXDG.getType())){
//            String kcmc = zykInfo.getKcmc();
//            fileName = kcmc+"_"+WjlxEnum.JXDG.getType()+suffix;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.JXRL.getType())){
//            String kcmc = zykInfo.getKcmc();
//            fileName = kcmc+"_"+WjlxEnum.JXRL.getType()+suffix;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.KCLW.getType())){
//            String kcmc = zykInfo.getKcmc();
//            fileName = kcmc+"_要求"+suffix;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.XSLW.getType())){
//            String kcmc = StringUtils.nullToEmpty(zykInfo.getKcmc());
//            String xh = StringUtils.nullToEmpty(zykInfo.getXh());
//            String seq = StringUtils.nullToEmpty(zykInfo.getSeq());
//            fileName = kcmc+"_"+xh+"_"+seq+"_"+fileName;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.JXDY.getType())){
//            String kcmc = StringUtils.nullToEmpty(zykInfo.getKcmc());
//            String chapter = StringUtils.nullToEmpty(zykInfo.getChapter());
//            String section = StringUtils.nullToEmpty(zykInfo.getSection());
//            fileName = kcmc+"_第"+chapter+"章_第"+section+"节"+suffix;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.QT.getType())){
//            String kcmc = zykInfo.getKcmc();
//            fileName = kcmc+"_其他_"+fileName;
//        }
        map.put("fileName",fileName);
        return map;
    }

    /**
     * 获取文件路径和新文件名称
     * @param fileNamePath
     * @return
     */
    private Map<String,String> getFileName(String fileNamePath){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        String uploadFileName = getRealFileFullPath(fileNamePath);
        if(StringUtils.isEmpty(uploadFileName)){
            map.put("code","1");
            map.put("msg","文件路径不能为空！");
            return map;
        }
        File file = new File(uploadFileName);
        if(!file.exists()){
            map.put("code","1");
            map.put("msg","文件["+uploadFileName+"]不存在..");
            return map;
        }
        map.put("filePath",uploadFileName);
        String fileName = uploadFileName.substring(uploadFileName.lastIndexOf('/')+1, uploadFileName.length());
//        String suffix = uploadFileName.substring(uploadFileName.lastIndexOf("."));
//        fileName = fileName + suffix;
        map.put("fileName",fileName);
        return map;
    }

    /**
     * 获取文件名称
     * @param zykInfo
     * @return
     */
    private String getName(ZykInfo zykInfo,boolean isPdf){
        String fileName = "";
        String uploadFileName = "";
        if(isPdf){
            uploadFileName = zykInfo.getPdfName();
        }else{
            uploadFileName = zykInfo.getFileName();
        }
        fileName = uploadFileName.substring(uploadFileName.lastIndexOf('/')+1, uploadFileName.indexOf("_"));
        String suffix = uploadFileName.substring(uploadFileName.lastIndexOf("."));
        fileName = fileName + suffix;
//        if(zykInfo.getWjlx().equals(WjlxEnum.XSLW.getType())){
//            String kcmc = StringUtils.nullToEmpty(zykInfo.getKcmc());
//            String xh = StringUtils.nullToEmpty(zykInfo.getXh());
//            String seq = StringUtils.nullToEmpty(zykInfo.getSeq());
//            fileName = kcmc+"_"+xh+"_"+seq+"_"+fileName;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.JXDY.getType())){
//            String kcmc = StringUtils.nullToEmpty(zykInfo.getKcmc());
//            String chapter = StringUtils.nullToEmpty(zykInfo.getChapter());
//            String section = StringUtils.nullToEmpty(zykInfo.getSection());
//            fileName = kcmc+"_第"+chapter+"章_第"+section+"节"+suffix;
//        }
        return fileName;
    }

    /**
     * 获取原文件和文件名
     * @param zykInfo
     * @return
     */
    private List<String[]> getPathsAndNames(ZykInfo zykInfo,boolean isPdf){
        List<String[]> list = Lists.newArrayList();
        String uploadFileName = "";
        if(isPdf){
            uploadFileName = zykInfo.getPdfName();
        }else{
            uploadFileName = zykInfo.getFileName();
        }
        StringTokenizer st = new StringTokenizer(uploadFileName,"|");
        while(st.hasMoreTokens()){
            String pathAndName[] = new String[2];
            String originPath = st.nextToken();
            String fileName = originPath.substring(originPath.lastIndexOf('/')+1);
//            String fileName = originPath.substring(originPath.lastIndexOf('/')+1, originPath.indexOf("_"));
//            String suffix = originPath.substring(originPath.lastIndexOf("."));
//            fileName = fileName + suffix;
//            if(zykInfo.getWjlx().equals(WjlxEnum.XSLW.getType())){
//                String kcmc = StringUtils.nullToEmpty(zykInfo.getKcmc());
//                String xh = StringUtils.nullToEmpty(zykInfo.getXh());
//                String seq = StringUtils.nullToEmpty(zykInfo.getSeq());
//                fileName = kcmc+"_"+xh+"_"+seq+"_"+fileName;
//            }
//            if(zykInfo.getWjlx().equals(WjlxEnum.JXDY.getType())){
//                String kcmc = StringUtils.nullToEmpty(zykInfo.getKcmc());
//                String chapter = StringUtils.nullToEmpty(zykInfo.getChapter());
//                String section = StringUtils.nullToEmpty(zykInfo.getSection());
//                fileName = kcmc+"_第"+chapter+"章_第"+section+"节"+suffix;
//            }
            pathAndName[0] = originPath;
            pathAndName[1] = fileName;
            list.add(pathAndName);
        }
        return list;
    }

    /**
     * 获取文件路径和新文件名称
     * @param zykInfo
     * @return
     */
    private Map<String,String> getPdfName(ZykInfo zykInfo){
        Map<String,String> map = new HashMap<String,String>();
        map.put("code","0");
        String uploadFileName = getRealFileFullPath(zykInfo.getPdfName());
        if(StringUtils.isEmpty(uploadFileName)){
            map.put("code","1");
            map.put("msg","文件路径不能为空！");
            return map;
        }
        File file = new File(uploadFileName);
        if(!file.exists()){
            map.put("code","1");
            map.put("msg","文件["+uploadFileName+"]不存在..");
            return map;
        }
        map.put("filePath",uploadFileName);
        String fileName = uploadFileName.substring(uploadFileName.lastIndexOf('/')+1, uploadFileName.indexOf("_"));
        String suffix = uploadFileName.substring(uploadFileName.lastIndexOf("."));
        fileName = fileName + suffix;
//        if(zykInfo.getWjlx().equals(WjlxEnum.JXDG.getType())){
//            String kcmc = zykInfo.getKcmc();
//            fileName = kcmc+"_"+WjlxEnum.JXDG.getType()+suffix;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.JXRL.getType())){
//            String kcmc = zykInfo.getKcmc();
//            fileName = kcmc+"_"+WjlxEnum.JXRL.getType()+suffix;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.KCLW.getType())){
//            String kcmc = zykInfo.getKcmc();
//            fileName = kcmc+"_要求"+suffix;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.XSLW.getType())){
//            String kcmc = StringUtils.nullToEmpty(zykInfo.getKcmc());
//            String xh = StringUtils.nullToEmpty(zykInfo.getXh());
//            String seq = StringUtils.nullToEmpty(zykInfo.getSeq());
//            fileName = kcmc+"_"+xh+"_"+seq+"_"+fileName;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.JXDY.getType())){
//            String kcmc = StringUtils.nullToEmpty(zykInfo.getKcmc());
//            String chapter = StringUtils.nullToEmpty(zykInfo.getChapter());
//            String section = StringUtils.nullToEmpty(zykInfo.getSection());
//            fileName = kcmc+"_第"+chapter+"章_第"+section+"节"+suffix;
//        }
//        if(zykInfo.getWjlx().equals(WjlxEnum.QT.getType())){
//            String kcmc = zykInfo.getKcmc();
//            fileName = kcmc+"_其他_"+fileName;
//        }
        map.put("pdfName",fileName);
        return map;
    }

    /**
     * 获取文件真实路径
     * @param path
     * @return
     */
    private String getRealFileFullPath(String path){
        String filePath = "";
        if(StringUtils.isEmpty(path)){
            return "";
        }
        path = path.replace("\\", "/");
        int idx = path.indexOf(uploadpath);
        if(idx==-1){
            filePath = uploadpath + File.separator + path;
        }else{
            filePath = path;
        }
        return filePath;
    }

    /**
     * 获取文件真实路径
     * @param path
     * @return
     */
    private String getDownloadPath(String path){
        String filePath = "";
        if(StringUtils.isEmpty(path)){
            return "";
        }
        int idx = path.indexOf(downloadpath);
        if(idx==-1){
            filePath = downloadpath + File.separator + path;
        }else{
            filePath = path;
        }
        return filePath;
    }



}
