package org.jeecg.modules.kc.blLoginLog.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.common.util.text.StringUtils;
import org.jeecg.modules.kc.blLoginLog.entity.BlLoginLog;
import org.jeecg.modules.kc.blLoginLog.service.IBlLoginLogService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.system.entity.SysUser;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 登录日志
 * @Author: jeecg-boot
 * @Date:   2024-06-17
 * @Version: V1.0
 */
@Api(tags="登录日志")
@RestController
@RequestMapping("/blLoginLog/blLoginLog")
@Slf4j
public class BlLoginLogController extends JeecgController<BlLoginLog, IBlLoginLogService> {
	@Autowired
	private IBlLoginLogService blLoginLogService;
	
	/**
	 * 分页列表查询
	 *
	 * @param blLoginLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "登录日志-分页列表查询")
	@ApiOperation(value="登录日志-分页列表查询", notes="登录日志-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<BlLoginLog>> queryPageList(BlLoginLog blLoginLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<BlLoginLog> queryWrapper = QueryGenerator.initQueryWrapper(blLoginLog, req.getParameterMap());
		Page<BlLoginLog> page = new Page<BlLoginLog>(pageNo, pageSize);
		queryWrapper.ge(StringUtils.isNotEmpty(blLoginLog.getStartTime()),"create_time",blLoginLog.getStartTime());
		queryWrapper.le(StringUtils.isNotEmpty(blLoginLog.getEndTime()),"create_time",blLoginLog.getEndTime()+" 23:59:59");
		IPage<BlLoginLog> pageList = blLoginLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param blLoginLog
	 * @return
	 */
	@AutoLog(value = "登录日志-添加")
	@ApiOperation(value="登录日志-添加", notes="登录日志-添加")
	@RequiresPermissions("blLoginLog:bl_login_log:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody BlLoginLog blLoginLog) {
		blLoginLogService.save(blLoginLog);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param blLoginLog
	 * @return
	 */
	@AutoLog(value = "登录日志-编辑")
	@ApiOperation(value="登录日志-编辑", notes="登录日志-编辑")
	@RequiresPermissions("blLoginLog:bl_login_log:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody BlLoginLog blLoginLog) {
		blLoginLogService.updateById(blLoginLog);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "登录日志-通过id删除")
	@ApiOperation(value="登录日志-通过id删除", notes="登录日志-通过id删除")
	@RequiresPermissions("blLoginLog:bl_login_log:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		blLoginLogService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "登录日志-批量删除")
	@ApiOperation(value="登录日志-批量删除", notes="登录日志-批量删除")
	@RequiresPermissions("blLoginLog:bl_login_log:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.blLoginLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "登录日志-通过id查询")
	@ApiOperation(value="登录日志-通过id查询", notes="登录日志-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<BlLoginLog> queryById(@RequestParam(name="id",required=true) String id) {
		BlLoginLog blLoginLog = blLoginLogService.getById(id);
		if(blLoginLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(blLoginLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param blLoginLog
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, BlLoginLog blLoginLog) {
        return super.exportXls(request, blLoginLog, BlLoginLog.class, "登录日志");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("blLoginLog:bl_login_log:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, BlLoginLog.class);
    }



	 @PostMapping(value = "/addLog")
	 public Result<String> addLog(@RequestBody SysUser sysUser) {
		 blLoginLogService.addLog("33用户名: " + sysUser.getUsername() + ",登录成功！", CommonConstant.LOG_TYPE_1, null,null);
		 return Result.OK("添加成功！");
	 }
}
