package org.jeecg.modules.system.controller;


import cn.hutool.core.io.FileUtil;
import cn.hutool.core.io.IoUtil;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.constant.CommonConstant;
import org.jeecg.common.constant.SymbolConstant;
import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.util.*;
import org.jeecg.common.util.filter.FileTypeFilter;
import org.jeecg.common.util.filter.StrAttackFilter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.util.AntPathMatcher;
import org.springframework.util.FileCopyUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.multipart.commons.CommonsMultipartFile;
import org.springframework.web.servlet.HandlerMapping;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 用户表 前端控制器
 * </p>
 *
 * @Author scott
 * @since 2018-12-20
 */
@Slf4j
@RestController
@RequestMapping("/sys/common")
public class CommonController {

    private final static Logger logger = LoggerFactory.getLogger(CommonController.class);

    @Value(value = "${jeecg.path.upload}")
    private String uploadpath;

    @Value(value = "${jeecg.path.webapp}")
    private String downloadpath;

    /**
     * 本地：local minio：minio 阿里：alioss
     */
    @Value(value = "${jeecg.uploadType}")
    private String uploadType;

    @Autowired
    SftpConfig sftpConfig;

    /**
     * @return
     * @Author 政辉
     */
    @GetMapping("/403")
    public Result<?> noauth() {
        return Result.error("没有权限，请联系管理员授权");
    }

    /**
     * 文件上传统一方法
     *
     * @param request
     * @param response
     * @return
     */
    @PostMapping(value = "/upload")
    public Result<?> upload(HttpServletRequest request, HttpServletResponse response) throws Exception {
        Result<?> result = new Result<>();
        String savePath = "";
        String bizPath = request.getParameter("biz");

        //LOWCOD-2580 sys/common/upload接口存在任意文件上传漏洞
        if (oConvertUtils.isNotEmpty(bizPath)) {
            if (bizPath.contains(SymbolConstant.SPOT_SINGLE_SLASH) || bizPath.contains(SymbolConstant.SPOT_DOUBLE_BACKSLASH)) {
                throw new JeecgBootException("上传目录bizPath，格式非法！");
            }
        }

        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        // 获取上传文件对象
        MultipartFile file = multipartRequest.getFile("file");

        Long fileSize = file.getSize();
        if (fileSize > 1024 * 1024 * 200) {
            result.setMessage("文件大小不能超过10M");
            result.setSuccess(false);
            return result;
        }

        savePath = upload(bizPath, file);
        if (oConvertUtils.isNotEmpty(savePath)) {
            result.setMessage(savePath);
            result.setSuccess(true);
        } else {
            result.setMessage("上传失败！");
            result.setSuccess(false);
        }
        return result;
    }

    /**
     * 文件上传统一方法
     *
     * @param bizPath
     * @param file
     * @return
     */
    public String upload(String bizPath, MultipartFile file) throws Exception {
        String savePath = "";
        if (oConvertUtils.isEmpty(bizPath)) {
            if (CommonConstant.UPLOAD_TYPE_OSS.equals(uploadType)) {
                //未指定目录，则用阿里云默认目录 upload
                bizPath = "upload";
                //result.setMessage("使用阿里云文件上传时，必须添加目录！");
                //result.setSuccess(false);
                //return result;
            } else {
                bizPath = "";
            }
        }
        if (CommonConstant.UPLOAD_TYPE_LOCAL.equals(uploadType)) {
            //update-begin-author:liusq date:20221102 for: 过滤上传文件类型
            FileTypeFilter.fileTypeFilter(file);
            //update-end-author:liusq date:20221102 for: 过滤上传文件类型
            //update-begin-author:lvdandan date:20200928 for:修改JEditor编辑器本地上传
            savePath = this.uploadLocal(file, bizPath);
            //update-begin-author:lvdandan date:20200928 for:修改JEditor编辑器本地上传
            /**  富文本编辑器及markdown本地上传时，采用返回链接方式
             //针对jeditor编辑器如何使 lcaol模式，采用 base64格式存储
             String jeditor = request.getParameter("jeditor");
             if(oConvertUtils.isNotEmpty(jeditor)){
             result.setMessage(CommonConstant.UPLOAD_TYPE_LOCAL);
             result.setSuccess(true);
             return result;
             }else{
             savePath = this.uploadLocal(file,bizPath);
             }
             */
        } else if (CommonConstant.UPLOAD_TYPE_SFTP.equals(uploadType)) {
            FileTypeFilter.fileTypeFilter(file);
            savePath = this.uploadSftp(file, bizPath);
        } else {
            //update-begin-author:taoyan date:20200814 for:文件上传改造
            savePath = CommonUtils.upload(file, bizPath, uploadType);
            //update-end-author:taoyan date:20200814 for:文件上传改造
        }
        return savePath;
    }

    /**
     * 本地文件上传
     *
     * @param mf      文件
     * @param bizPath 自定义路径
     * @return
     */
    private String uploadLocal(MultipartFile mf, String bizPath) {
        return uploadLocal(mf, null, bizPath);
    }

    /**
     * 本地文件上传
     *
     * @param mf      文件
     * @param bizPath 自定义路径
     * @return
     */
    public String uploadLocal(MultipartFile mf, String _fileName, String bizPath) {
        try {
            String ctxPath = uploadpath;
            String fileName = _fileName;
            File file = new File(ctxPath + File.separator + bizPath + File.separator);
            if (!file.exists()) {
                // 创建文件根目录
                file.mkdirs();
            }
            // 获取文件名
            if (fileName == null) {
                String orgName = StrAttackFilter.filter2(mf.getOriginalFilename());
                if (orgName != null) {
                    orgName = CommonUtils.getFileName(orgName);
                    if (orgName.contains(SymbolConstant.SPOT)) {
                        fileName = orgName.substring(0, orgName.lastIndexOf(".")) + "_" + System.currentTimeMillis() + orgName.substring(orgName.lastIndexOf("."));
                    } else {
                        fileName = orgName + "_" + System.currentTimeMillis();
                    }
                }
            }
            String savePath = file.getPath() + File.separator + fileName;
            File savefile = new File(savePath);
            FileCopyUtils.copy(mf.getBytes(), savefile);
            String dbpath = null;
            if (oConvertUtils.isNotEmpty(bizPath)) {
                dbpath = bizPath + File.separator + fileName;
            } else {
                dbpath = fileName;
            }
            if (dbpath.contains(SymbolConstant.DOUBLE_BACKSLASH)) {
                dbpath = dbpath.replace(SymbolConstant.DOUBLE_BACKSLASH, SymbolConstant.SINGLE_SLASH);
            }
            return dbpath;
        } catch (IOException e) {
            log.error(e.getMessage(), e);
        }
        return "";
    }

    private String uploadSftp(MultipartFile mf, String bizPath) {
        try {
            Map<String, String> uploadMap = SFTPUtil.upload(sftpConfig, mf, bizPath);
            SFTPUtil.disChannel();
            SFTPUtil.disSession();
            if (uploadMap.get("code").equals("0")) {
                return uploadMap.get("data");
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        } finally {
            SFTPUtil.disChannel();
            SFTPUtil.disSession();
        }
        return "";
    }

//	@PostMapping(value = "/upload2")
//	public Result<?> upload2(HttpServletRequest request, HttpServletResponse response) {
//		Result<?> result = new Result<>();
//		try {
//			String ctxPath = uploadpath;
//			String fileName = null;
//			String bizPath = "files";
//			String tempBizPath = request.getParameter("biz");
//			if(oConvertUtils.isNotEmpty(tempBizPath)){
//				bizPath = tempBizPath;
//			}
//			String nowday = new SimpleDateFormat("yyyyMMdd").format(new Date());
//			File file = new File(ctxPath + File.separator + bizPath + File.separator + nowday);
//			if (!file.exists()) {
//				file.mkdirs();// 创建文件根目录
//			}
//			MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
//			MultipartFile mf = multipartRequest.getFile("file");// 获取上传文件对象
//			String orgName = mf.getOriginalFilename();// 获取文件名
//			fileName = orgName.substring(0, orgName.lastIndexOf(".")) + "_" + System.currentTimeMillis() + orgName.substring(orgName.indexOf("."));
//			String savePath = file.getPath() + File.separator + fileName;
//			File savefile = new File(savePath);
//			FileCopyUtils.copy(mf.getBytes(), savefile);
//			String dbpath = bizPath + File.separator + nowday + File.separator + fileName;
//			if (dbpath.contains("\\")) {
//				dbpath = dbpath.replace("\\", "/");
//			}
//			result.setMessage(dbpath);
//			result.setSuccess(true);
//		} catch (IOException e) {
//			result.setSuccess(false);
//			result.setMessage(e.getMessage());
//			log.error(e.getMessage(), e);
//		}
//		return result;
//	}

    @Data
    public static class SectionUploadData {
        private Integer chunkCount;
        private String fileMd5;
        private String biz;
        private String fileName;
    }

    //切片上传
    @PostMapping(value = "/sectionUpload/init")
    public Result<?> sectionUploadInit(@RequestBody SectionUploadData sectionUploadData) throws Exception {
        log.info("初始化文件！");
        //创建文件
        Integer chunkCount = sectionUploadData.getChunkCount();
        String fileMd5 = sectionUploadData.getFileMd5();
        String fileName = sectionUploadData.getFileName();
        String bizPath = sectionUploadData.getBiz();
        if (oConvertUtils.isNotEmpty(bizPath)) {
            if (bizPath.contains(SymbolConstant.SPOT_SINGLE_SLASH) || bizPath.contains(SymbolConstant.SPOT_DOUBLE_BACKSLASH)) {
                throw new JeecgBootException("上传目录bizPath，格式非法！");
            }
        }

        //创建一个空文件夹,里面有个文件信息
        String ctxPath = uploadpath;
        File file = new File(ctxPath + File.separator + bizPath + File.separator + fileMd5);
        if (!file.exists()) {
            // 创建文件根目录
            file.mkdirs();
        }

        File fileInfo = new File(ctxPath + File.separator + bizPath + File.separator + fileMd5 + File.separator + "file.info");
        FileUtil.writeUtf8String("fileMd5:" + fileMd5 + "\nchunkCount:" + chunkCount + "\nfileName:" + fileName, fileInfo);
        return Result.OK("init ok");
    }

    @PostMapping(value = "/sectionUpload/upload")
    public Result<?> sectionUploadUpload(HttpServletRequest request, HttpServletResponse response) {
        log.info("上传文件！");
        String bizPath = request.getParameter("biz");
        String fileMd5 = request.getParameter("fileMd5");
        String partNumber = request.getParameter("partNumber");

        //LOWCOD-2580 sys/common/upload接口存在任意文件上传漏洞
        if (oConvertUtils.isNotEmpty(bizPath)) {
            if (bizPath.contains(SymbolConstant.SPOT_SINGLE_SLASH) || bizPath.contains(SymbolConstant.SPOT_DOUBLE_BACKSLASH)) {
                throw new JeecgBootException("上传目录bizPath，格式非法！");
            }
        }

        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        // 获取上传文件对象
        MultipartFile file = multipartRequest.getFile("file");
//        5242880
//        1,048,576
        Long fileSize = file.getSize();
        if (fileSize > 1024 * 1024 * 100){
            throw new JeecgBootException("上传文件大小不能超过200M！");
        }

        String savePath = this.uploadLocal(file, partNumber, bizPath + File.separator + fileMd5);

        if (StringUtils.isBlank(savePath)) {
            return Result.error("upload error");
        }

        return Result.OK("upload ok");
    }

    @PostMapping(value = "/sectionUpload/end")
    public Result<?> sectionUploadEnd(@RequestBody SectionUploadData sectionUploadData) {
        log.info("合并文件！");
        Result<?> result = new Result<>();
        Integer chunkCount = sectionUploadData.getChunkCount();
        String fileMd5 = sectionUploadData.getFileMd5();
        String fileName = sectionUploadData.getFileName();
        String orgName = fileName;
        String bizPath = sectionUploadData.getBiz();

        if (oConvertUtils.isNotEmpty(bizPath)) {
            if (bizPath.contains(SymbolConstant.SPOT_SINGLE_SLASH) || bizPath.contains(SymbolConstant.SPOT_DOUBLE_BACKSLASH)) {
                throw new JeecgBootException("上传目录bizPath，格式非法！");
            }
        }

        //创建一个空文件夹,里面有个文件信息
        String ctxPath = uploadpath;
        String folderPath = ctxPath + File.separator + bizPath + File.separator + fileMd5;
        File fileFolder = new File(folderPath);


        //savePath = this.uploadLocal(file,bizPath)

        List<String> allFileNameList = FileUtil.listFileNames(fileFolder.getPath());
        List<String> fileNameList = allFileNameList.stream().filter(x -> !StringUtils.equals("file.info", x))
                .sorted(Comparator.comparing(Integer::parseInt))
                .collect(Collectors.toList());

        if (orgName != null) {
            orgName = CommonUtils.getFileName(orgName);
            if (orgName.contains(SymbolConstant.SPOT)) {
                fileName = orgName.substring(0, orgName.lastIndexOf(".")) + "_" + System.currentTimeMillis() + orgName.substring(orgName.lastIndexOf("."));
            } else {
                fileName = orgName + "_" + System.currentTimeMillis();
            }
        }


        File outFile = FileUtil.newFile(ctxPath + File.separator + bizPath + File.separator + fileName);


//        FastByteArrayOutputStream ais = IoUtil.w
        try {
            Vector<InputStream> streams = new Vector<>();
            fileNameList.forEach(sectionFileName -> {
                InputStream is = FileUtil.getInputStream(folderPath + File.separator + sectionFileName);
                streams.add(is);
            });
            Enumeration<InputStream> enumerations = streams.elements();
            SequenceInputStream sis = new SequenceInputStream(enumerations);
            BufferedOutputStream bos = new BufferedOutputStream(Files.newOutputStream(outFile.toPath()));
            byte[] bys = new byte[1024];
            int len = 0;
            while ((len = sis.read(bys)) != -1) {
                bos.write(bys, 0, len);
            }
            IoUtil.close(sis);
            IoUtil.close(bos);
            streams.forEach(IoUtil::close);

            //删除临时文件
            FileUtil.del(fileFolder);

            //本地上传不做处理，
            if (!CommonConstant.UPLOAD_TYPE_LOCAL.equals(uploadType)) {
                String savePath = upload(bizPath, getMultipartFile(outFile));
                if (oConvertUtils.isNotEmpty(savePath)) {
                    //删除本地文件
                    if (!StringUtils.equals(bizPath, "temp")) {
                        //不等于这个的删除
                        FileUtil.del(outFile);
                    }
                    result.setMessage(savePath);
                    result.setSuccess(true);
                } else {
                    result.setMessage("上传失败！");
                    result.setSuccess(false);
                }
            } else {
                //本地上传不做处理，直接返回地址即可
                result.setSuccess(true);
                result.setMessage(bizPath + "/" + fileName);//地址
            }
            return result;

        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.setSuccess(false);
            result.setMessage(e.getMessage());//地址
            return result;
        }
    }


    /**
     * file转MultipartFile
     *
     * @param file File对象
     * @return MultipartFile 对象
     */
    public static MultipartFile getMultipartFile(File file) {
        FileItem item = new DiskFileItemFactory().createItem("file"
                , MediaType.MULTIPART_FORM_DATA_VALUE
                , true
                , file.getName());
        try (InputStream input = Files.newInputStream(file.toPath());
             OutputStream os = item.getOutputStream()) {
            // 流转移
            IOUtils.copy(input, os);
        } catch (Exception e) {
            throw new IllegalArgumentException("Invalid file: " + e, e);
        }

        return new CommonsMultipartFile(item);
    }

    //切片上传END

    /**
     * 预览图片&下载文件
     * 请求地址：http://localhost:8080/common/static/{user/20190119/e1fe9925bc315c60addea1b98eb1cb1349547719_1547866868179.jpg}
     *
     * @param request
     * @param response
     */
    @GetMapping(value = "/static/**")
    public void view(HttpServletRequest request, HttpServletResponse response) {
        // ISO-8859-1 ==> UTF-8 进行编码转换
        String imgPath = extractPathFromPattern(request);
        if (oConvertUtils.isEmpty(imgPath) || CommonConstant.STRING_NULL.equals(imgPath)) {
            return;
        }
        // 其余处理略
        InputStream inputStream = null;
        OutputStream outputStream = null;
        try {
            imgPath = imgPath.replace("..", "").replace("../", "");
            if (imgPath.endsWith(SymbolConstant.COMMA)) {
                imgPath = imgPath.substring(0, imgPath.length() - 1);
            }
            if (CommonConstant.UPLOAD_TYPE_SFTP.equals(uploadType)) {
                try {
                    logger.info("/sys/common/static/SFTP下载 ..." + new Date());
//                    SFTPUtil.writeFileToRes(sftpConfig,imgPath,response);
                    int index = imgPath.lastIndexOf("/");
                    String path = "temp";
                    if (index != -1) {
                        path = imgPath.substring(0, index);
                    }
                    //TODO 不确定是否有问题，
                    Map<String, String> map = SFTPUtil.download(sftpConfig, imgPath, getDownloadPath(path));
                    if (!map.get("code").equals("0")) {
                        response.setStatus(404);
                        throw new RuntimeException(map.get("msg"));
                    }
                    String localFilePath = map.get("fileName");
                    File file = new File(localFilePath);
                    if (!file.exists()) {
                        response.setStatus(404);
                        throw new RuntimeException("文件[" + imgPath + "]不存在..");
                    }
                    // 设置强制下载不打开
//                    response.setContentType("application/force-download");
                    response.addHeader("Content-Disposition", "attachment;fileName=" + new String(file.getName().getBytes("UTF-8"), "iso-8859-1"));
                    inputStream = new BufferedInputStream(new FileInputStream(localFilePath));
                    outputStream = response.getOutputStream();
                    byte[] buf = new byte[1024];
                    int len;
                    while ((len = inputStream.read(buf)) > 0) {
                        outputStream.write(buf, 0, len);
                    }
                    response.flushBuffer();
                } catch (Exception e) {
//                    e.printStackTrace();
                } finally {
                    SFTPUtil.disChannel();
                    SFTPUtil.disSession();
                }
            } else {
                String filePath = uploadpath + File.separator + imgPath;
                File file = new File(filePath);
                if (!file.exists()) {
                    response.setStatus(404);
                    throw new RuntimeException("文件[" + imgPath + "]不存在..");
                }
                // 设置强制下载不打开
//                response.setContentType("application/force-download");
                response.addHeader("Content-Disposition", "attachment;fileName=" + new String(file.getName().getBytes("UTF-8"), "iso-8859-1"));
                inputStream = new BufferedInputStream(new FileInputStream(filePath));
                outputStream = response.getOutputStream();
                byte[] buf = new byte[1024];
                int len;
                while ((len = inputStream.read(buf)) > 0) {
                    outputStream.write(buf, 0, len);
                }
                response.flushBuffer();
            }
        } catch (Exception e) {
            log.error("预览文件失败" + e.getMessage());
            response.setStatus(404);
            e.printStackTrace();
        } finally {
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    log.error(e.getMessage(), e);
                }
            }
            if (outputStream != null) {
                try {
                    outputStream.close();
                } catch (IOException e) {
//                    log.error(e.getMessage(), e);
                }
            }
        }

    }

//	/**
//	 * 下载文件
//	 * 请求地址：http://localhost:8080/common/download/{user/20190119/e1fe9925bc315c60addea1b98eb1cb1349547719_1547866868179.jpg}
//	 *
//	 * @param request
//	 * @param response
//	 * @throws Exception
//	 */
//	@GetMapping(value = "/download/**")
//	public void download(HttpServletRequest request, HttpServletResponse response) throws Exception {
//		// ISO-8859-1 ==> UTF-8 进行编码转换
//		String filePath = extractPathFromPattern(request);
//		// 其余处理略
//		InputStream inputStream = null;
//		OutputStream outputStream = null;
//		try {
//			filePath = filePath.replace("..", "");
//			if (filePath.endsWith(",")) {
//				filePath = filePath.substring(0, filePath.length() - 1);
//			}
//			String localPath = uploadpath;
//			String downloadFilePath = localPath + File.separator + filePath;
//			File file = new File(downloadFilePath);
//	         if (file.exists()) {
//	         	response.setContentType("application/force-download");// 设置强制下载不打开            
//	 			response.addHeader("Content-Disposition", "attachment;fileName=" + new String(file.getName().getBytes("UTF-8"),"iso-8859-1"));
//	 			inputStream = new BufferedInputStream(new FileInputStream(file));
//	 			outputStream = response.getOutputStream();
//	 			byte[] buf = new byte[1024];
//	 			int len;
//	 			while ((len = inputStream.read(buf)) > 0) {
//	 				outputStream.write(buf, 0, len);
//	 			}
//	 			response.flushBuffer();
//	         }
//
//		} catch (Exception e) {
//			log.info("文件下载失败" + e.getMessage());
//			// e.printStackTrace();
//		} finally {
//			if (inputStream != null) {
//				try {
//					inputStream.close();
//				} catch (IOException e) {
//					e.printStackTrace();
//				}
//			}
//			if (outputStream != null) {
//				try {
//					outputStream.close();
//				} catch (IOException e) {
//					e.printStackTrace();
//				}
//			}
//		}
//
//	}

    /**
     * @param modelAndView
     * @return
     * @功能：pdf预览Iframe
     */
    @RequestMapping("/pdf/pdfPreviewIframe")
    public ModelAndView pdfPreviewIframe(ModelAndView modelAndView) {
        modelAndView.setViewName("pdfPreviewIframe");
        return modelAndView;
    }

    /**
     * 把指定URL后的字符串全部截断当成参数
     * 这么做是为了防止URL中包含中文或者特殊字符（/等）时，匹配不了的问题
     *
     * @param request
     * @return
     */
    private static String extractPathFromPattern(final HttpServletRequest request) {
        String path = (String) request.getAttribute(HandlerMapping.PATH_WITHIN_HANDLER_MAPPING_ATTRIBUTE);
        String bestMatchPattern = (String) request.getAttribute(HandlerMapping.BEST_MATCHING_PATTERN_ATTRIBUTE);
        return new AntPathMatcher().extractPathWithinPattern(bestMatchPattern, path);
    }

    /**
     * 获取文件真实路径
     *
     * @param path
     * @return
     */
    private String getDownloadPath(String path) {
        String filePath = "";
        if (org.jeecg.common.util.text.StringUtils.isEmpty(path)) {
            return "";
        }
        int idx = path.indexOf(downloadpath);
        if (idx == -1) {
            filePath = downloadpath + File.separator + path;
        } else {
            filePath = path;
        }
        return filePath;
    }

}
